Class: Google::Apis::SpannerV1::AsymmetricAutoscalingOption
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::AsymmetricAutoscalingOption
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
AsymmetricAutoscalingOption specifies the scaling of replicas identified by the given selection.
Instance Attribute Summary collapse
-
#overrides ⇒ Google::Apis::SpannerV1::AutoscalingConfigOverrides
Overrides the top-level autoscaling configuration for the replicas identified by
replica_selection. -
#replica_selection ⇒ Google::Apis::SpannerV1::InstanceReplicaSelection
ReplicaSelection identifies replicas with common properties.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AsymmetricAutoscalingOption
constructor
A new instance of AsymmetricAutoscalingOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AsymmetricAutoscalingOption
Returns a new instance of AsymmetricAutoscalingOption.
205 206 207 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#overrides ⇒ Google::Apis::SpannerV1::AutoscalingConfigOverrides
Overrides the top-level autoscaling configuration for the replicas identified
by replica_selection. All fields in this message are optional. Any
unspecified fields will use the corresponding values from the top-level
autoscaling configuration.
Corresponds to the JSON property overrides
198 199 200 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 198 def overrides @overrides end |
#replica_selection ⇒ Google::Apis::SpannerV1::InstanceReplicaSelection
ReplicaSelection identifies replicas with common properties.
Corresponds to the JSON property replicaSelection
203 204 205 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 203 def replica_selection @replica_selection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
210 211 212 213 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 210 def update!(**args) @overrides = args[:overrides] if args.key?(:overrides) @replica_selection = args[:replica_selection] if args.key?(:replica_selection) end |