Class: Google::Apis::SpannerV1::BackupInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Information about a backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupInfo

Returns a new instance of BackupInfo.



649
650
651
# File 'lib/google/apis/spanner_v1/classes.rb', line 649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

Name of the backup. Corresponds to the JSON property backup

Returns:

  • (String)


629
630
631
# File 'lib/google/apis/spanner_v1/classes.rb', line 629

def backup
  @backup
end

#create_timeString

The time the CreateBackup request was received. Corresponds to the JSON property createTime

Returns:

  • (String)


634
635
636
# File 'lib/google/apis/spanner_v1/classes.rb', line 634

def create_time
  @create_time
end

#source_databaseString

Name of the database the backup was created from. Corresponds to the JSON property sourceDatabase

Returns:

  • (String)


639
640
641
# File 'lib/google/apis/spanner_v1/classes.rb', line 639

def source_database
  @source_database
end

#version_timeString

The backup contains an externally consistent copy of source_database at the timestamp specified by version_time. If the CreateBackup request did not specify version_time, the version_time of the backup is equivalent to the create_time. Corresponds to the JSON property versionTime

Returns:

  • (String)


647
648
649
# File 'lib/google/apis/spanner_v1/classes.rb', line 647

def version_time
  @version_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



654
655
656
657
658
659
# File 'lib/google/apis/spanner_v1/classes.rb', line 654

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @create_time = args[:create_time] if args.key?(:create_time)
  @source_database = args[:source_database] if args.key?(:source_database)
  @version_time = args[:version_time] if args.key?(:version_time)
end