Class: Google::Apis::SpannerV1::BackupScheduleSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Defines specifications of the backup schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackupScheduleSpec

Returns a new instance of BackupScheduleSpec.



759
760
761
# File 'lib/google/apis/spanner_v1/classes.rb', line 759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cron_specGoogle::Apis::SpannerV1::CrontabSpec

CrontabSpec can be used to specify the version time and frequency at which the backup is created. Corresponds to the JSON property cronSpec



757
758
759
# File 'lib/google/apis/spanner_v1/classes.rb', line 757

def cron_spec
  @cron_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



764
765
766
# File 'lib/google/apis/spanner_v1/classes.rb', line 764

def update!(**args)
  @cron_spec = args[:cron_spec] if args.key?(:cron_spec)
end