Class: Google::Apis::SpannerV1::BatchWriteRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for BatchWrite.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchWriteRequest

Returns a new instance of BatchWriteRequest.



842
843
844
# File 'lib/google/apis/spanner_v1/classes.rb', line 842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclude_txn_from_change_streamsBoolean Also known as: exclude_txn_from_change_streams?

Optional. If you don't set the exclude_txn_from_change_streams option or if it's set to false, then any change streams monitoring columns modified by transactions will capture the updates made within that transaction. Corresponds to the JSON property excludeTxnFromChangeStreams

Returns:

  • (Boolean)


829
830
831
# File 'lib/google/apis/spanner_v1/classes.rb', line 829

def exclude_txn_from_change_streams
  @exclude_txn_from_change_streams
end

#mutation_groupsArray<Google::Apis::SpannerV1::MutationGroup>

Required. The groups of mutations to be applied. Corresponds to the JSON property mutationGroups



835
836
837
# File 'lib/google/apis/spanner_v1/classes.rb', line 835

def mutation_groups
  @mutation_groups
end

#request_optionsGoogle::Apis::SpannerV1::RequestOptions

Common request options for various APIs. Corresponds to the JSON property requestOptions



840
841
842
# File 'lib/google/apis/spanner_v1/classes.rb', line 840

def request_options
  @request_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



847
848
849
850
851
# File 'lib/google/apis/spanner_v1/classes.rb', line 847

def update!(**args)
  @exclude_txn_from_change_streams = args[:exclude_txn_from_change_streams] if args.key?(:exclude_txn_from_change_streams)
  @mutation_groups = args[:mutation_groups] if args.key?(:mutation_groups)
  @request_options = args[:request_options] if args.key?(:request_options)
end