Class: Google::Apis::SpannerV1::BeginTransactionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for BeginTransaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BeginTransactionRequest

Returns a new instance of BeginTransactionRequest.



912
913
914
# File 'lib/google/apis/spanner_v1/classes.rb', line 912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mutation_keyGoogle::Apis::SpannerV1::Mutation

A modification to one or more Cloud Spanner rows. Mutations can be applied to a Cloud Spanner database by sending them in a Commit call. Corresponds to the JSON property mutationKey



900
901
902
# File 'lib/google/apis/spanner_v1/classes.rb', line 900

def mutation_key
  @mutation_key
end

#optionsGoogle::Apis::SpannerV1::TransactionOptions

Options to use for transactions. Corresponds to the JSON property options



905
906
907
# File 'lib/google/apis/spanner_v1/classes.rb', line 905

def options
  @options
end

#request_optionsGoogle::Apis::SpannerV1::RequestOptions

Common request options for various APIs. Corresponds to the JSON property requestOptions



910
911
912
# File 'lib/google/apis/spanner_v1/classes.rb', line 910

def request_options
  @request_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



917
918
919
920
921
# File 'lib/google/apis/spanner_v1/classes.rb', line 917

def update!(**args)
  @mutation_key = args[:mutation_key] if args.key?(:mutation_key)
  @options = args[:options] if args.key?(:options)
  @request_options = args[:request_options] if args.key?(:request_options)
end