Class: Google::Apis::SpannerV1::ChangeQuorumMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ChangeQuorumMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Metadata type for the long-running operation returned by ChangeQuorum.
Instance Attribute Summary collapse
-
#end_time ⇒ String
If set, the time at which this operation failed or was completed successfully.
-
#request ⇒ Google::Apis::SpannerV1::ChangeQuorumRequest
The request for ChangeQuorum.
-
#start_time ⇒ String
Time the request was received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChangeQuorumMetadata
constructor
A new instance of ChangeQuorumMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChangeQuorumMetadata
Returns a new instance of ChangeQuorumMetadata.
1044 1045 1046 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1044 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
If set, the time at which this operation failed or was completed successfully.
Corresponds to the JSON property endTime
1032 1033 1034 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1032 def end_time @end_time end |
#request ⇒ Google::Apis::SpannerV1::ChangeQuorumRequest
The request for ChangeQuorum.
Corresponds to the JSON property request
1037 1038 1039 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1037 def request @request end |
#start_time ⇒ String
Time the request was received.
Corresponds to the JSON property startTime
1042 1043 1044 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1042 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1049 1050 1051 1052 1053 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1049 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @request = args[:request] if args.key?(:request) @start_time = args[:start_time] if args.key?(:start_time) end |