Class: Google::Apis::SpannerV1::ChildLink
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ChildLink
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Metadata associated with a parent-child relationship appearing in a PlanNode.
Instance Attribute Summary collapse
-
#child_index ⇒ Fixnum
The node to which the link points.
-
#type ⇒ String
The type of the link.
-
#variable ⇒ String
Only present if the child node is SCALAR and corresponds to an output variable of the parent node.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChildLink
constructor
A new instance of ChildLink.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChildLink
Returns a new instance of ChildLink.
1193 1194 1195 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1193 def initialize(**args) update!(**args) end |
Instance Attribute Details
#child_index ⇒ Fixnum
The node to which the link points.
Corresponds to the JSON property childIndex
1173 1174 1175 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1173 def child_index @child_index end |
#type ⇒ String
The type of the link. For example, in Hash Joins this could be used to
distinguish between the build child and the probe child, or in the case of the
child being an output variable, to represent the tag associated with the
output variable.
Corresponds to the JSON property type
1181 1182 1183 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1181 def type @type end |
#variable ⇒ String
Only present if the child node is SCALAR and corresponds to an output variable
of the parent node. The field carries the name of the output variable. For
example, a TableScan operator that reads rows from a table will have child
links to the SCALAR nodes representing the output variables created for each
column that is read by the operator. The corresponding variable fields will
be set to the variable names assigned to the columns.
Corresponds to the JSON property variable
1191 1192 1193 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1191 def variable @variable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1198 1199 1200 1201 1202 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1198 def update!(**args) @child_index = args[:child_index] if args.key?(:child_index) @type = args[:type] if args.key?(:type) @variable = args[:variable] if args.key?(:variable) end |