Class: Google::Apis::SpannerV1::CommitResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The response for Commit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitResponse

Returns a new instance of CommitResponse.



1373
1374
1375
# File 'lib/google/apis/spanner_v1/classes.rb', line 1373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commit_statsGoogle::Apis::SpannerV1::CommitStats

Additional statistics about a commit. Corresponds to the JSON property commitStats



1341
1342
1343
# File 'lib/google/apis/spanner_v1/classes.rb', line 1341

def commit_stats
  @commit_stats
end

#commit_timestampString

The Cloud Spanner timestamp at which the transaction committed. Corresponds to the JSON property commitTimestamp

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/spanner_v1/classes.rb', line 1346

def commit_timestamp
  @commit_timestamp
end

#isolation_levelString

The isolation level used for the read-write transaction. Corresponds to the JSON property isolationLevel

Returns:

  • (String)


1351
1352
1353
# File 'lib/google/apis/spanner_v1/classes.rb', line 1351

def isolation_level
  @isolation_level
end

#precommit_tokenGoogle::Apis::SpannerV1::MultiplexedSessionPrecommitToken

When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses. Corresponds to the JSON property precommitToken



1359
1360
1361
# File 'lib/google/apis/spanner_v1/classes.rb', line 1359

def precommit_token
  @precommit_token
end

#read_lock_modeString

The read lock mode used for the read-write transaction. Corresponds to the JSON property readLockMode

Returns:

  • (String)


1364
1365
1366
# File 'lib/google/apis/spanner_v1/classes.rb', line 1364

def read_lock_mode
  @read_lock_mode
end

#snapshot_timestampString

If TransactionOptions.isolation_level is set to IsolationLevel. REPEATABLE_READ, then the snapshot timestamp is the timestamp at which all reads in the transaction ran. This timestamp is never returned. Corresponds to the JSON property snapshotTimestamp

Returns:

  • (String)


1371
1372
1373
# File 'lib/google/apis/spanner_v1/classes.rb', line 1371

def snapshot_timestamp
  @snapshot_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1378
1379
1380
1381
1382
1383
1384
1385
# File 'lib/google/apis/spanner_v1/classes.rb', line 1378

def update!(**args)
  @commit_stats = args[:commit_stats] if args.key?(:commit_stats)
  @commit_timestamp = args[:commit_timestamp] if args.key?(:commit_timestamp)
  @isolation_level = args[:isolation_level] if args.key?(:isolation_level)
  @precommit_token = args[:precommit_token] if args.key?(:precommit_token)
  @read_lock_mode = args[:read_lock_mode] if args.key?(:read_lock_mode)
  @snapshot_timestamp = args[:snapshot_timestamp] if args.key?(:snapshot_timestamp)
end