Class: Google::Apis::SpannerV1::CommitStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Additional statistics about a commit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitStats

Returns a new instance of CommitStats.



1404
1405
1406
# File 'lib/google/apis/spanner_v1/classes.rb', line 1404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mutation_countFixnum

The total number of mutations for the transaction. Knowing the mutation_count value can help you maximize the number of mutations in a transaction and minimize the number of API round trips. You can also monitor this value to prevent transactions from exceeding the system limit. If the number of mutations exceeds the limit, the server returns INVALID_ARGUMENT. Corresponds to the JSON property mutationCount

Returns:

  • (Fixnum)


1402
1403
1404
# File 'lib/google/apis/spanner_v1/classes.rb', line 1402

def mutation_count
  @mutation_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1409
1410
1411
# File 'lib/google/apis/spanner_v1/classes.rb', line 1409

def update!(**args)
  @mutation_count = args[:mutation_count] if args.key?(:mutation_count)
end