Class: Google::Apis::SpannerV1::CompactDatabaseMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::CompactDatabaseMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Metadata type for the long-running operation returned by CALL compact_all(),
which can be executed using ExecuteSql or ExecuteStreamingSql APIs.
Instance Attribute Summary collapse
-
#cancel_time ⇒ String
Output only.
-
#database ⇒ String
Output only.
-
#progress ⇒ Google::Apis::SpannerV1::OperationProgress
Encapsulates progress related information for a Cloud Spanner long running operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompactDatabaseMetadata
constructor
A new instance of CompactDatabaseMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompactDatabaseMetadata
Returns a new instance of CompactDatabaseMetadata.
1442 1443 1444 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancel_time ⇒ String
Output only. The time at which cancellation of this operation was received.
Operations.CancelOperation starts asynchronous cancellation on a long-running
operation. The server makes a best effort to cancel the operation, but success
is not guaranteed. Clients can use Operations.GetOperation or other methods to
check whether the cancellation succeeded or whether the operation completed
despite cancellation. On successful cancellation, the operation is not deleted;
instead, it becomes an operation with an Operation.error value with a google.
rpc.Status.code of 1, corresponding to Code.CANCELLED.
Corresponds to the JSON property cancelTime
1429 1430 1431 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1429 def cancel_time @cancel_time end |
#database ⇒ String
Output only. The database being compacted.
Corresponds to the JSON property database
1434 1435 1436 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1434 def database @database end |
#progress ⇒ Google::Apis::SpannerV1::OperationProgress
Encapsulates progress related information for a Cloud Spanner long running
operation.
Corresponds to the JSON property progress
1440 1441 1442 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1440 def progress @progress end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1447 1448 1449 1450 1451 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1447 def update!(**args) @cancel_time = args[:cancel_time] if args.key?(:cancel_time) @database = args[:database] if args.key?(:database) @progress = args[:progress] if args.key?(:progress) end |