Class: Google::Apis::SpannerV1::CopyBackupEncryptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::CopyBackupEncryptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Encryption configuration for the copied backup.
Instance Attribute Summary collapse
-
#encryption_type ⇒ String
Required.
-
#kms_key_name ⇒ String
Optional.
-
#kms_key_names ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CopyBackupEncryptionConfig
constructor
A new instance of CopyBackupEncryptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CopyBackupEncryptionConfig
Returns a new instance of CopyBackupEncryptionConfig.
1520 1521 1522 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_type ⇒ String
Required. The encryption type of the backup.
Corresponds to the JSON property encryptionType
1488 1489 1490 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1488 def encryption_type @encryption_type end |
#kms_key_name ⇒ String
Optional. This field is maintained for backwards compatibility. For new
callers, we recommend using kms_key_names to specify the KMS key. Only use
kms_key_name if the location of the KMS key matches the database instance's
configuration (location) exactly. For example, if the KMS location is in us-
central1 or nam3, then the database instance must also be in us-central1
or nam3. The Cloud KMS key that is used to encrypt and decrypt the restored
database. Set this field only when encryption_type is
CUSTOMER_MANAGED_ENCRYPTION. Values are of the form projects/project/
locations/location/keyRings/key_ring/cryptoKeys/kms_key_name`.
Corresponds to the JSON propertykmsKeyName`
1501 1502 1503 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1501 def kms_key_name @kms_key_name end |
#kms_key_names ⇒ Array<String>
Optional. Specifies the KMS configuration for the one or more keys used to
protect the backup. Values are of the form projects/project/locations/
location/keyRings/key_ring/cryptoKeys/kms_key_name`. KMS keys specified
can be in any order. The keys referenced bykms_key_namesmust fully cover
all regions of the backup's instance configuration. Some examples: * For
regional (single-region) instance configurations, specify a regional location
KMS key. * For multi-region instance configurations of typeGOOGLE_MANAGED,
either specify a multi-region location KMS key or multiple regional location
KMS keys that cover all regions in the instance configuration. * For an
instance configuration of typeUSER_MANAGED, specify only regional location
KMS keys to cover each region in the instance configuration. Multi-region
location KMS keys aren't supported forUSER_MANAGEDtype instance
configurations.
Corresponds to the JSON propertykmsKeyNames`
1518 1519 1520 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1518 def kms_key_names @kms_key_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1525 1526 1527 1528 1529 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1525 def update!(**args) @encryption_type = args[:encryption_type] if args.key?(:encryption_type) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_names = args[:kms_key_names] if args.key?(:kms_key_names) end |