Class: Google::Apis::SpannerV1::CopyBackupRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for CopyBackup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CopyBackupRequest

Returns a new instance of CopyBackupRequest.



1625
1626
1627
# File 'lib/google/apis/spanner_v1/classes.rb', line 1625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_idString

Required. The id of the backup copy. The backup_id appended to parent forms the full backup_uri of the form projects/project/instances/instance/ backups/backup`. Corresponds to the JSON propertybackupId`

Returns:

  • (String)


1600
1601
1602
# File 'lib/google/apis/spanner_v1/classes.rb', line 1600

def backup_id
  @backup_id
end

#encryption_configGoogle::Apis::SpannerV1::CopyBackupEncryptionConfig

Encryption configuration for the copied backup. Corresponds to the JSON property encryptionConfig



1605
1606
1607
# File 'lib/google/apis/spanner_v1/classes.rb', line 1605

def encryption_config
  @encryption_config
end

#expire_timeString

Required. The expiration time of the backup in microsecond granularity. The expiration time must be at least 6 hours and at most 366 days from the create_time of the source backup. Once the expire_time has passed, the backup is eligible to be automatically deleted by Cloud Spanner to free the resources used by the backup. Corresponds to the JSON property expireTime

Returns:

  • (String)


1614
1615
1616
# File 'lib/google/apis/spanner_v1/classes.rb', line 1614

def expire_time
  @expire_time
end

#source_backupString

Required. The source backup to be copied. The source backup needs to be in READY state for it to be copied. Once CopyBackup is in progress, the source backup cannot be deleted or cleaned up on expiration until CopyBackup is finished. Values are of the form: projects/project/instances/instance/ backups/backup`. Corresponds to the JSON propertysourceBackup`

Returns:

  • (String)


1623
1624
1625
# File 'lib/google/apis/spanner_v1/classes.rb', line 1623

def source_backup
  @source_backup
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1630
1631
1632
1633
1634
1635
# File 'lib/google/apis/spanner_v1/classes.rb', line 1630

def update!(**args)
  @backup_id = args[:backup_id] if args.key?(:backup_id)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @source_backup = args[:source_backup] if args.key?(:source_backup)
end