Class: Google::Apis::SpannerV1::CreateBackupEncryptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Encryption configuration for the backup to create.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateBackupEncryptionConfig

Returns a new instance of CreateBackupEncryptionConfig.



1664
1665
1666
# File 'lib/google/apis/spanner_v1/classes.rb', line 1664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encryption_typeString

Required. The encryption type of the backup. Corresponds to the JSON property encryptionType

Returns:

  • (String)


1633
1634
1635
# File 'lib/google/apis/spanner_v1/classes.rb', line 1633

def encryption_type
  @encryption_type
end

#kms_key_nameString

Optional. This field is maintained for backwards compatibility. For new callers, we recommend using kms_key_names to specify the KMS key. Only use kms_key_name if the location of the KMS key matches the database instance's configuration (location) exactly. For example, if the KMS location is in us- central1 or nam3, then the database instance must also be in us-central1 or nam3. The Cloud KMS key that is used to encrypt and decrypt the restored database. Set this field only when encryption_type is CUSTOMER_MANAGED_ENCRYPTION. Values are of the form projects/project/ locations/location/keyRings/key_ring/cryptoKeys/kms_key_name`. Corresponds to the JSON propertykmsKeyName`

Returns:

  • (String)


1646
1647
1648
# File 'lib/google/apis/spanner_v1/classes.rb', line 1646

def kms_key_name
  @kms_key_name
end

#kms_key_namesArray<String>

Optional. Specifies the KMS configuration for the one or more keys used to protect the backup. Values are of the form projects/project/locations/ location/keyRings/key_ring/cryptoKeys/kms_key_name`. The keys referenced bykms_key_namesmust fully cover all regions of the backup's instance configuration. Some examples: * For regional (single-region) instance configurations, specify a regional location KMS key. * For multi-region instance configurations of typeGOOGLE_MANAGED, either specify a multi- region location KMS key or multiple regional location KMS keys that cover all regions in the instance configuration. * For an instance configuration of type USER_MANAGED, specify only regional location KMS keys to cover each region in the instance configuration. Multi-region location KMS keys aren't supported forUSER_MANAGEDtype instance configurations. Corresponds to the JSON propertykmsKeyNames`

Returns:

  • (Array<String>)


1662
1663
1664
# File 'lib/google/apis/spanner_v1/classes.rb', line 1662

def kms_key_names
  @kms_key_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1669
1670
1671
1672
1673
# File 'lib/google/apis/spanner_v1/classes.rb', line 1669

def update!(**args)
  @encryption_type = args[:encryption_type] if args.key?(:encryption_type)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @kms_key_names = args[:kms_key_names] if args.key?(:kms_key_names)
end