Class: Google::Apis::SpannerV1::CreateInstanceConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for CreateInstanceConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateInstanceConfigRequest

Returns a new instance of CreateInstanceConfigRequest.



1858
1859
1860
# File 'lib/google/apis/spanner_v1/classes.rb', line 1858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_configGoogle::Apis::SpannerV1::InstanceConfig

A possible configuration for a Cloud Spanner instance. Configurations define the geographic placement of nodes and their replication. Corresponds to the JSON property instanceConfig



1841
1842
1843
# File 'lib/google/apis/spanner_v1/classes.rb', line 1841

def instance_config
  @instance_config
end

#instance_config_idString

Required. The ID of the instance configuration to create. Valid identifiers are of the form custom-[-a-z0-9]*[a-z0-9] and must be between 2 and 64 characters in length. The custom- prefix is required to avoid name conflicts with Google-managed configurations. Corresponds to the JSON property instanceConfigId

Returns:

  • (String)


1849
1850
1851
# File 'lib/google/apis/spanner_v1/classes.rb', line 1849

def instance_config_id
  @instance_config_id
end

#validate_onlyBoolean Also known as: validate_only?

An option to validate, but not actually execute, a request, and provide the same response. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


1855
1856
1857
# File 'lib/google/apis/spanner_v1/classes.rb', line 1855

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1863
1864
1865
1866
1867
# File 'lib/google/apis/spanner_v1/classes.rb', line 1863

def update!(**args)
  @instance_config = args[:instance_config] if args.key?(:instance_config)
  @instance_config_id = args[:instance_config_id] if args.key?(:instance_config_id)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end