Class: Google::Apis::SpannerV1::DerivedMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A message representing a derived metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DerivedMetric

Returns a new instance of DerivedMetric.



2454
2455
2456
# File 'lib/google/apis/spanner_v1/classes.rb', line 2454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#denominatorGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property denominator



2446
2447
2448
# File 'lib/google/apis/spanner_v1/classes.rb', line 2446

def denominator
  @denominator
end

#numeratorGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property numerator



2452
2453
2454
# File 'lib/google/apis/spanner_v1/classes.rb', line 2452

def numerator
  @numerator
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2459
2460
2461
2462
# File 'lib/google/apis/spanner_v1/classes.rb', line 2459

def update!(**args)
  @denominator = args[:denominator] if args.key?(:denominator)
  @numerator = args[:numerator] if args.key?(:numerator)
end