Class: Google::Apis::SpannerV1::EncryptionInfo
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::EncryptionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Encryption information for a Cloud Spanner database or backup.
Instance Attribute Summary collapse
-
#encryption_status ⇒ Google::Apis::SpannerV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#encryption_type ⇒ String
Output only.
-
#kms_key_version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionInfo
constructor
A new instance of EncryptionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionInfo
Returns a new instance of EncryptionInfo.
2637 2638 2639 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_status ⇒ Google::Apis::SpannerV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property encryptionStatus
2624 2625 2626 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2624 def encryption_status @encryption_status end |
#encryption_type ⇒ String
Output only. The type of encryption.
Corresponds to the JSON property encryptionType
2629 2630 2631 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2629 def encryption_type @encryption_type end |
#kms_key_version ⇒ String
Output only. A Cloud KMS key version that is being used to protect the
database or backup.
Corresponds to the JSON property kmsKeyVersion
2635 2636 2637 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2635 def kms_key_version @kms_key_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2642 2643 2644 2645 2646 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2642 def update!(**args) @encryption_status = args[:encryption_status] if args.key?(:encryption_status) @encryption_type = args[:encryption_type] if args.key?(:encryption_type) @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version) end |