Class: Google::Apis::SpannerV1::ExecuteSqlRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for ExecuteSql and ExecuteStreamingSql.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecuteSqlRequest

Returns a new instance of ExecuteSqlRequest.



2899
2900
2901
# File 'lib/google/apis/spanner_v1/classes.rb', line 2899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_boost_enabledBoolean Also known as: data_boost_enabled?

If this is for a partitioned query and this field is set to true, the request is executed with Spanner Data Boost independent compute resources. If the field is set to true but the request doesn't set partition_token, the API returns an INVALID_ARGUMENT error. Corresponds to the JSON property dataBoostEnabled

Returns:

  • (Boolean)


2796
2797
2798
# File 'lib/google/apis/spanner_v1/classes.rb', line 2796

def data_boost_enabled
  @data_boost_enabled
end

#directed_read_optionsGoogle::Apis::SpannerV1::DirectedReadOptions

The DirectedReadOptions can be used to indicate which replicas or regions should be used for non-transactional reads or queries. DirectedReadOptions can only be specified for a read-only transaction, otherwise the API returns an INVALID_ARGUMENT error. Corresponds to the JSON property directedReadOptions



2805
2806
2807
# File 'lib/google/apis/spanner_v1/classes.rb', line 2805

def directed_read_options
  @directed_read_options
end

#last_statementBoolean Also known as: last_statement?

Optional. If set to true, this statement marks the end of the transaction. After this statement executes, you must commit or abort the transaction. Attempts to execute any other requests against this transaction (including reads and queries) are rejected. For DML statements, setting this option might cause some error reporting to be deferred until commit time (for example, validation of unique constraints). Given this, successful execution of a DML statement shouldn't be assumed until a subsequent Commit call completes successfully. Corresponds to the JSON property lastStatement

Returns:

  • (Boolean)


2817
2818
2819
# File 'lib/google/apis/spanner_v1/classes.rb', line 2817

def last_statement
  @last_statement
end

#param_typesHash<String,Google::Apis::SpannerV1::Type>

It isn't always possible for Cloud Spanner to infer the right SQL type from a JSON value. For example, values of type BYTES and values of type STRING both appear in params as JSON strings. In these cases, you can use param_types to specify the exact SQL type for some or all of the SQL statement parameters. See the definition of Type for more information about SQL types. Corresponds to the JSON property paramTypes

Returns:



2828
2829
2830
# File 'lib/google/apis/spanner_v1/classes.rb', line 2828

def param_types
  @param_types
end

#paramsHash<String,Object>

Parameter names and values that bind to placeholders in the SQL string. A parameter placeholder consists of the @ character followed by the parameter name (for example, @firstName). Parameter names must conform to the naming requirements of identifiers as specified at https://cloud.google.com/spanner/ docs/lexical#identifiers. Parameters can appear anywhere that a literal value is expected. The same parameter name can be used more than once, for example: "WHERE id > @msg_id AND id < @msg_id + 100" It's an error to execute a SQL statement with unbound parameters. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


2840
2841
2842
# File 'lib/google/apis/spanner_v1/classes.rb', line 2840

def params
  @params
end

#partition_tokenString

If present, results are restricted to the specified partition previously created using PartitionQuery. There must be an exact match for the values of fields common to this message and the PartitionQueryRequest message used to create this partition_token. Corresponds to the JSON property partitionToken NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2849
2850
2851
# File 'lib/google/apis/spanner_v1/classes.rb', line 2849

def partition_token
  @partition_token
end

#query_modeString

Used to control the amount of debugging information returned in ResultSetStats. If partition_token is set, query_mode can only be set to QueryMode.NORMAL. Corresponds to the JSON property queryMode

Returns:

  • (String)


2855
2856
2857
# File 'lib/google/apis/spanner_v1/classes.rb', line 2855

def query_mode
  @query_mode
end

#query_optionsGoogle::Apis::SpannerV1::QueryOptions

Query optimizer configuration. Corresponds to the JSON property queryOptions



2860
2861
2862
# File 'lib/google/apis/spanner_v1/classes.rb', line 2860

def query_options
  @query_options
end

#request_optionsGoogle::Apis::SpannerV1::RequestOptions

Common request options for various APIs. Corresponds to the JSON property requestOptions



2865
2866
2867
# File 'lib/google/apis/spanner_v1/classes.rb', line 2865

def request_options
  @request_options
end

#resume_tokenString

If this request is resuming a previously interrupted SQL statement execution, resume_token should be copied from the last PartialResultSet yielded before the interruption. Doing this enables the new SQL statement execution to resume where the last one left off. The rest of the request parameters must exactly match the request that yielded this token. Corresponds to the JSON property resumeToken NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2875
2876
2877
# File 'lib/google/apis/spanner_v1/classes.rb', line 2875

def resume_token
  @resume_token
end

#seqnoFixnum

A per-transaction sequence number used to identify this request. This field makes each request idempotent such that if the request is received multiple times, at most one succeeds. The sequence number must be monotonically increasing within the transaction. If a request arrives for the first time with an out-of-order sequence number, the transaction can be aborted. Replays of previously handled requests yield the same response as the first execution. Required for DML statements. Ignored for queries. Corresponds to the JSON property seqno

Returns:

  • (Fixnum)


2886
2887
2888
# File 'lib/google/apis/spanner_v1/classes.rb', line 2886

def seqno
  @seqno
end

#sqlString

Required. The SQL string. Corresponds to the JSON property sql

Returns:

  • (String)


2891
2892
2893
# File 'lib/google/apis/spanner_v1/classes.rb', line 2891

def sql
  @sql
end

#transactionGoogle::Apis::SpannerV1::TransactionSelector

This message is used to select the transaction in which a Read or ExecuteSql call runs. See TransactionOptions for more information about transactions. Corresponds to the JSON property transaction



2897
2898
2899
# File 'lib/google/apis/spanner_v1/classes.rb', line 2897

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
# File 'lib/google/apis/spanner_v1/classes.rb', line 2904

def update!(**args)
  @data_boost_enabled = args[:data_boost_enabled] if args.key?(:data_boost_enabled)
  @directed_read_options = args[:directed_read_options] if args.key?(:directed_read_options)
  @last_statement = args[:last_statement] if args.key?(:last_statement)
  @param_types = args[:param_types] if args.key?(:param_types)
  @params = args[:params] if args.key?(:params)
  @partition_token = args[:partition_token] if args.key?(:partition_token)
  @query_mode = args[:query_mode] if args.key?(:query_mode)
  @query_options = args[:query_options] if args.key?(:query_options)
  @request_options = args[:request_options] if args.key?(:request_options)
  @resume_token = args[:resume_token] if args.key?(:resume_token)
  @seqno = args[:seqno] if args.key?(:seqno)
  @sql = args[:sql] if args.key?(:sql)
  @transaction = args[:transaction] if args.key?(:transaction)
end