Class: Google::Apis::SpannerV1::Field
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::Field
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Message representing a single field of a struct.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the field.
-
#type ⇒ Google::Apis::SpannerV1::Type
Typeindicates the type of a Cloud Spanner value, as might be stored in a table cell or returned from an SQL query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Field
constructor
A new instance of Field.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Field
Returns a new instance of Field.
2994 2995 2996 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the field. For reads, this is the column name. For SQL queries, it
is the column alias (e.g., "Word" in the query "SELECT 'hello' AS Word"),
or the column name (e.g., "ColName" in the query "SELECT ColName FROM Table"
). Some columns might have an empty name (e.g., "SELECT UPPER(ColName)").
Note that a query result can contain multiple fields with the same name.
Corresponds to the JSON property name
2986 2987 2988 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2986 def name @name end |
#type ⇒ Google::Apis::SpannerV1::Type
Type indicates the type of a Cloud Spanner value, as might be stored in a
table cell or returned from an SQL query.
Corresponds to the JSON property type
2992 2993 2994 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2992 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2999 3000 3001 3002 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2999 def update!(**args) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |