Class: Google::Apis::SpannerV1::FreeInstanceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::FreeInstanceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Free instance specific metadata that is kept even after an instance has been upgraded for tracking purposes.
Instance Attribute Summary collapse
-
#expire_behavior ⇒ String
Specifies the expiration behavior of a free instance.
-
#expire_time ⇒ String
Output only.
-
#upgrade_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FreeInstanceMetadata
constructor
A new instance of FreeInstanceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FreeInstanceMetadata
Returns a new instance of FreeInstanceMetadata.
3031 3032 3033 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_behavior ⇒ String
Specifies the expiration behavior of a free instance. The default of
ExpireBehavior is REMOVE_AFTER_GRACE_PERIOD. This can be modified during or
after creation, and before expiration.
Corresponds to the JSON property expireBehavior
3015 3016 3017 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3015 def expire_behavior @expire_behavior end |
#expire_time ⇒ String
Output only. Timestamp after which the instance will either be upgraded or
scheduled for deletion after a grace period. ExpireBehavior is used to choose
between upgrading or scheduling the free instance for deletion. This timestamp
is set during the creation of a free instance.
Corresponds to the JSON property expireTime
3023 3024 3025 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3023 def expire_time @expire_time end |
#upgrade_time ⇒ String
Output only. If present, the timestamp at which the free instance was upgraded
to a provisioned instance.
Corresponds to the JSON property upgradeTime
3029 3030 3031 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3029 def upgrade_time @upgrade_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3036 3037 3038 3039 3040 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3036 def update!(**args) @expire_behavior = args[:expire_behavior] if args.key?(:expire_behavior) @expire_time = args[:expire_time] if args.key?(:expire_time) @upgrade_time = args[:upgrade_time] if args.key?(:upgrade_time) end |