Class: Google::Apis::SpannerV1::HeartbeatRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A heartbeat record is returned as a progress indicator, when there are no data changes or any other partition record types in the change stream partition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HeartbeatRecord

Returns a new instance of HeartbeatRecord.



3044
3045
3046
# File 'lib/google/apis/spanner_v1/classes.rb', line 3044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#timestampString

Indicates the timestamp at which the query has returned all the records in the change stream partition with timestamp <= heartbeat timestamp. The heartbeat timestamp will not be the same as the timestamps of other record types in the same partition. Corresponds to the JSON property timestamp

Returns:

  • (String)


3042
3043
3044
# File 'lib/google/apis/spanner_v1/classes.rb', line 3042

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3049
3050
3051
# File 'lib/google/apis/spanner_v1/classes.rb', line 3049

def update!(**args)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end