Class: Google::Apis::SpannerV1::IndexedHotKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A message representing a (sparse) collection of hot keys for specific key buckets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IndexedHotKey

Returns a new instance of IndexedHotKey.



3231
3232
3233
# File 'lib/google/apis/spanner_v1/classes.rb', line 3231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sparse_hot_keysHash<String,Fixnum>

A (sparse) mapping from key bucket index to the index of the specific hot row key for that key bucket. The index of the hot row key can be translated to the actual row key via the ScanData.VisualizationData.indexed_keys repeated field. Corresponds to the JSON property sparseHotKeys

Returns:

  • (Hash<String,Fixnum>)


3229
3230
3231
# File 'lib/google/apis/spanner_v1/classes.rb', line 3229

def sparse_hot_keys
  @sparse_hot_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3236
3237
3238
# File 'lib/google/apis/spanner_v1/classes.rb', line 3236

def update!(**args)
  @sparse_hot_keys = args[:sparse_hot_keys] if args.key?(:sparse_hot_keys)
end