Class: Google::Apis::SpannerV1::KeyRangeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A message representing information for a key range (possibly one key).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyRangeInfo

Returns a new instance of KeyRangeInfo.



3928
3929
3930
# File 'lib/google/apis/spanner_v1/classes.rb', line 3928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_valuesArray<Google::Apis::SpannerV1::ContextValue>

The list of context values for this key range. Corresponds to the JSON property contextValues



3883
3884
3885
# File 'lib/google/apis/spanner_v1/classes.rb', line 3883

def context_values
  @context_values
end

#end_key_indexFixnum

The index of the end key in indexed_keys. Corresponds to the JSON property endKeyIndex

Returns:

  • (Fixnum)


3888
3889
3890
# File 'lib/google/apis/spanner_v1/classes.rb', line 3888

def end_key_index
  @end_key_index
end

#infoGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property info



3894
3895
3896
# File 'lib/google/apis/spanner_v1/classes.rb', line 3894

def info
  @info
end

#keys_countFixnum

The number of keys this range covers. Corresponds to the JSON property keysCount

Returns:

  • (Fixnum)


3899
3900
3901
# File 'lib/google/apis/spanner_v1/classes.rb', line 3899

def keys_count
  @keys_count
end

#metricGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property metric



3905
3906
3907
# File 'lib/google/apis/spanner_v1/classes.rb', line 3905

def metric
  @metric
end

#start_key_indexFixnum

The index of the start key in indexed_keys. Corresponds to the JSON property startKeyIndex

Returns:

  • (Fixnum)


3910
3911
3912
# File 'lib/google/apis/spanner_v1/classes.rb', line 3910

def start_key_index
  @start_key_index
end

#time_offsetString

The time offset. This is the time since the start of the time interval. Corresponds to the JSON property timeOffset

Returns:

  • (String)


3915
3916
3917
# File 'lib/google/apis/spanner_v1/classes.rb', line 3915

def time_offset
  @time_offset
end

#unitGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property unit



3921
3922
3923
# File 'lib/google/apis/spanner_v1/classes.rb', line 3921

def unit
  @unit
end

#valueFloat

The value of the metric. Corresponds to the JSON property value

Returns:

  • (Float)


3926
3927
3928
# File 'lib/google/apis/spanner_v1/classes.rb', line 3926

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
# File 'lib/google/apis/spanner_v1/classes.rb', line 3933

def update!(**args)
  @context_values = args[:context_values] if args.key?(:context_values)
  @end_key_index = args[:end_key_index] if args.key?(:end_key_index)
  @info = args[:info] if args.key?(:info)
  @keys_count = args[:keys_count] if args.key?(:keys_count)
  @metric = args[:metric] if args.key?(:metric)
  @start_key_index = args[:start_key_index] if args.key?(:start_key_index)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @unit = args[:unit] if args.key?(:unit)
  @value = args[:value] if args.key?(:value)
end