Class: Google::Apis::SpannerV1::KeyRangeInfos

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A message representing a list of specific information for multiple key ranges.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyRangeInfos

Returns a new instance of KeyRangeInfos.



3962
3963
3964
# File 'lib/google/apis/spanner_v1/classes.rb', line 3962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#infosArray<Google::Apis::SpannerV1::KeyRangeInfo>

The list individual KeyRangeInfos. Corresponds to the JSON property infos



3953
3954
3955
# File 'lib/google/apis/spanner_v1/classes.rb', line 3953

def infos
  @infos
end

#total_sizeFixnum

The total size of the list of all KeyRangeInfos. This may be larger than the number of repeated messages above. If that is the case, this number may be used to determine how many are not being shown. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


3960
3961
3962
# File 'lib/google/apis/spanner_v1/classes.rb', line 3960

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3967
3968
3969
3970
# File 'lib/google/apis/spanner_v1/classes.rb', line 3967

def update!(**args)
  @infos = args[:infos] if args.key?(:infos)
  @total_size = args[:total_size] if args.key?(:total_size)
end