Class: Google::Apis::SpannerV1::KeySet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

KeySet defines a collection of Cloud Spanner keys and/or key ranges. All the keys are expected to be in the same table or index. The keys need not be sorted in any particular way. If the same key is specified multiple times in the set (for example if two ranges, two keys, or a key and a range overlap), Cloud Spanner behaves as if the key were only specified once.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeySet

Returns a new instance of KeySet.



4002
4003
4004
# File 'lib/google/apis/spanner_v1/classes.rb', line 4002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allBoolean Also known as: all?

For convenience all can be set to true to indicate that this KeySet matches all keys in the table or index. Note that any keys specified in keys or ranges are only yielded once. Corresponds to the JSON property all

Returns:

  • (Boolean)


3986
3987
3988
# File 'lib/google/apis/spanner_v1/classes.rb', line 3986

def all
  @all
end

#keysArray<Array<Object>>

A list of specific keys. Entries in keys should have exactly as many elements as there are columns in the primary or index key with which this KeySet is used. Individual key values are encoded as described here. Corresponds to the JSON property keys

Returns:

  • (Array<Array<Object>>)


3994
3995
3996
# File 'lib/google/apis/spanner_v1/classes.rb', line 3994

def keys
  @keys
end

#rangesArray<Google::Apis::SpannerV1::KeyRange>

A list of key ranges. See KeyRange for more information about key range specifications. Corresponds to the JSON property ranges



4000
4001
4002
# File 'lib/google/apis/spanner_v1/classes.rb', line 4000

def ranges
  @ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4007
4008
4009
4010
4011
# File 'lib/google/apis/spanner_v1/classes.rb', line 4007

def update!(**args)
  @all = args[:all] if args.key?(:all)
  @keys = args[:keys] if args.key?(:keys)
  @ranges = args[:ranges] if args.key?(:ranges)
end