Class: Google::Apis::SpannerV1::ListInstanceConfigOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The response for ListInstanceConfigOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstanceConfigOperationsResponse

Returns a new instance of ListInstanceConfigOperationsResponse.



4173
4174
4175
# File 'lib/google/apis/spanner_v1/classes.rb', line 4173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

next_page_token can be sent in a subsequent ListInstanceConfigOperations call to fetch more of the matching metadata. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4163
4164
4165
# File 'lib/google/apis/spanner_v1/classes.rb', line 4163

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::SpannerV1::Operation>

The list of matching instance configuration long-running operations. Each operation's name will be prefixed by the name of the instance configuration. The operation's metadata field type metadata.type_url describes the type of the metadata. Corresponds to the JSON property operations



4171
4172
4173
# File 'lib/google/apis/spanner_v1/classes.rb', line 4171

def operations
  @operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4178
4179
4180
4181
# File 'lib/google/apis/spanner_v1/classes.rb', line 4178

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
end