Class: Google::Apis::SpannerV1::ListInstancePartitionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The response for ListInstancePartitions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancePartitionsResponse

Returns a new instance of ListInstancePartitionsResponse.



4269
4270
4271
# File 'lib/google/apis/spanner_v1/classes.rb', line 4269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_partitionsArray<Google::Apis::SpannerV1::InstancePartition>

The list of requested instancePartitions. Corresponds to the JSON property instancePartitions



4254
4255
4256
# File 'lib/google/apis/spanner_v1/classes.rb', line 4254

def instance_partitions
  @instance_partitions
end

#next_page_tokenString

next_page_token can be sent in a subsequent ListInstancePartitions call to fetch more of the matching instance partitions. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4260
4261
4262
# File 'lib/google/apis/spanner_v1/classes.rb', line 4260

def next_page_token
  @next_page_token
end

#unreachableArray<String>

The list of unreachable instances or instance partitions. It includes the names of instances or instance partitions whose metadata could not be retrieved within instance_partition_deadline. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4267
4268
4269
# File 'lib/google/apis/spanner_v1/classes.rb', line 4267

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4274
4275
4276
4277
4278
# File 'lib/google/apis/spanner_v1/classes.rb', line 4274

def update!(**args)
  @instance_partitions = args[:instance_partitions] if args.key?(:instance_partitions)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end