Class: Google::Apis::SpannerV1::ListScansResponse
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ListScansResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Response method from the ListScans method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#scans ⇒ Array<Google::Apis::SpannerV1::Scan>
Available scans based on the list query parameters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScansResponse
constructor
A new instance of ListScansResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScansResponse
Returns a new instance of ListScansResponse.
4363 4364 4365 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4363 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
4356 4357 4358 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4356 def next_page_token @next_page_token end |
#scans ⇒ Array<Google::Apis::SpannerV1::Scan>
Available scans based on the list query parameters.
Corresponds to the JSON property scans
4361 4362 4363 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4361 def scans @scans end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4368 4369 4370 4371 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4368 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scans = args[:scans] if args.key?(:scans) end |