Class: Google::Apis::SpannerV1::Metric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A message representing the actual monitoring data, values for each key bucket over time, of a metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Metric

Returns a new instance of Metric.



4538
4539
4540
# File 'lib/google/apis/spanner_v1/classes.rb', line 4538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregationString

The aggregation function used to aggregate each key bucket Corresponds to the JSON property aggregation

Returns:

  • (String)


4469
4470
4471
# File 'lib/google/apis/spanner_v1/classes.rb', line 4469

def aggregation
  @aggregation
end

#categoryGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property category



4475
4476
4477
# File 'lib/google/apis/spanner_v1/classes.rb', line 4475

def category
  @category
end

#derivedGoogle::Apis::SpannerV1::DerivedMetric

A message representing a derived metric. Corresponds to the JSON property derived



4480
4481
4482
# File 'lib/google/apis/spanner_v1/classes.rb', line 4480

def derived
  @derived
end

#display_labelGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property displayLabel



4486
4487
4488
# File 'lib/google/apis/spanner_v1/classes.rb', line 4486

def display_label
  @display_label
end

#has_nonzero_dataBoolean Also known as: has_nonzero_data?

Whether the metric has any non-zero data. Corresponds to the JSON property hasNonzeroData

Returns:

  • (Boolean)


4491
4492
4493
# File 'lib/google/apis/spanner_v1/classes.rb', line 4491

def has_nonzero_data
  @has_nonzero_data
end

#hot_valueFloat

The value that is considered hot for the metric. On a per metric basis hotness signals high utilization and something that might potentially be a cause for concern by the end user. hot_value is used to calibrate and scale visual color scales. Corresponds to the JSON property hotValue

Returns:

  • (Float)


4500
4501
4502
# File 'lib/google/apis/spanner_v1/classes.rb', line 4500

def hot_value
  @hot_value
end

#indexed_hot_keysHash<String,Google::Apis::SpannerV1::IndexedHotKey>

The (sparse) mapping from time index to an IndexedHotKey message, representing those time intervals for which there are hot keys. Corresponds to the JSON property indexedHotKeys

Returns:



4506
4507
4508
# File 'lib/google/apis/spanner_v1/classes.rb', line 4506

def indexed_hot_keys
  @indexed_hot_keys
end

#indexed_key_range_infosHash<String,Google::Apis::SpannerV1::IndexedKeyRangeInfos>

The (sparse) mapping from time interval index to an IndexedKeyRangeInfos message, representing those time intervals for which there are informational messages concerning key ranges. Corresponds to the JSON property indexedKeyRangeInfos



4513
4514
4515
# File 'lib/google/apis/spanner_v1/classes.rb', line 4513

def indexed_key_range_infos
  @indexed_key_range_infos
end

#infoGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property info



4519
4520
4521
# File 'lib/google/apis/spanner_v1/classes.rb', line 4519

def info
  @info
end

#matrixGoogle::Apis::SpannerV1::MetricMatrix

A message representing a matrix of floats. Corresponds to the JSON property matrix



4524
4525
4526
# File 'lib/google/apis/spanner_v1/classes.rb', line 4524

def matrix
  @matrix
end

#unitGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property unit



4530
4531
4532
# File 'lib/google/apis/spanner_v1/classes.rb', line 4530

def unit
  @unit
end

#visibleBoolean Also known as: visible?

Whether the metric is visible to the end user. Corresponds to the JSON property visible

Returns:

  • (Boolean)


4535
4536
4537
# File 'lib/google/apis/spanner_v1/classes.rb', line 4535

def visible
  @visible
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
# File 'lib/google/apis/spanner_v1/classes.rb', line 4543

def update!(**args)
  @aggregation = args[:aggregation] if args.key?(:aggregation)
  @category = args[:category] if args.key?(:category)
  @derived = args[:derived] if args.key?(:derived)
  @display_label = args[:display_label] if args.key?(:display_label)
  @has_nonzero_data = args[:has_nonzero_data] if args.key?(:has_nonzero_data)
  @hot_value = args[:hot_value] if args.key?(:hot_value)
  @indexed_hot_keys = args[:indexed_hot_keys] if args.key?(:indexed_hot_keys)
  @indexed_key_range_infos = args[:indexed_key_range_infos] if args.key?(:indexed_key_range_infos)
  @info = args[:info] if args.key?(:info)
  @matrix = args[:matrix] if args.key?(:matrix)
  @unit = args[:unit] if args.key?(:unit)
  @visible = args[:visible] if args.key?(:visible)
end