Class: Google::Apis::SpannerV1::MoveInEvent
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::MoveInEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Describes move-in of the key ranges into the change stream partition identified by partition_token. To maintain processing the changes for a particular key in timestamp order, the query processing the change stream partition identified by partition_token should not advance beyond the partition event record commit timestamp until the queries processing the source change stream partitions have processed all change stream records with timestamps <= the partition event record commit timestamp.
Instance Attribute Summary collapse
-
#source_partition_token ⇒ String
An unique partition identifier describing the source change stream partition that recorded changes for the key range that is moving into this partition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MoveInEvent
constructor
A new instance of MoveInEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MoveInEvent
Returns a new instance of MoveInEvent.
4656 4657 4658 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_partition_token ⇒ String
An unique partition identifier describing the source change stream partition
that recorded changes for the key range that is moving into this partition.
Corresponds to the JSON property sourcePartitionToken
4654 4655 4656 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4654 def source_partition_token @source_partition_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4661 4662 4663 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4661 def update!(**args) @source_partition_token = args[:source_partition_token] if args.key?(:source_partition_token) end |