Class: Google::Apis::SpannerV1::MoveInstanceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for MoveInstance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MoveInstanceRequest

Returns a new instance of MoveInstanceRequest.



4675
4676
4677
# File 'lib/google/apis/spanner_v1/classes.rb', line 4675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_configString

Required. The target instance configuration where to move the instance. Values are of the form projects//instanceConfigs/. Corresponds to the JSON property targetConfig

Returns:

  • (String)


4667
4668
4669
# File 'lib/google/apis/spanner_v1/classes.rb', line 4667

def target_config
  @target_config
end

#target_database_move_configsArray<Google::Apis::SpannerV1::DatabaseMoveConfig>

Optional. The configuration for each database in the target instance configuration. Corresponds to the JSON property targetDatabaseMoveConfigs



4673
4674
4675
# File 'lib/google/apis/spanner_v1/classes.rb', line 4673

def target_database_move_configs
  @target_database_move_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4680
4681
4682
4683
# File 'lib/google/apis/spanner_v1/classes.rb', line 4680

def update!(**args)
  @target_config = args[:target_config] if args.key?(:target_config)
  @target_database_move_configs = args[:target_database_move_configs] if args.key?(:target_database_move_configs)
end