Class: Google::Apis::SpannerV1::PartialResultSet
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::PartialResultSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Partial results from a streaming read or SQL query. Streaming reads and SQL queries better tolerate large result sets, large rows, and large values, but are a little trickier to consume.
Instance Attribute Summary collapse
-
#chunked_value ⇒ Boolean
(also: #chunked_value?)
If true, then the final value in values is chunked, and must be combined with more values from subsequent
PartialResultSets to obtain a complete field value. -
#last ⇒ Boolean
(also: #last?)
Optional.
-
#metadata ⇒ Google::Apis::SpannerV1::ResultSetMetadata
Metadata about a ResultSet or PartialResultSet.
-
#precommit_token ⇒ Google::Apis::SpannerV1::MultiplexedSessionPrecommitToken
When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses.
-
#resume_token ⇒ String
Streaming calls might be interrupted for a variety of reasons, such as TCP connection loss.
-
#stats ⇒ Google::Apis::SpannerV1::ResultSetStats
Additional statistics about a ResultSet or PartialResultSet.
-
#values ⇒ Array<Object>
A streamed result set consists of a stream of values, which might be split into many
PartialResultSetmessages to accommodate large rows and/or large values.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartialResultSet
constructor
A new instance of PartialResultSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartialResultSet
Returns a new instance of PartialResultSet.
5038 5039 5040 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunked_value ⇒ Boolean Also known as: chunked_value?
If true, then the final value in values is chunked, and must be combined with
more values from subsequent PartialResultSets to obtain a complete field
value.
Corresponds to the JSON property chunkedValue
4961 4962 4963 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4961 def chunked_value @chunked_value end |
#last ⇒ Boolean Also known as: last?
Optional. Indicates whether this is the last PartialResultSet in the stream.
The server might optionally set this field. Clients shouldn't rely on this
field being set in all cases.
Corresponds to the JSON property last
4969 4970 4971 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4969 def last @last end |
#metadata ⇒ Google::Apis::SpannerV1::ResultSetMetadata
Metadata about a ResultSet or PartialResultSet.
Corresponds to the JSON property metadata
4975 4976 4977 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4975 def @metadata end |
#precommit_token ⇒ Google::Apis::SpannerV1::MultiplexedSessionPrecommitToken
When a read-write transaction is executed on a multiplexed session, this
precommit token is sent back to the client as a part of the Transaction
message in the BeginTransaction response and also as a part of the ResultSet
and PartialResultSet responses.
Corresponds to the JSON property precommitToken
4983 4984 4985 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4983 def precommit_token @precommit_token end |
#resume_token ⇒ String
Streaming calls might be interrupted for a variety of reasons, such as TCP
connection loss. If this occurs, the stream of results can be resumed by re-
sending the original request and including resume_token. Note that executing
any other transaction in the same session invalidates the token.
Corresponds to the JSON property resumeToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
4992 4993 4994 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4992 def resume_token @resume_token end |
#stats ⇒ Google::Apis::SpannerV1::ResultSetStats
Additional statistics about a ResultSet or PartialResultSet.
Corresponds to the JSON property stats
4997 4998 4999 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4997 def stats @stats end |
#values ⇒ Array<Object>
A streamed result set consists of a stream of values, which might be split
into many PartialResultSet messages to accommodate large rows and/or large
values. Every N complete values defines a row, where N is equal to the number
of entries in metadata.row_type.fields. Most values are encoded based on type
as described here. It's possible that the last value in values is "chunked",
meaning that the rest of the value is sent in subsequent PartialResultSet(s).
This is denoted by the chunked_value field. Two or more chunked values can be
merged to form a complete value as follows: * bool/number/null: can't be
chunked * string: concatenate the strings * list: concatenate the lists.
If the last element in a list is a string, list, or object, merge it
with the first element in the next list by applying these rules recursively. *
object: concatenate the (field name, field value) pairs. If a field name is
duplicated, then apply these rules recursively to merge the field values. Some
examples of merging: Strings are concatenated. "foo", "bar" => "foobar" Lists
of non-strings are concatenated. [2, 3], [4] => [2, 3, 4] Lists are
concatenated, but the last and first elements are merged because they are
strings. ["a", "b"], ["c", "d"] => ["a", "bc", "d"] Lists are concatenated,
but the last and first elements are merged because they are lists. Recursively,
the last and first elements of the inner lists are merged because they are
strings. ["a", ["b", "c"]], [["d"], "e"] => ["a", ["b", "cd"], "e"] Non-
overlapping object fields are combined. "a": "1", "b": "2" => "a": "1", "
b": 2" Overlapping object fields are merged. "a": "1", "a": "2" => "a": "
12" Examples of merging objects containing lists of strings. "a": ["1"], "
a": ["2"] => "a": ["12"] For a more complete example, suppose a streaming
SQL query is yielding a result set whose rows contain a single string field.
The following PartialResultSets might be yielded: "metadata": ... "
values": ["Hello", "W"] "chunked_value": true "resume_token": "Af65..." "
values": ["orl"] "chunked_value": true "values": ["d"] "resume_token": "
Zx1B..." This sequence of PartialResultSets encodes two rows, one
containing the field value "Hello", and a second containing the field value
"World" = "W" + "orl" + "d". Not all PartialResultSets contain a
resume_token. Execution can only be resumed from a previously yielded
resume_token. For the above sequence of PartialResultSets, resuming the
query with "resume_token": "Af65..." yields results from the
PartialResultSet with value "orl".
Corresponds to the JSON property values
5036 5037 5038 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5036 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5043 5044 5045 5046 5047 5048 5049 5050 5051 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5043 def update!(**args) @chunked_value = args[:chunked_value] if args.key?(:chunked_value) @last = args[:last] if args.key?(:last) @metadata = args[:metadata] if args.key?(:metadata) @precommit_token = args[:precommit_token] if args.key?(:precommit_token) @resume_token = args[:resume_token] if args.key?(:resume_token) @stats = args[:stats] if args.key?(:stats) @values = args[:values] if args.key?(:values) end |