Class: Google::Apis::SpannerV1::PartitionEndRecord
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::PartitionEndRecord
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A partition end record serves as a notification that the client should stop reading the partition. No further records are expected to be retrieved on it.
Instance Attribute Summary collapse
-
#end_timestamp ⇒ String
End timestamp at which the change stream partition is terminated.
-
#partition_token ⇒ String
Unique partition identifier describing the terminated change stream partition.
-
#record_sequence ⇒ String
Record sequence numbers are unique and monotonically increasing (but not necessarily contiguous) for a specific timestamp across record types in the same partition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartitionEndRecord
constructor
A new instance of PartitionEndRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartitionEndRecord
Returns a new instance of PartitionEndRecord.
5015 5016 5017 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_timestamp ⇒ String
End timestamp at which the change stream partition is terminated. All changes
generated by this partition will have timestamps <= end_timestamp.
DataChangeRecord.commit_timestamps, PartitionStartRecord.start_timestamps,
PartitionEventRecord.commit_timestamps, and PartitionEndRecord.end_timestamps
can have the same value in the same partition. PartitionEndRecord is the last
record returned for a partition.
Corresponds to the JSON property endTimestamp
4997 4998 4999 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4997 def @end_timestamp end |
#partition_token ⇒ String
Unique partition identifier describing the terminated change stream partition.
partition_token is equal to the partition token of the change stream partition
currently queried to return this PartitionEndRecord.
Corresponds to the JSON property partitionToken
5004 5005 5006 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5004 def partition_token @partition_token end |
#record_sequence ⇒ String
Record sequence numbers are unique and monotonically increasing (but not
necessarily contiguous) for a specific timestamp across record types in the
same partition. To guarantee ordered processing, the reader should process
records (of potentially different types) in record_sequence order for a
specific timestamp in the same partition.
Corresponds to the JSON property recordSequence
5013 5014 5015 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5013 def record_sequence @record_sequence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5020 5021 5022 5023 5024 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5020 def update!(**args) @end_timestamp = args[:end_timestamp] if args.key?(:end_timestamp) @partition_token = args[:partition_token] if args.key?(:partition_token) @record_sequence = args[:record_sequence] if args.key?(:record_sequence) end |