Class: Google::Apis::SpannerV1::PartitionQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for PartitionQuery

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartitionQueryRequest

Returns a new instance of PartitionQueryRequest.



5305
5306
5307
# File 'lib/google/apis/spanner_v1/classes.rb', line 5305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#param_typesHash<String,Google::Apis::SpannerV1::Type>

Optional. It isn't always possible for Cloud Spanner to infer the right SQL type from a JSON value. For example, values of type BYTES and values of type STRING both appear in params as JSON strings. In these cases, param_types can be used to specify the exact SQL type for some or all of the SQL query parameters. See the definition of Type for more information about SQL types. Corresponds to the JSON property paramTypes

Returns:



5268
5269
5270
# File 'lib/google/apis/spanner_v1/classes.rb', line 5268

def param_types
  @param_types
end

#paramsHash<String,Object>

Optional. Parameter names and values that bind to placeholders in the SQL string. A parameter placeholder consists of the @ character followed by the parameter name (for example, @firstName). Parameter names can contain letters, numbers, and underscores. Parameters can appear anywhere that a literal value is expected. The same parameter name can be used more than once, for example: "WHERE id > @msg_id AND id < @msg_id + 100" It's an error to execute a SQL statement with unbound parameters. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


5279
5280
5281
# File 'lib/google/apis/spanner_v1/classes.rb', line 5279

def params
  @params
end

#partition_optionsGoogle::Apis::SpannerV1::PartitionOptions

Options for a PartitionQueryRequest and PartitionReadRequest. Corresponds to the JSON property partitionOptions



5284
5285
5286
# File 'lib/google/apis/spanner_v1/classes.rb', line 5284

def partition_options
  @partition_options
end

#sqlString

Required. The query request to generate partitions for. The request fails if the query isn't root partitionable. For a query to be root partitionable, it needs to satisfy a few conditions. For example, if the query execution plan contains a distributed union operator, then it must be the first operator in the plan. For more information about other conditions, see Read data in parallel. The query request must not contain DML commands, such as INSERT, UPDATE, or DELETE. Use ExecuteStreamingSql with a PartitionedDml transaction for large, partition-friendly DML operations. Corresponds to the JSON property sql

Returns:

  • (String)


5297
5298
5299
# File 'lib/google/apis/spanner_v1/classes.rb', line 5297

def sql
  @sql
end

#transactionGoogle::Apis::SpannerV1::TransactionSelector

This message is used to select the transaction in which a Read or ExecuteSql call runs. See TransactionOptions for more information about transactions. Corresponds to the JSON property transaction



5303
5304
5305
# File 'lib/google/apis/spanner_v1/classes.rb', line 5303

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5310
5311
5312
5313
5314
5315
5316
# File 'lib/google/apis/spanner_v1/classes.rb', line 5310

def update!(**args)
  @param_types = args[:param_types] if args.key?(:param_types)
  @params = args[:params] if args.key?(:params)
  @partition_options = args[:partition_options] if args.key?(:partition_options)
  @sql = args[:sql] if args.key?(:sql)
  @transaction = args[:transaction] if args.key?(:transaction)
end