Class: Google::Apis::SpannerV1::PartitionReadRequest
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::PartitionReadRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The request for PartitionRead
Instance Attribute Summary collapse
-
#columns ⇒ Array<String>
The columns of table to be returned for each row matching this request.
-
#index ⇒ String
If non-empty, the name of an index on table.
-
#key_set ⇒ Google::Apis::SpannerV1::KeySet
KeySetdefines a collection of Cloud Spanner keys and/or key ranges. -
#partition_options ⇒ Google::Apis::SpannerV1::PartitionOptions
Options for a
PartitionQueryRequestandPartitionReadRequest. -
#table ⇒ String
Required.
-
#transaction ⇒ Google::Apis::SpannerV1::TransactionSelector
This message is used to select the transaction in which a Read or ExecuteSql call runs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartitionReadRequest
constructor
A new instance of PartitionReadRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartitionReadRequest
Returns a new instance of PartitionReadRequest.
5360 5361 5362 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5360 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<String>
The columns of table to be returned for each row matching this request.
Corresponds to the JSON property columns
5326 5327 5328 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5326 def columns @columns end |
#index ⇒ String
If non-empty, the name of an index on table. This index is used instead of the
table primary key when interpreting key_set and sorting result rows. See
key_set for further information.
Corresponds to the JSON property index
5333 5334 5335 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5333 def index @index end |
#key_set ⇒ Google::Apis::SpannerV1::KeySet
KeySet defines a collection of Cloud Spanner keys and/or key ranges. All the
keys are expected to be in the same table or index. The keys need not be
sorted in any particular way. If the same key is specified multiple times in
the set (for example if two ranges, two keys, or a key and a range overlap),
Cloud Spanner behaves as if the key were only specified once.
Corresponds to the JSON property keySet
5342 5343 5344 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5342 def key_set @key_set end |
#partition_options ⇒ Google::Apis::SpannerV1::PartitionOptions
Options for a PartitionQueryRequest and PartitionReadRequest.
Corresponds to the JSON property partitionOptions
5347 5348 5349 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5347 def @partition_options end |
#table ⇒ String
Required. The name of the table in the database to be read.
Corresponds to the JSON property table
5352 5353 5354 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5352 def table @table end |
#transaction ⇒ Google::Apis::SpannerV1::TransactionSelector
This message is used to select the transaction in which a Read or ExecuteSql
call runs. See TransactionOptions for more information about transactions.
Corresponds to the JSON property transaction
5358 5359 5360 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5358 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5365 5366 5367 5368 5369 5370 5371 5372 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5365 def update!(**args) @columns = args[:columns] if args.key?(:columns) @index = args[:index] if args.key?(:index) @key_set = args[:key_set] if args.key?(:key_set) @partition_options = args[:partition_options] if args.key?(:partition_options) @table = args[:table] if args.key?(:table) @transaction = args[:transaction] if args.key?(:transaction) end |