Class: Google::Apis::SpannerV1::PartitionStartRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A partition start record serves as a notification that the client should schedule the partitions to be queried. PartitionStartRecord returns information about one or more partitions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartitionStartRecord

Returns a new instance of PartitionStartRecord.



5320
5321
5322
# File 'lib/google/apis/spanner_v1/classes.rb', line 5320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partition_tokensArray<String>

Unique partition identifiers to be used in queries. Corresponds to the JSON property partitionTokens

Returns:

  • (Array<String>)


5300
5301
5302
# File 'lib/google/apis/spanner_v1/classes.rb', line 5300

def partition_tokens
  @partition_tokens
end

#record_sequenceString

Record sequence numbers are unique and monotonically increasing (but not necessarily contiguous) for a specific timestamp across record types in the same partition. To guarantee ordered processing, the reader should process records (of potentially different types) in record_sequence order for a specific timestamp in the same partition. Corresponds to the JSON property recordSequence

Returns:

  • (String)


5309
5310
5311
# File 'lib/google/apis/spanner_v1/classes.rb', line 5309

def record_sequence
  @record_sequence
end

#start_timestampString

Start timestamp at which the partitions should be queried to return change stream records with timestamps >= start_timestamp. DataChangeRecord. commit_timestamps, PartitionStartRecord.start_timestamps, PartitionEventRecord. commit_timestamps, and PartitionEndRecord.end_timestamps can have the same value in the same partition. Corresponds to the JSON property startTimestamp

Returns:

  • (String)


5318
5319
5320
# File 'lib/google/apis/spanner_v1/classes.rb', line 5318

def start_timestamp
  @start_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5325
5326
5327
5328
5329
# File 'lib/google/apis/spanner_v1/classes.rb', line 5325

def update!(**args)
  @partition_tokens = args[:partition_tokens] if args.key?(:partition_tokens)
  @record_sequence = args[:record_sequence] if args.key?(:record_sequence)
  @start_timestamp = args[:start_timestamp] if args.key?(:start_timestamp)
end