Class: Google::Apis::SpannerV1::PrefixNode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A message representing a key prefix node in the key prefix hierarchy. for eg. Bigtable keyspaces are lexicographically ordered mappings of keys to values. Keys often have a shared prefix structure where users use the keys to organize data. Eg ///employee In this case Keysight will possibly use one node for a company and reuse it for all employees that fall under the company. Doing so improves legibility in the UI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrefixNode

Returns a new instance of PrefixNode.



5642
5643
5644
# File 'lib/google/apis/spanner_v1/classes.rb', line 5642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_nodeBoolean Also known as: data_source_node?

Whether this corresponds to a data_source name. Corresponds to the JSON property dataSourceNode

Returns:

  • (Boolean)


5619
5620
5621
# File 'lib/google/apis/spanner_v1/classes.rb', line 5619

def data_source_node
  @data_source_node
end

#depthFixnum

The depth in the prefix hierarchy. Corresponds to the JSON property depth

Returns:

  • (Fixnum)


5625
5626
5627
# File 'lib/google/apis/spanner_v1/classes.rb', line 5625

def depth
  @depth
end

#end_indexFixnum

The index of the end key bucket of the range that this node spans. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


5630
5631
5632
# File 'lib/google/apis/spanner_v1/classes.rb', line 5630

def end_index
  @end_index
end

#start_indexFixnum

The index of the start key bucket of the range that this node spans. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


5635
5636
5637
# File 'lib/google/apis/spanner_v1/classes.rb', line 5635

def start_index
  @start_index
end

#wordString

The string represented by the prefix node. Corresponds to the JSON property word

Returns:

  • (String)


5640
5641
5642
# File 'lib/google/apis/spanner_v1/classes.rb', line 5640

def word
  @word
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5647
5648
5649
5650
5651
5652
5653
# File 'lib/google/apis/spanner_v1/classes.rb', line 5647

def update!(**args)
  @data_source_node = args[:data_source_node] if args.key?(:data_source_node)
  @depth = args[:depth] if args.key?(:depth)
  @end_index = args[:end_index] if args.key?(:end_index)
  @start_index = args[:start_index] if args.key?(:start_index)
  @word = args[:word] if args.key?(:word)
end