Class: Google::Apis::SpannerV1::QueryAdvisorResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Output of query advisor analysis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryAdvisorResult

Returns a new instance of QueryAdvisorResult.



5643
5644
5645
# File 'lib/google/apis/spanner_v1/classes.rb', line 5643

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#index_adviceArray<Google::Apis::SpannerV1::IndexAdvice>

Optional. Index Recommendation for a query. This is an optional field and the recommendation will only be available when the recommendation guarantees significant improvement in query performance. Corresponds to the JSON property indexAdvice



5641
5642
5643
# File 'lib/google/apis/spanner_v1/classes.rb', line 5641

def index_advice
  @index_advice
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5648
5649
5650
# File 'lib/google/apis/spanner_v1/classes.rb', line 5648

def update!(**args)
  @index_advice = args[:index_advice] if args.key?(:index_advice)
end