Class: Google::Apis::SpannerV1::ReadOnly

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Message type to initiate a read-only transaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReadOnly

Returns a new instance of ReadOnly.



5860
5861
5862
# File 'lib/google/apis/spanner_v1/classes.rb', line 5860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_stalenessString

Executes all reads at a timestamp that is exact_staleness old. The timestamp is chosen soon after the read is started. Guarantees that all writes that have committed more than the specified number of seconds ago are visible. Because Cloud Spanner chooses the exact timestamp, this mode works even if the client' s local clock is substantially skewed from Cloud Spanner commit timestamps. Useful for reading at nearby replicas without the distributed timestamp negotiation overhead of max_staleness. Corresponds to the JSON property exactStaleness

Returns:

  • (String)


5813
5814
5815
# File 'lib/google/apis/spanner_v1/classes.rb', line 5813

def exact_staleness
  @exact_staleness
end

#max_stalenessString

Read data at a timestamp >= NOW - max_staleness seconds. Guarantees that all writes that have committed more than the specified number of seconds ago are visible. Because Cloud Spanner chooses the exact timestamp, this mode works even if the client's local clock is substantially skewed from Cloud Spanner commit timestamps. Useful for reading the freshest data available at a nearby replica, while bounding the possible staleness if the local replica has fallen behind. Note that this option can only be used in single-use transactions. Corresponds to the JSON property maxStaleness

Returns:

  • (String)


5824
5825
5826
# File 'lib/google/apis/spanner_v1/classes.rb', line 5824

def max_staleness
  @max_staleness
end

#min_read_timestampString

Executes all reads at a timestamp >= min_read_timestamp. This is useful for requesting fresher data than some previous read, or data that is fresh enough to observe the effects of some previously committed transaction whose timestamp is known. Note that this option can only be used in single-use transactions. A timestamp in RFC3339 UTC \"Zulu\" format, accurate to nanoseconds. Example: "2014-10-02T15:01:23.045123456Z". Corresponds to the JSON property minReadTimestamp

Returns:

  • (String)


5834
5835
5836
# File 'lib/google/apis/spanner_v1/classes.rb', line 5834

def min_read_timestamp
  @min_read_timestamp
end

#read_timestampString

Executes all reads at the given timestamp. Unlike other modes, reads at a specific timestamp are repeatable; the same read at the same timestamp always returns the same data. If the timestamp is in the future, the read is blocked until the specified timestamp, modulo the read's deadline. Useful for large scale consistent reads such as mapreduces, or for coordinating many reads against a consistent snapshot of the data. A timestamp in RFC3339 UTC \"Zulu\" format, accurate to nanoseconds. Example: "2014-10-02T15:01:23.045123456Z". Corresponds to the JSON property readTimestamp

Returns:

  • (String)


5845
5846
5847
# File 'lib/google/apis/spanner_v1/classes.rb', line 5845

def read_timestamp
  @read_timestamp
end

#return_read_timestampBoolean Also known as: return_read_timestamp?

If true, the Cloud Spanner-selected read timestamp is included in the Transaction message that describes the transaction. Corresponds to the JSON property returnReadTimestamp

Returns:

  • (Boolean)


5851
5852
5853
# File 'lib/google/apis/spanner_v1/classes.rb', line 5851

def return_read_timestamp
  @return_read_timestamp
end

#strongBoolean Also known as: strong?

Read at a timestamp where all previously committed transactions are visible. Corresponds to the JSON property strong

Returns:

  • (Boolean)


5857
5858
5859
# File 'lib/google/apis/spanner_v1/classes.rb', line 5857

def strong
  @strong
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5865
5866
5867
5868
5869
5870
5871
5872
# File 'lib/google/apis/spanner_v1/classes.rb', line 5865

def update!(**args)
  @exact_staleness = args[:exact_staleness] if args.key?(:exact_staleness)
  @max_staleness = args[:max_staleness] if args.key?(:max_staleness)
  @min_read_timestamp = args[:min_read_timestamp] if args.key?(:min_read_timestamp)
  @read_timestamp = args[:read_timestamp] if args.key?(:read_timestamp)
  @return_read_timestamp = args[:return_read_timestamp] if args.key?(:return_read_timestamp)
  @strong = args[:strong] if args.key?(:strong)
end