Class: Google::Apis::SpannerV1::ReadWrite

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Message type to initiate a read-write transaction. Currently this transaction type has no options.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReadWrite

Returns a new instance of ReadWrite.



5924
5925
5926
# File 'lib/google/apis/spanner_v1/classes.rb', line 5924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#multiplexed_session_previous_transaction_idString

Optional. Clients should pass the transaction ID of the previous transaction attempt that was aborted if this transaction is being executed on a multiplexed session. Corresponds to the JSON property multiplexedSessionPreviousTransactionId NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5917
5918
5919
# File 'lib/google/apis/spanner_v1/classes.rb', line 5917

def multiplexed_session_previous_transaction_id
  @multiplexed_session_previous_transaction_id
end

#read_lock_modeString

Read lock mode for the transaction. Corresponds to the JSON property readLockMode

Returns:

  • (String)


5922
5923
5924
# File 'lib/google/apis/spanner_v1/classes.rb', line 5922

def read_lock_mode
  @read_lock_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5929
5930
5931
5932
# File 'lib/google/apis/spanner_v1/classes.rb', line 5929

def update!(**args)
  @multiplexed_session_previous_transaction_id = args[:multiplexed_session_previous_transaction_id] if args.key?(:multiplexed_session_previous_transaction_id)
  @read_lock_mode = args[:read_lock_mode] if args.key?(:read_lock_mode)
end