Class: Google::Apis::SpannerV1::RequestOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Common request options for various APIs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RequestOptions

Returns a new instance of RequestOptions.



6161
6162
6163
# File 'lib/google/apis/spanner_v1/classes.rb', line 6161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_contextGoogle::Apis::SpannerV1::ClientContext

Container for various pieces of client-owned context attached to a request. Corresponds to the JSON property clientContext



6128
6129
6130
# File 'lib/google/apis/spanner_v1/classes.rb', line 6128

def client_context
  @client_context
end

#priorityString

Priority for the request. Corresponds to the JSON property priority

Returns:

  • (String)


6133
6134
6135
# File 'lib/google/apis/spanner_v1/classes.rb', line 6133

def priority
  @priority
end

#request_tagString

A per-request tag which can be applied to queries or reads, used for statistics collection. Both request_tag and transaction_tag can be specified for a read or query that belongs to a transaction. This field is ignored for requests where it's not applicable (for example, CommitRequest). Legal characters for request_tag values are all printable characters (ASCII 32 - 126) and the length of a request_tag is limited to 50 characters. Values that exceed this limit are truncated. Any leading underscore (_) characters are removed from the string. Corresponds to the JSON property requestTag

Returns:

  • (String)


6145
6146
6147
# File 'lib/google/apis/spanner_v1/classes.rb', line 6145

def request_tag
  @request_tag
end

#transaction_tagString

A tag used for statistics collection about this transaction. Both request_tag and transaction_tag can be specified for a read or query that belongs to a transaction. To enable tagging on a transaction, transaction_tag must be set to the same value for all requests belonging to the same transaction, including BeginTransaction. If this request doesn't belong to any transaction, transaction_tag is ignored. Legal characters for transaction_tag values are all printable characters (ASCII 32 - 126) and the length of a transaction_tag is limited to 50 characters. Values that exceed this limit are truncated. Any leading underscore (_) characters are removed from the string. Corresponds to the JSON property transactionTag

Returns:

  • (String)


6159
6160
6161
# File 'lib/google/apis/spanner_v1/classes.rb', line 6159

def transaction_tag
  @transaction_tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6166
6167
6168
6169
6170
6171
# File 'lib/google/apis/spanner_v1/classes.rb', line 6166

def update!(**args)
  @client_context = args[:client_context] if args.key?(:client_context)
  @priority = args[:priority] if args.key?(:priority)
  @request_tag = args[:request_tag] if args.key?(:request_tag)
  @transaction_tag = args[:transaction_tag] if args.key?(:transaction_tag)
end