Class: Google::Apis::SpannerV1::RestoreDatabaseRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for RestoreDatabase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreDatabaseRequest

Returns a new instance of RestoreDatabaseRequest.



6218
6219
6220
# File 'lib/google/apis/spanner_v1/classes.rb', line 6218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

Name of the backup from which to restore. Values are of the form projects// instances//backups/. Corresponds to the JSON property backup

Returns:

  • (String)


6204
6205
6206
# File 'lib/google/apis/spanner_v1/classes.rb', line 6204

def backup
  @backup
end

#database_idString

Required. The id of the database to create and restore to. This database must not already exist. The database_id appended to parent forms the full database name of the form projects//instances//databases/. Corresponds to the JSON property databaseId

Returns:

  • (String)


6211
6212
6213
# File 'lib/google/apis/spanner_v1/classes.rb', line 6211

def database_id
  @database_id
end

#encryption_configGoogle::Apis::SpannerV1::RestoreDatabaseEncryptionConfig

Encryption configuration for the restored database. Corresponds to the JSON property encryptionConfig



6216
6217
6218
# File 'lib/google/apis/spanner_v1/classes.rb', line 6216

def encryption_config
  @encryption_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6223
6224
6225
6226
6227
# File 'lib/google/apis/spanner_v1/classes.rb', line 6223

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @database_id = args[:database_id] if args.key?(:database_id)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
end