Class: Google::Apis::SpannerV1::ScanData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

ScanData contains Cloud Key Visualizer scan data used by the caller to construct a visualization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScanData

Returns a new instance of ScanData.



6573
6574
6575
# File 'lib/google/apis/spanner_v1/classes.rb', line 6573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataGoogle::Apis::SpannerV1::VisualizationData

Cloud Key Visualizer scan data. The range of time this information covers is captured via the above time range fields. Note, this field is not available to the ListScans method. Corresponds to the JSON property data



6560
6561
6562
# File 'lib/google/apis/spanner_v1/classes.rb', line 6560

def data
  @data
end

#end_timeString

The upper bound for when the contained data is defined. Corresponds to the JSON property endTime

Returns:

  • (String)


6565
6566
6567
# File 'lib/google/apis/spanner_v1/classes.rb', line 6565

def end_time
  @end_time
end

#start_timeString

A range of time (inclusive) for when the contained data is defined. The lower bound for when the contained data is defined. Corresponds to the JSON property startTime

Returns:

  • (String)


6571
6572
6573
# File 'lib/google/apis/spanner_v1/classes.rb', line 6571

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6578
6579
6580
6581
6582
# File 'lib/google/apis/spanner_v1/classes.rb', line 6578

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end