Class: Google::Apis::SpannerV1::SplitPoints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The split points of a table or an index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SplitPoints

Returns a new instance of SplitPoints.



6809
6810
6811
# File 'lib/google/apis/spanner_v1/classes.rb', line 6809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

Optional. The expiration timestamp of the split points. A timestamp in the past means immediate expiration. The maximum value can be 30 days in the future. Defaults to 10 days in the future if not specified. Corresponds to the JSON property expireTime

Returns:

  • (String)


6791
6792
6793
# File 'lib/google/apis/spanner_v1/classes.rb', line 6791

def expire_time
  @expire_time
end

#indexString

The index to split. If specified, the table field must refer to the index's base table. Corresponds to the JSON property index

Returns:

  • (String)


6797
6798
6799
# File 'lib/google/apis/spanner_v1/classes.rb', line 6797

def index
  @index
end

#keysArray<Google::Apis::SpannerV1::Key>

Required. The list of split keys. In essence, the split boundaries. Corresponds to the JSON property keys

Returns:



6802
6803
6804
# File 'lib/google/apis/spanner_v1/classes.rb', line 6802

def keys
  @keys
end

#tableString

The table to split. Corresponds to the JSON property table

Returns:

  • (String)


6807
6808
6809
# File 'lib/google/apis/spanner_v1/classes.rb', line 6807

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6814
6815
6816
6817
6818
6819
# File 'lib/google/apis/spanner_v1/classes.rb', line 6814

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @index = args[:index] if args.key?(:index)
  @keys = args[:keys] if args.key?(:keys)
  @table = args[:table] if args.key?(:table)
end