Class: Google::Apis::SpannerV1::StructType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

StructType defines the fields of a STRUCT type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StructType

Returns a new instance of StructType.



6898
6899
6900
# File 'lib/google/apis/spanner_v1/classes.rb', line 6898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::SpannerV1::Field>

The list of fields that make up this struct. Order is significant, because values of this struct type are represented as lists, where the order of field values matches the order of fields in the StructType. In turn, the order of fields matches the order of columns in a read request, or the order of fields in the SELECT clause of a query. Corresponds to the JSON property fields

Returns:



6896
6897
6898
# File 'lib/google/apis/spanner_v1/classes.rb', line 6896

def fields
  @fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6903
6904
6905
# File 'lib/google/apis/spanner_v1/classes.rb', line 6903

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
end