Class: Google::Apis::SpannerV1::UpdateDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the operation returned by UpdateDatabase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateDatabaseMetadata

Returns a new instance of UpdateDatabaseMetadata.



7168
7169
7170
# File 'lib/google/apis/spanner_v1/classes.rb', line 7168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancel_timeString

The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is best-effort). Corresponds to the JSON property cancelTime

Returns:

  • (String)


7155
7156
7157
# File 'lib/google/apis/spanner_v1/classes.rb', line 7155

def cancel_time
  @cancel_time
end

#progressGoogle::Apis::SpannerV1::OperationProgress

Encapsulates progress related information for a Cloud Spanner long running operation. Corresponds to the JSON property progress



7161
7162
7163
# File 'lib/google/apis/spanner_v1/classes.rb', line 7161

def progress
  @progress
end

#requestGoogle::Apis::SpannerV1::UpdateDatabaseRequest

The request for UpdateDatabase. Corresponds to the JSON property request



7166
7167
7168
# File 'lib/google/apis/spanner_v1/classes.rb', line 7166

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7173
7174
7175
7176
7177
# File 'lib/google/apis/spanner_v1/classes.rb', line 7173

def update!(**args)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @progress = args[:progress] if args.key?(:progress)
  @request = args[:request] if args.key?(:request)
end