Class: Google::Apis::SpannerV1::UpdateInstanceConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for UpdateInstanceConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateInstanceConfigRequest

Returns a new instance of UpdateInstanceConfigRequest.



7356
7357
7358
# File 'lib/google/apis/spanner_v1/classes.rb', line 7356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_configGoogle::Apis::SpannerV1::InstanceConfig

A possible configuration for a Cloud Spanner instance. Configurations define the geographic placement of nodes and their replication. Corresponds to the JSON property instanceConfig



7339
7340
7341
# File 'lib/google/apis/spanner_v1/classes.rb', line 7339

def instance_config
  @instance_config
end

#update_maskString

Required. A mask specifying which fields in InstanceConfig should be updated. The field mask must always be specified; this prevents any future fields in InstanceConfig from being erased accidentally by clients that do not know about them. Only display_name and labels can be updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


7347
7348
7349
# File 'lib/google/apis/spanner_v1/classes.rb', line 7347

def update_mask
  @update_mask
end

#validate_onlyBoolean Also known as: validate_only?

An option to validate, but not actually execute, a request, and provide the same response. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


7353
7354
7355
# File 'lib/google/apis/spanner_v1/classes.rb', line 7353

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7361
7362
7363
7364
7365
# File 'lib/google/apis/spanner_v1/classes.rb', line 7361

def update!(**args)
  @instance_config = args[:instance_config] if args.key?(:instance_config)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end