Class: Google::Apis::SpannerV1::UpdateInstanceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the operation returned by UpdateInstance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateInstanceMetadata

Returns a new instance of UpdateInstanceMetadata.



7423
7424
7425
# File 'lib/google/apis/spanner_v1/classes.rb', line 7423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancel_timeString

The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again. Corresponds to the JSON property cancelTime

Returns:

  • (String)


7401
7402
7403
# File 'lib/google/apis/spanner_v1/classes.rb', line 7401

def cancel_time
  @cancel_time
end

#end_timeString

The time at which this operation failed or was completed successfully. Corresponds to the JSON property endTime

Returns:

  • (String)


7406
7407
7408
# File 'lib/google/apis/spanner_v1/classes.rb', line 7406

def end_time
  @end_time
end

#expected_fulfillment_periodString

The expected fulfillment period of this update operation. Corresponds to the JSON property expectedFulfillmentPeriod

Returns:

  • (String)


7411
7412
7413
# File 'lib/google/apis/spanner_v1/classes.rb', line 7411

def expected_fulfillment_period
  @expected_fulfillment_period
end

#instanceGoogle::Apis::SpannerV1::Instance

An isolated set of Cloud Spanner resources on which databases can be hosted. Corresponds to the JSON property instance



7416
7417
7418
# File 'lib/google/apis/spanner_v1/classes.rb', line 7416

def instance
  @instance
end

#start_timeString

The time at which UpdateInstance request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


7421
7422
7423
# File 'lib/google/apis/spanner_v1/classes.rb', line 7421

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7428
7429
7430
7431
7432
7433
7434
# File 'lib/google/apis/spanner_v1/classes.rb', line 7428

def update!(**args)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @expected_fulfillment_period = args[:expected_fulfillment_period] if args.key?(:expected_fulfillment_period)
  @instance = args[:instance] if args.key?(:instance)
  @start_time = args[:start_time] if args.key?(:start_time)
end