Class: Google::Apis::SpannerV1::UpdateInstancePartitionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for UpdateInstancePartition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateInstancePartitionRequest

Returns a new instance of UpdateInstancePartitionRequest.



7471
7472
7473
# File 'lib/google/apis/spanner_v1/classes.rb', line 7471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_maskString

Required. A mask specifying which fields in InstancePartition should be updated. The field mask must always be specified; this prevents any future fields in InstancePartition from being erased accidentally by clients that do not know about them. Corresponds to the JSON property fieldMask

Returns:

  • (String)


7463
7464
7465
# File 'lib/google/apis/spanner_v1/classes.rb', line 7463

def field_mask
  @field_mask
end

#instance_partitionGoogle::Apis::SpannerV1::InstancePartition

An isolated set of Cloud Spanner resources that databases can define placements on. Corresponds to the JSON property instancePartition



7469
7470
7471
# File 'lib/google/apis/spanner_v1/classes.rb', line 7469

def instance_partition
  @instance_partition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7476
7477
7478
7479
# File 'lib/google/apis/spanner_v1/classes.rb', line 7476

def update!(**args)
  @field_mask = args[:field_mask] if args.key?(:field_mask)
  @instance_partition = args[:instance_partition] if args.key?(:instance_partition)
end