Class: Google::Apis::SpannerV1::VisualizationData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VisualizationData

Returns a new instance of VisualizationData.



7592
7593
7594
# File 'lib/google/apis/spanner_v1/classes.rb', line 7592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_source_end_tokenString

The token signifying the end of a data_source. Corresponds to the JSON property dataSourceEndToken

Returns:

  • (String)


7540
7541
7542
# File 'lib/google/apis/spanner_v1/classes.rb', line 7540

def data_source_end_token
  @data_source_end_token
end

#data_source_separator_tokenString

The token delimiting a datasource name from the rest of a key in a data_source. Corresponds to the JSON property dataSourceSeparatorToken

Returns:

  • (String)


7545
7546
7547
# File 'lib/google/apis/spanner_v1/classes.rb', line 7545

def data_source_separator_token
  @data_source_separator_token
end

#diagnostic_messagesArray<Google::Apis::SpannerV1::DiagnosticMessage>

The list of messages (info, alerts, ...) Corresponds to the JSON property diagnosticMessages



7550
7551
7552
# File 'lib/google/apis/spanner_v1/classes.rb', line 7550

def diagnostic_messages
  @diagnostic_messages
end

#end_key_stringsArray<String>

We discretize the entire keyspace into buckets. Assuming each bucket has an inclusive keyrange and covers keys from k(i) ... k(n). In this case k(n) would be an end key for a given range. end_key_string is the collection of all such end keys Corresponds to the JSON property endKeyStrings

Returns:

  • (Array<String>)


7558
7559
7560
# File 'lib/google/apis/spanner_v1/classes.rb', line 7558

def end_key_strings
  @end_key_strings
end

#has_piiBoolean Also known as: has_pii?

Whether this scan contains PII. Corresponds to the JSON property hasPii

Returns:

  • (Boolean)


7563
7564
7565
# File 'lib/google/apis/spanner_v1/classes.rb', line 7563

def has_pii
  @has_pii
end

#indexed_keysArray<String>

Keys of key ranges that contribute significantly to a given metric Can be thought of as heavy hitters. Corresponds to the JSON property indexedKeys

Returns:

  • (Array<String>)


7570
7571
7572
# File 'lib/google/apis/spanner_v1/classes.rb', line 7570

def indexed_keys
  @indexed_keys
end

#key_separatorString

The token delimiting the key prefixes. Corresponds to the JSON property keySeparator

Returns:

  • (String)


7575
7576
7577
# File 'lib/google/apis/spanner_v1/classes.rb', line 7575

def key_separator
  @key_separator
end

#key_unitString

The unit for the key: e.g. 'key' or 'chunk'. Corresponds to the JSON property keyUnit

Returns:

  • (String)


7580
7581
7582
# File 'lib/google/apis/spanner_v1/classes.rb', line 7580

def key_unit
  @key_unit
end

#metricsArray<Google::Apis::SpannerV1::Metric>

The list of data objects for each metric. Corresponds to the JSON property metrics



7585
7586
7587
# File 'lib/google/apis/spanner_v1/classes.rb', line 7585

def metrics
  @metrics
end

#prefix_nodesArray<Google::Apis::SpannerV1::PrefixNode>

The list of extracted key prefix nodes used in the key prefix hierarchy. Corresponds to the JSON property prefixNodes



7590
7591
7592
# File 'lib/google/apis/spanner_v1/classes.rb', line 7590

def prefix_nodes
  @prefix_nodes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
# File 'lib/google/apis/spanner_v1/classes.rb', line 7597

def update!(**args)
  @data_source_end_token = args[:data_source_end_token] if args.key?(:data_source_end_token)
  @data_source_separator_token = args[:data_source_separator_token] if args.key?(:data_source_separator_token)
  @diagnostic_messages = args[:diagnostic_messages] if args.key?(:diagnostic_messages)
  @end_key_strings = args[:end_key_strings] if args.key?(:end_key_strings)
  @has_pii = args[:has_pii] if args.key?(:has_pii)
  @indexed_keys = args[:indexed_keys] if args.key?(:indexed_keys)
  @key_separator = args[:key_separator] if args.key?(:key_separator)
  @key_unit = args[:key_unit] if args.key?(:key_unit)
  @metrics = args[:metrics] if args.key?(:metrics)
  @prefix_nodes = args[:prefix_nodes] if args.key?(:prefix_nodes)
end