Class: Google::Apis::SpannerV1::AdaptMessageResponse
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::AdaptMessageResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Message sent by the adapter to the client.
Instance Attribute Summary collapse
-
#last ⇒ Boolean
(also: #last?)
Optional.
-
#payload ⇒ String
Optional.
-
#state_updates ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AdaptMessageResponse
constructor
A new instance of AdaptMessageResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AdaptMessageResponse
Returns a new instance of AdaptMessageResponse.
115 116 117 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last ⇒ Boolean Also known as: last?
Optional. Indicates whether this is the last AdaptMessageResponse in the
stream. This field may be optionally set by the server. Clients should not
rely on this field being set in all cases.
Corresponds to the JSON property last
101 102 103 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 101 def last @last end |
#payload ⇒ String
Optional. Uninterpreted bytes from the underlying wire protocol.
Corresponds to the JSON property payload
NOTE: Values are automatically base64 encoded/decoded in the client library.
108 109 110 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 108 def payload @payload end |
#state_updates ⇒ Hash<String,String>
Optional. Opaque state updates to be applied by the client.
Corresponds to the JSON property stateUpdates
113 114 115 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 113 def state_updates @state_updates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
120 121 122 123 124 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 120 def update!(**args) @last = args[:last] if args.key?(:last) @payload = args[:payload] if args.key?(:payload) @state_updates = args[:state_updates] if args.key?(:state_updates) end |