Class: Google::Apis::SpannerV1::AutoscalingConfigOverrides
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::AutoscalingConfigOverrides
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Overrides the top-level autoscaling configuration for the replicas identified
by replica_selection. All fields in this message are optional. Any
unspecified fields will use the corresponding values from the top-level
autoscaling configuration.
Instance Attribute Summary collapse
-
#autoscaling_limits ⇒ Google::Apis::SpannerV1::AutoscalingLimits
The autoscaling limits for the instance.
-
#autoscaling_target_high_priority_cpu_utilization_percent ⇒ Fixnum
Optional.
-
#autoscaling_target_total_cpu_utilization_percent ⇒ Fixnum
Optional.
-
#disable_high_priority_cpu_autoscaling ⇒ Boolean
(also: #disable_high_priority_cpu_autoscaling?)
Optional.
-
#disable_total_cpu_autoscaling ⇒ Boolean
(also: #disable_total_cpu_autoscaling?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalingConfigOverrides
constructor
A new instance of AutoscalingConfigOverrides.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalingConfigOverrides
Returns a new instance of AutoscalingConfigOverrides.
318 319 320 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 318 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_limits ⇒ Google::Apis::SpannerV1::AutoscalingLimits
The autoscaling limits for the instance. Users can define the minimum and
maximum compute capacity allocated to the instance, and the autoscaler will
only scale within that range. Users can either use nodes or processing units
to specify the limits, but should use the same unit to set both the min_limit
and max_limit.
Corresponds to the JSON property autoscalingLimits
271 272 273 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 271 def autoscaling_limits @autoscaling_limits end |
#autoscaling_target_high_priority_cpu_utilization_percent ⇒ Fixnum
Optional. If specified, overrides the autoscaling target
high_priority_cpu_utilization_percent in the top-level autoscaling
configuration for the selected replicas.
Corresponds to the JSON property autoscalingTargetHighPriorityCpuUtilizationPercent
278 279 280 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 278 def autoscaling_target_high_priority_cpu_utilization_percent @autoscaling_target_high_priority_cpu_utilization_percent end |
#autoscaling_target_total_cpu_utilization_percent ⇒ Fixnum
Optional. If specified, overrides the autoscaling target
total_cpu_utilization_percent in the top-level autoscaling configuration for
the selected replicas.
Corresponds to the JSON property autoscalingTargetTotalCpuUtilizationPercent
285 286 287 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 285 def autoscaling_target_total_cpu_utilization_percent @autoscaling_target_total_cpu_utilization_percent end |
#disable_high_priority_cpu_autoscaling ⇒ Boolean Also known as: disable_high_priority_cpu_autoscaling?
Optional. If true, disables high priority CPU autoscaling for the selected
replicas and ignores high_priority_cpu_utilization_percent in the top-level
autoscaling configuration. When setting this field to true, setting
autoscaling_target_high_priority_cpu_utilization_percent field to a non-zero
value for the same replica is not supported. If false, the
autoscaling_target_high_priority_cpu_utilization_percent field in the replica
will be used if set to a non-zero value. Otherwise, the
high_priority_cpu_utilization_percent field in the top-level autoscaling
configuration will be used. Setting both disable_high_priority_cpu_autoscaling
and disable_total_cpu_autoscaling to true for the same replica is not
supported.
Corresponds to the JSON property disableHighPriorityCpuAutoscaling
300 301 302 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 300 def disable_high_priority_cpu_autoscaling @disable_high_priority_cpu_autoscaling end |
#disable_total_cpu_autoscaling ⇒ Boolean Also known as: disable_total_cpu_autoscaling?
Optional. If true, disables total CPU autoscaling for the selected replicas
and ignores total_cpu_utilization_percent in the top-level autoscaling
configuration. When setting this field to true, setting
autoscaling_target_total_cpu_utilization_percent field to a non-zero value for
the same replica is not supported. If false, the
autoscaling_target_total_cpu_utilization_percent field in the replica will be
used if set to a non-zero value. Otherwise, the total_cpu_utilization_percent
field in the top-level autoscaling configuration will be used. Setting both
disable_high_priority_cpu_autoscaling and disable_total_cpu_autoscaling to
true for the same replica is not supported.
Corresponds to the JSON property disableTotalCpuAutoscaling
315 316 317 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 315 def disable_total_cpu_autoscaling @disable_total_cpu_autoscaling end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
323 324 325 326 327 328 329 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 323 def update!(**args) @autoscaling_limits = args[:autoscaling_limits] if args.key?(:autoscaling_limits) @autoscaling_target_high_priority_cpu_utilization_percent = args[:autoscaling_target_high_priority_cpu_utilization_percent] if args.key?(:autoscaling_target_high_priority_cpu_utilization_percent) @autoscaling_target_total_cpu_utilization_percent = args[:autoscaling_target_total_cpu_utilization_percent] if args.key?(:autoscaling_target_total_cpu_utilization_percent) @disable_high_priority_cpu_autoscaling = args[:disable_high_priority_cpu_autoscaling] if args.key?(:disable_high_priority_cpu_autoscaling) @disable_total_cpu_autoscaling = args[:disable_total_cpu_autoscaling] if args.key?(:disable_total_cpu_autoscaling) end |