Class: Google::Apis::SpannerV1::AutoscalingConfigOverrides

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Overrides the top-level autoscaling configuration for the replicas identified by replica_selection. All fields in this message are optional. Any unspecified fields will use the corresponding values from the top-level autoscaling configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalingConfigOverrides

Returns a new instance of AutoscalingConfigOverrides.



280
281
282
# File 'lib/google/apis/spanner_v1/classes.rb', line 280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_limitsGoogle::Apis::SpannerV1::AutoscalingLimits

The autoscaling limits for the instance. Users can define the minimum and maximum compute capacity allocated to the instance, and the autoscaler will only scale within that range. Users can either use nodes or processing units to specify the limits, but should use the same unit to set both the min_limit and max_limit. Corresponds to the JSON property autoscalingLimits



271
272
273
# File 'lib/google/apis/spanner_v1/classes.rb', line 271

def autoscaling_limits
  @autoscaling_limits
end

#autoscaling_target_high_priority_cpu_utilization_percentFixnum

Optional. If specified, overrides the autoscaling target high_priority_cpu_utilization_percent in the top-level autoscaling configuration for the selected replicas. Corresponds to the JSON property autoscalingTargetHighPriorityCpuUtilizationPercent

Returns:

  • (Fixnum)


278
279
280
# File 'lib/google/apis/spanner_v1/classes.rb', line 278

def autoscaling_target_high_priority_cpu_utilization_percent
  @autoscaling_target_high_priority_cpu_utilization_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



285
286
287
288
# File 'lib/google/apis/spanner_v1/classes.rb', line 285

def update!(**args)
  @autoscaling_limits = args[:autoscaling_limits] if args.key?(:autoscaling_limits)
  @autoscaling_target_high_priority_cpu_utilization_percent = args[:autoscaling_target_high_priority_cpu_utilization_percent] if args.key?(:autoscaling_target_high_priority_cpu_utilization_percent)
end