Class: Google::Apis::SpannerV1::Backup
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::Backup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A backup of a Cloud Spanner database.
Instance Attribute Summary collapse
-
#backup_schedules ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#database ⇒ String
Required for the CreateBackup operation.
-
#database_dialect ⇒ String
Output only.
-
#encryption_info ⇒ Google::Apis::SpannerV1::EncryptionInfo
Encryption information for a Cloud Spanner database or backup.
-
#encryption_information ⇒ Array<Google::Apis::SpannerV1::EncryptionInfo>
Output only.
-
#exclusive_size_bytes ⇒ Fixnum
Output only.
-
#expire_time ⇒ String
Required for the CreateBackup operation.
-
#freeable_size_bytes ⇒ Fixnum
Output only.
-
#incremental_backup_chain_id ⇒ String
Output only.
-
#instance_partitions ⇒ Array<Google::Apis::SpannerV1::BackupInstancePartition>
Output only.
-
#max_expire_time ⇒ String
Output only.
-
#minimum_restorable_edition ⇒ String
Output only.
-
#name ⇒ String
Output only for the CreateBackup operation.
-
#oldest_version_time ⇒ String
Output only.
-
#referencing_backups ⇒ Array<String>
Output only.
-
#referencing_databases ⇒ Array<String>
Output only.
-
#size_bytes ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
-
#version_time ⇒ String
The backup will contain an externally consistent copy of the database at the timestamp specified by
version_time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Backup
constructor
A new instance of Backup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Backup
Returns a new instance of Backup.
593 594 595 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 593 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_schedules ⇒ Array<String>
Output only. List of backup schedule URIs that are associated with creating
this backup. This is only applicable for scheduled backups, and is empty for
on-demand backups. To optimize for storage, whenever possible, multiple
schedules are collapsed together to create one backup. In such cases, this
field captures the list of all backup schedule URIs that are associated with
creating this backup. If collapsing is not done, then this field captures the
single backup schedule URI associated with creating this backup.
Corresponds to the JSON property backupSchedules
434 435 436 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 434 def backup_schedules @backup_schedules end |
#create_time ⇒ String
Output only. The time the CreateBackup request is received. If the request
does not specify version_time, the version_time of the backup will be
equivalent to the create_time.
Corresponds to the JSON property createTime
441 442 443 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 441 def create_time @create_time end |
#database ⇒ String
Required for the CreateBackup operation. Name of the database from which this
backup was created. This needs to be in the same instance as the backup.
Values are of the form projects/project/instances/instance/databases/
database`.
Corresponds to the JSON propertydatabase`
449 450 451 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 449 def database @database end |
#database_dialect ⇒ String
Output only. The database dialect information for the backup.
Corresponds to the JSON property databaseDialect
454 455 456 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 454 def database_dialect @database_dialect end |
#encryption_info ⇒ Google::Apis::SpannerV1::EncryptionInfo
Encryption information for a Cloud Spanner database or backup.
Corresponds to the JSON property encryptionInfo
459 460 461 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 459 def encryption_info @encryption_info end |
#encryption_information ⇒ Array<Google::Apis::SpannerV1::EncryptionInfo>
Output only. The encryption information for the backup, whether it is
protected by one or more KMS keys. The information includes all Cloud KMS key
versions used to encrypt the backup. The encryption_status field inside of
each EncryptionInfo is not populated. At least one of the key versions must
be available for the backup to be restored. If a key version is revoked in the
middle of a restore, the restore behavior is undefined.
Corresponds to the JSON property encryptionInformation
469 470 471 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 469 def encryption_information @encryption_information end |
#exclusive_size_bytes ⇒ Fixnum
Output only. For a backup in an incremental backup chain, this is the storage
space needed to keep the data that has changed since the previous backup. For
all other backups, this is always the size of the backup. This value may
change if backups on the same chain get deleted or expired. This field can be
used to calculate the total storage space used by a set of backups. For
example, the total space used by all backups of a database can be computed by
summing up this field.
Corresponds to the JSON property exclusiveSizeBytes
480 481 482 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 480 def exclusive_size_bytes @exclusive_size_bytes end |
#expire_time ⇒ String
Required for the CreateBackup operation. The expiration time of the backup,
with microseconds granularity that must be at least 6 hours and at most 366
days from the time the CreateBackup request is processed. Once the
expire_time has passed, the backup is eligible to be automatically deleted by
Cloud Spanner to free the resources used by the backup.
Corresponds to the JSON property expireTime
489 490 491 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 489 def expire_time @expire_time end |
#freeable_size_bytes ⇒ Fixnum
Output only. The number of bytes that will be freed by deleting this backup.
This value will be zero if, for example, this backup is part of an incremental
backup chain and younger backups in the chain require that we keep its data.
For backups not in an incremental backup chain, this is always the size of the
backup. This value may change if backups on the same chain get created,
deleted or expired.
Corresponds to the JSON property freeableSizeBytes
499 500 501 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 499 def freeable_size_bytes @freeable_size_bytes end |
#incremental_backup_chain_id ⇒ String
Output only. Populated only for backups in an incremental backup chain.
Backups share the same chain id if and only if they belong to the same
incremental backup chain. Use this field to determine which backups are part
of the same incremental backup chain. The ordering of backups in the chain can
be determined by ordering the backup version_time.
Corresponds to the JSON property incrementalBackupChainId
508 509 510 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 508 def incremental_backup_chain_id @incremental_backup_chain_id end |
#instance_partitions ⇒ Array<Google::Apis::SpannerV1::BackupInstancePartition>
Output only. The instance partition storing the backup. This is the same as
the list of the instance partitions that the database recorded at the backup's
version_time.
Corresponds to the JSON property instancePartitions
515 516 517 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 515 def instance_partitions @instance_partitions end |
#max_expire_time ⇒ String
Output only. The max allowed expiration time of the backup, with microseconds
granularity. A backup's expiration time can be configured in multiple APIs:
CreateBackup, UpdateBackup, CopyBackup. When updating or copying an existing
backup, the expiration time specified must be less than Backup.
max_expire_time.
Corresponds to the JSON property maxExpireTime
524 525 526 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 524 def max_expire_time @max_expire_time end |
#minimum_restorable_edition ⇒ String
Output only. The minimum edition required to successfully restore the backup.
Populated only if the edition is Enterprise or Enterprise Plus.
Corresponds to the JSON property minimumRestorableEdition
530 531 532 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 530 def minimum_restorable_edition @minimum_restorable_edition end |
#name ⇒ String
Output only for the CreateBackup operation. Required for the UpdateBackup
operation. A globally unique identifier for the backup which cannot be changed.
Values are of the form projects/project/instances/instance/backups/a-z*[
a-z0-9] The final segment of the name must be between 2 and 60 characters in
length. The backup is stored in the location(s) specified in the instance
configuration of the instance containing the backup, identified by the prefix
of the backup name of the form projects/project/instances/instance`.
Corresponds to the JSON propertyname`
541 542 543 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 541 def name @name end |
#oldest_version_time ⇒ String
Output only. Data deleted at a time older than this is guaranteed not to be
retained in order to support this backup. For a backup in an incremental
backup chain, this is the version time of the oldest backup that exists or
ever existed in the chain. For all other backups, this is the version time of
the backup. This field can be used to understand what data is being retained
by the backup system.
Corresponds to the JSON property oldestVersionTime
551 552 553 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 551 def oldest_version_time @oldest_version_time end |
#referencing_backups ⇒ Array<String>
Output only. The names of the destination backups being created by copying
this source backup. The backup names are of the form projects/project/
instances/instance/backups/backup`. Referencing backups may exist in
different instances. The existence of any referencing backup prevents the
backup from being deleted. When the copy operation is done (either
successfully completed or cancelled or the destination backup is deleted), the
reference to the backup is removed.
Corresponds to the JSON propertyreferencingBackups`
562 563 564 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 562 def referencing_backups @referencing_backups end |
#referencing_databases ⇒ Array<String>
Output only. The names of the restored databases that reference the backup.
The database names are of the form projects/project/instances/instance/
databases/database`. Referencing databases may exist in different instances.
The existence of any referencing database prevents the backup from being
deleted. When a restored database from the backup enters theREADYstate,
the reference to the backup is removed.
Corresponds to the JSON propertyreferencingDatabases`
572 573 574 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 572 def referencing_databases @referencing_databases end |
#size_bytes ⇒ Fixnum
Output only. Size of the backup in bytes. For a backup in an incremental
backup chain, this is the sum of the exclusive_size_bytes of itself and all
older backups in the chain.
Corresponds to the JSON property sizeBytes
579 580 581 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 579 def size_bytes @size_bytes end |
#state ⇒ String
Output only. The current state of the backup.
Corresponds to the JSON property state
584 585 586 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 584 def state @state end |
#version_time ⇒ String
The backup will contain an externally consistent copy of the database at the
timestamp specified by version_time. If version_time is not specified, the
system will set version_time to the create_time of the backup.
Corresponds to the JSON property versionTime
591 592 593 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 591 def version_time @version_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 598 def update!(**args) @backup_schedules = args[:backup_schedules] if args.key?(:backup_schedules) @create_time = args[:create_time] if args.key?(:create_time) @database = args[:database] if args.key?(:database) @database_dialect = args[:database_dialect] if args.key?(:database_dialect) @encryption_info = args[:encryption_info] if args.key?(:encryption_info) @encryption_information = args[:encryption_information] if args.key?(:encryption_information) @exclusive_size_bytes = args[:exclusive_size_bytes] if args.key?(:exclusive_size_bytes) @expire_time = args[:expire_time] if args.key?(:expire_time) @freeable_size_bytes = args[:freeable_size_bytes] if args.key?(:freeable_size_bytes) @incremental_backup_chain_id = args[:incremental_backup_chain_id] if args.key?(:incremental_backup_chain_id) @instance_partitions = args[:instance_partitions] if args.key?(:instance_partitions) @max_expire_time = args[:max_expire_time] if args.key?(:max_expire_time) @minimum_restorable_edition = args[:minimum_restorable_edition] if args.key?(:minimum_restorable_edition) @name = args[:name] if args.key?(:name) @oldest_version_time = args[:oldest_version_time] if args.key?(:oldest_version_time) @referencing_backups = args[:referencing_backups] if args.key?(:referencing_backups) @referencing_databases = args[:referencing_databases] if args.key?(:referencing_databases) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @state = args[:state] if args.key?(:state) @version_time = args[:version_time] if args.key?(:version_time) end |