Class: Google::Apis::SpannerV1::BackupScheduleSpec
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::BackupScheduleSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Defines specifications of the backup schedule.
Instance Attribute Summary collapse
-
#cron_spec ⇒ Google::Apis::SpannerV1::CrontabSpec
CrontabSpec can be used to specify the version time and frequency at which the backup is created.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupScheduleSpec
constructor
A new instance of BackupScheduleSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupScheduleSpec
Returns a new instance of BackupScheduleSpec.
698 699 700 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 698 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cron_spec ⇒ Google::Apis::SpannerV1::CrontabSpec
CrontabSpec can be used to specify the version time and frequency at which the
backup is created.
Corresponds to the JSON property cronSpec
696 697 698 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 696 def cron_spec @cron_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
703 704 705 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 703 def update!(**args) @cron_spec = args[:cron_spec] if args.key?(:cron_spec) end |