Class: Google::Apis::SpannerV1::BatchCreateSessionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for BatchCreateSessions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchCreateSessionsRequest

Returns a new instance of BatchCreateSessionsRequest.



787
788
789
# File 'lib/google/apis/spanner_v1/classes.rb', line 787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#session_countFixnum

Required. The number of sessions to be created in this batch call. At least one session is created. The API can return fewer than the requested number of sessions. If a specific number of sessions are desired, the client can make additional calls to BatchCreateSessions (adjusting session_count as necessary). Corresponds to the JSON property sessionCount

Returns:

  • (Fixnum)


780
781
782
# File 'lib/google/apis/spanner_v1/classes.rb', line 780

def session_count
  @session_count
end

#session_templateGoogle::Apis::SpannerV1::Session

A session in the Cloud Spanner API. Corresponds to the JSON property sessionTemplate



785
786
787
# File 'lib/google/apis/spanner_v1/classes.rb', line 785

def session_template
  @session_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



792
793
794
795
# File 'lib/google/apis/spanner_v1/classes.rb', line 792

def update!(**args)
  @session_count = args[:session_count] if args.key?(:session_count)
  @session_template = args[:session_template] if args.key?(:session_template)
end