Class: Google::Apis::SpannerV1::BatchCreateSessionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::BatchCreateSessionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The request for BatchCreateSessions.
Instance Attribute Summary collapse
-
#session_count ⇒ Fixnum
Required.
-
#session_template ⇒ Google::Apis::SpannerV1::Session
A session in the Cloud Spanner API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchCreateSessionsRequest
constructor
A new instance of BatchCreateSessionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchCreateSessionsRequest
Returns a new instance of BatchCreateSessionsRequest.
726 727 728 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#session_count ⇒ Fixnum
Required. The number of sessions to be created in this batch call. At least
one session is created. The API can return fewer than the requested number of
sessions. If a specific number of sessions are desired, the client can make
additional calls to BatchCreateSessions (adjusting session_count as
necessary).
Corresponds to the JSON property sessionCount
719 720 721 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 719 def session_count @session_count end |
#session_template ⇒ Google::Apis::SpannerV1::Session
A session in the Cloud Spanner API.
Corresponds to the JSON property sessionTemplate
724 725 726 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 724 def session_template @session_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
731 732 733 734 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 731 def update!(**args) @session_count = args[:session_count] if args.key?(:session_count) @session_template = args[:session_template] if args.key?(:session_template) end |