Class: Google::Apis::SpannerV1::BatchWriteRequest
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::BatchWriteRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The request for BatchWrite.
Instance Attribute Summary collapse
-
#exclude_txn_from_change_streams ⇒ Boolean
(also: #exclude_txn_from_change_streams?)
Optional.
-
#mutation_groups ⇒ Array<Google::Apis::SpannerV1::MutationGroup>
Required.
-
#request_options ⇒ Google::Apis::SpannerV1::RequestOptions
Common request options for various APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchWriteRequest
constructor
A new instance of BatchWriteRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchWriteRequest
Returns a new instance of BatchWriteRequest.
778 779 780 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_txn_from_change_streams ⇒ Boolean Also known as: exclude_txn_from_change_streams?
Optional. If you don't set the exclude_txn_from_change_streams option or if
it's set to false, then any change streams monitoring columns modified by
transactions will capture the updates made within that transaction.
Corresponds to the JSON property excludeTxnFromChangeStreams
765 766 767 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 765 def exclude_txn_from_change_streams @exclude_txn_from_change_streams end |
#mutation_groups ⇒ Array<Google::Apis::SpannerV1::MutationGroup>
Required. The groups of mutations to be applied.
Corresponds to the JSON property mutationGroups
771 772 773 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 771 def mutation_groups @mutation_groups end |
#request_options ⇒ Google::Apis::SpannerV1::RequestOptions
Common request options for various APIs.
Corresponds to the JSON property requestOptions
776 777 778 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 776 def @request_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
783 784 785 786 787 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 783 def update!(**args) @exclude_txn_from_change_streams = args[:exclude_txn_from_change_streams] if args.key?(:exclude_txn_from_change_streams) @mutation_groups = args[:mutation_groups] if args.key?(:mutation_groups) @request_options = args[:request_options] if args.key?(:request_options) end |