Class: Google::Apis::SpannerV1::BatchWriteResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The result of applying a batch of mutations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchWriteResponse

Returns a new instance of BatchWriteResponse.



816
817
818
# File 'lib/google/apis/spanner_v1/classes.rb', line 816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commit_timestampString

The commit timestamp of the transaction that applied this batch. Present if status is OK, absent otherwise. Corresponds to the JSON property commitTimestamp

Returns:

  • (String)


798
799
800
# File 'lib/google/apis/spanner_v1/classes.rb', line 798

def commit_timestamp
  @commit_timestamp
end

#indexesArray<Fixnum>

The mutation groups applied in this batch. The values index into the mutation_groups field in the corresponding BatchWriteRequest. Corresponds to the JSON property indexes

Returns:

  • (Array<Fixnum>)


804
805
806
# File 'lib/google/apis/spanner_v1/classes.rb', line 804

def indexes
  @indexes
end

#statusGoogle::Apis::SpannerV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



814
815
816
# File 'lib/google/apis/spanner_v1/classes.rb', line 814

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



821
822
823
824
825
# File 'lib/google/apis/spanner_v1/classes.rb', line 821

def update!(**args)
  @commit_timestamp = args[:commit_timestamp] if args.key?(:commit_timestamp)
  @indexes = args[:indexes] if args.key?(:indexes)
  @status = args[:status] if args.key?(:status)
end