Class: Google::Apis::SpannerV1::BeginTransactionRequest
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::BeginTransactionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The request for BeginTransaction.
Instance Attribute Summary collapse
-
#mutation_key ⇒ Google::Apis::SpannerV1::Mutation
A modification to one or more Cloud Spanner rows.
-
#options ⇒ Google::Apis::SpannerV1::TransactionOptions
Options to use for transactions.
-
#request_options ⇒ Google::Apis::SpannerV1::RequestOptions
Common request options for various APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BeginTransactionRequest
constructor
A new instance of BeginTransactionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BeginTransactionRequest
Returns a new instance of BeginTransactionRequest.
848 849 850 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mutation_key ⇒ Google::Apis::SpannerV1::Mutation
A modification to one or more Cloud Spanner rows. Mutations can be applied to
a Cloud Spanner database by sending them in a Commit call.
Corresponds to the JSON property mutationKey
836 837 838 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 836 def mutation_key @mutation_key end |
#options ⇒ Google::Apis::SpannerV1::TransactionOptions
Options to use for transactions.
Corresponds to the JSON property options
841 842 843 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 841 def @options end |
#request_options ⇒ Google::Apis::SpannerV1::RequestOptions
Common request options for various APIs.
Corresponds to the JSON property requestOptions
846 847 848 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 846 def @request_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
853 854 855 856 857 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 853 def update!(**args) @mutation_key = args[:mutation_key] if args.key?(:mutation_key) @options = args[:options] if args.key?(:options) @request_options = args[:request_options] if args.key?(:request_options) end |