Class: Google::Apis::SpannerV1::ChangeQuorumRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for ChangeQuorum.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChangeQuorumRequest

Returns a new instance of ChangeQuorumRequest.



1017
1018
1019
# File 'lib/google/apis/spanner_v1/classes.rb', line 1017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The etag is the hash of the QuorumInfo. The ChangeQuorum operation is only performed if the etag matches that of the QuorumInfo in the current database resource. Otherwise the API returns an ABORTED error. The etag is used for optimistic concurrency control as a way to help prevent simultaneous change quorum requests that could create a race condition. Corresponds to the JSON property etag

Returns:

  • (String)


1003
1004
1005
# File 'lib/google/apis/spanner_v1/classes.rb', line 1003

def etag
  @etag
end

#nameString

Required. Name of the database in which to apply ChangeQuorum. Values are of the form projects//instances//databases/. Corresponds to the JSON property name

Returns:

  • (String)


1009
1010
1011
# File 'lib/google/apis/spanner_v1/classes.rb', line 1009

def name
  @name
end

#quorum_typeGoogle::Apis::SpannerV1::QuorumType

Information about the database quorum type. This only applies to dual-region instance configs. Corresponds to the JSON property quorumType



1015
1016
1017
# File 'lib/google/apis/spanner_v1/classes.rb', line 1015

def quorum_type
  @quorum_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1022
1023
1024
1025
1026
# File 'lib/google/apis/spanner_v1/classes.rb', line 1022

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @quorum_type = args[:quorum_type] if args.key?(:quorum_type)
end