Class: Google::Apis::SpannerV1::CommitResponse
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::CommitResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The response for Commit.
Instance Attribute Summary collapse
-
#commit_stats ⇒ Google::Apis::SpannerV1::CommitStats
Additional statistics about a commit.
-
#commit_timestamp ⇒ String
The Cloud Spanner timestamp at which the transaction committed.
-
#precommit_token ⇒ Google::Apis::SpannerV1::MultiplexedSessionPrecommitToken
When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses.
-
#snapshot_timestamp ⇒ String
If
TransactionOptions.isolation_levelis set to `IsolationLevel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitResponse
constructor
A new instance of CommitResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitResponse
Returns a new instance of CommitResponse.
1275 1276 1277 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commit_stats ⇒ Google::Apis::SpannerV1::CommitStats
Additional statistics about a commit.
Corresponds to the JSON property commitStats
1253 1254 1255 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1253 def commit_stats @commit_stats end |
#commit_timestamp ⇒ String
The Cloud Spanner timestamp at which the transaction committed.
Corresponds to the JSON property commitTimestamp
1258 1259 1260 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1258 def @commit_timestamp end |
#precommit_token ⇒ Google::Apis::SpannerV1::MultiplexedSessionPrecommitToken
When a read-write transaction is executed on a multiplexed session, this
precommit token is sent back to the client as a part of the Transaction
message in the BeginTransaction response and also as a part of the ResultSet
and PartialResultSet responses.
Corresponds to the JSON property precommitToken
1266 1267 1268 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1266 def precommit_token @precommit_token end |
#snapshot_timestamp ⇒ String
If TransactionOptions.isolation_level is set to IsolationLevel.
REPEATABLE_READ, then the snapshot timestamp is the timestamp at which all
reads in the transaction ran. This timestamp is never returned.
Corresponds to the JSON property snapshotTimestamp
1273 1274 1275 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1273 def @snapshot_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1280 1281 1282 1283 1284 1285 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1280 def update!(**args) @commit_stats = args[:commit_stats] if args.key?(:commit_stats) @commit_timestamp = args[:commit_timestamp] if args.key?(:commit_timestamp) @precommit_token = args[:precommit_token] if args.key?(:precommit_token) @snapshot_timestamp = args[:snapshot_timestamp] if args.key?(:snapshot_timestamp) end |