Class: Google::Apis::SpannerV1::CommitStats
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::CommitStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Additional statistics about a commit.
Instance Attribute Summary collapse
-
#mutation_count ⇒ Fixnum
The total number of mutations for the transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitStats
constructor
A new instance of CommitStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitStats
Returns a new instance of CommitStats.
1304 1305 1306 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mutation_count ⇒ Fixnum
The total number of mutations for the transaction. Knowing the mutation_count
value can help you maximize the number of mutations in a transaction and
minimize the number of API round trips. You can also monitor this value to
prevent transactions from exceeding the system limit. If
the number of mutations exceeds the limit, the server returns
INVALID_ARGUMENT.
Corresponds to the JSON property mutationCount
1302 1303 1304 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1302 def mutation_count @mutation_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1309 1310 1311 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1309 def update!(**args) @mutation_count = args[:mutation_count] if args.key?(:mutation_count) end |