Class: Google::Apis::SpannerV1::CompactDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the long-running operation returned by CALL compact_all(), which can be executed using ExecuteSql or ExecuteStreamingSql APIs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompactDatabaseMetadata

Returns a new instance of CompactDatabaseMetadata.



1427
1428
1429
# File 'lib/google/apis/spanner_v1/classes.rb', line 1427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancel_timeString

Output only. The time at which cancellation of this operation was received. Operations.CancelOperation starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google. rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property cancelTime

Returns:

  • (String)


1414
1415
1416
# File 'lib/google/apis/spanner_v1/classes.rb', line 1414

def cancel_time
  @cancel_time
end

#databaseString

Output only. The database being compacted. Corresponds to the JSON property database

Returns:

  • (String)


1419
1420
1421
# File 'lib/google/apis/spanner_v1/classes.rb', line 1419

def database
  @database
end

#progressGoogle::Apis::SpannerV1::OperationProgress

Encapsulates progress related information for a Cloud Spanner long running operation. Corresponds to the JSON property progress



1425
1426
1427
# File 'lib/google/apis/spanner_v1/classes.rb', line 1425

def progress
  @progress
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1432
1433
1434
1435
1436
# File 'lib/google/apis/spanner_v1/classes.rb', line 1432

def update!(**args)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @database = args[:database] if args.key?(:database)
  @progress = args[:progress] if args.key?(:progress)
end