Class: Google::Apis::SpannerV1::CopyBackupMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::CopyBackupMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Metadata type for the operation returned by CopyBackup.
Instance Attribute Summary collapse
-
#cancel_time ⇒ String
The time at which cancellation of CopyBackup operation was received.
-
#name ⇒ String
The name of the backup being created through the copy operation.
-
#progress ⇒ Google::Apis::SpannerV1::OperationProgress
Encapsulates progress related information for a Cloud Spanner long running operation.
-
#source_backup ⇒ String
The name of the source backup that is being copied.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CopyBackupMetadata
constructor
A new instance of CopyBackupMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CopyBackupMetadata
Returns a new instance of CopyBackupMetadata.
1562 1563 1564 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1562 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancel_time ⇒ String
The time at which cancellation of CopyBackup operation was received.
Operations.CancelOperation starts asynchronous cancellation on a long-running
operation. The server makes a best effort to cancel the operation, but success
is not guaranteed. Clients can use Operations.GetOperation or other methods to
check whether the cancellation succeeded or whether the operation completed
despite cancellation. On successful cancellation, the operation is not deleted;
instead, it becomes an operation with an Operation.error value with a google.
rpc.Status.code of 1, corresponding to Code.CANCELLED.
Corresponds to the JSON property cancelTime
1542 1543 1544 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1542 def cancel_time @cancel_time end |
#name ⇒ String
The name of the backup being created through the copy operation. Values are of
the form projects//instances//backups/.
Corresponds to the JSON property name
1548 1549 1550 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1548 def name @name end |
#progress ⇒ Google::Apis::SpannerV1::OperationProgress
Encapsulates progress related information for a Cloud Spanner long running
operation.
Corresponds to the JSON property progress
1554 1555 1556 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1554 def progress @progress end |
#source_backup ⇒ String
The name of the source backup that is being copied. Values are of the form
projects//instances//backups/.
Corresponds to the JSON property sourceBackup
1560 1561 1562 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1560 def source_backup @source_backup end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1567 1568 1569 1570 1571 1572 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1567 def update!(**args) @cancel_time = args[:cancel_time] if args.key?(:cancel_time) @name = args[:name] if args.key?(:name) @progress = args[:progress] if args.key?(:progress) @source_backup = args[:source_backup] if args.key?(:source_backup) end |