Class: Google::Apis::SpannerV1::CopyBackupRequest
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::CopyBackupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The request for CopyBackup.
Instance Attribute Summary collapse
-
#backup_id ⇒ String
Required.
-
#encryption_config ⇒ Google::Apis::SpannerV1::CopyBackupEncryptionConfig
Encryption configuration for the copied backup.
-
#expire_time ⇒ String
Required.
-
#source_backup ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CopyBackupRequest
constructor
A new instance of CopyBackupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CopyBackupRequest
Returns a new instance of CopyBackupRequest.
1607 1608 1609 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_id ⇒ String
Required. The id of the backup copy. The backup_id appended to parent
forms the full backup_uri of the form projects//instances//backups/.
Corresponds to the JSON property backupId
1583 1584 1585 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1583 def backup_id @backup_id end |
#encryption_config ⇒ Google::Apis::SpannerV1::CopyBackupEncryptionConfig
Encryption configuration for the copied backup.
Corresponds to the JSON property encryptionConfig
1588 1589 1590 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1588 def encryption_config @encryption_config end |
#expire_time ⇒ String
Required. The expiration time of the backup in microsecond granularity. The
expiration time must be at least 6 hours and at most 366 days from the
create_time of the source backup. Once the expire_time has passed, the
backup is eligible to be automatically deleted by Cloud Spanner to free the
resources used by the backup.
Corresponds to the JSON property expireTime
1597 1598 1599 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1597 def expire_time @expire_time end |
#source_backup ⇒ String
Required. The source backup to be copied. The source backup needs to be in
READY state for it to be copied. Once CopyBackup is in progress, the source
backup cannot be deleted or cleaned up on expiration until CopyBackup is
finished. Values are of the form: projects//instances//backups/.
Corresponds to the JSON property sourceBackup
1605 1606 1607 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1605 def source_backup @source_backup end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1612 1613 1614 1615 1616 1617 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1612 def update!(**args) @backup_id = args[:backup_id] if args.key?(:backup_id) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @expire_time = args[:expire_time] if args.key?(:expire_time) @source_backup = args[:source_backup] if args.key?(:source_backup) end |