Class: Google::Apis::SpannerV1::CreateBackupMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::CreateBackupMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Metadata type for the operation returned by CreateBackup.
Instance Attribute Summary collapse
-
#cancel_time ⇒ String
The time at which cancellation of this operation was received.
-
#database ⇒ String
The name of the database the backup is created from.
-
#name ⇒ String
The name of the backup being created.
-
#progress ⇒ Google::Apis::SpannerV1::OperationProgress
Encapsulates progress related information for a Cloud Spanner long running operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateBackupMetadata
constructor
A new instance of CreateBackupMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateBackupMetadata
Returns a new instance of CreateBackupMetadata.
1720 1721 1722 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1720 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancel_time ⇒ String
The time at which cancellation of this operation was received. Operations.
CancelOperation starts asynchronous cancellation on a long-running operation.
The server makes a best effort to cancel the operation, but success is not
guaranteed. Clients can use Operations.GetOperation or other methods to check
whether the cancellation succeeded or whether the operation completed despite
cancellation. On successful cancellation, the operation is not deleted;
instead, it becomes an operation with an Operation.error value with a google.
rpc.Status.code of 1, corresponding to Code.CANCELLED.
Corresponds to the JSON property cancelTime
1702 1703 1704 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1702 def cancel_time @cancel_time end |
#database ⇒ String
The name of the database the backup is created from.
Corresponds to the JSON property database
1707 1708 1709 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1707 def database @database end |
#name ⇒ String
The name of the backup being created.
Corresponds to the JSON property name
1712 1713 1714 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1712 def name @name end |
#progress ⇒ Google::Apis::SpannerV1::OperationProgress
Encapsulates progress related information for a Cloud Spanner long running
operation.
Corresponds to the JSON property progress
1718 1719 1720 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1718 def progress @progress end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1725 1726 1727 1728 1729 1730 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1725 def update!(**args) @cancel_time = args[:cancel_time] if args.key?(:cancel_time) @database = args[:database] if args.key?(:database) @name = args[:name] if args.key?(:name) @progress = args[:progress] if args.key?(:progress) end |