Class: Google::Apis::SpannerV1::CreateBackupMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the operation returned by CreateBackup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateBackupMetadata

Returns a new instance of CreateBackupMetadata.



1708
1709
1710
# File 'lib/google/apis/spanner_v1/classes.rb', line 1708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancel_timeString

The time at which cancellation of this operation was received. Operations. CancelOperation starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google. rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property cancelTime

Returns:

  • (String)


1690
1691
1692
# File 'lib/google/apis/spanner_v1/classes.rb', line 1690

def cancel_time
  @cancel_time
end

#databaseString

The name of the database the backup is created from. Corresponds to the JSON property database

Returns:

  • (String)


1695
1696
1697
# File 'lib/google/apis/spanner_v1/classes.rb', line 1695

def database
  @database
end

#nameString

The name of the backup being created. Corresponds to the JSON property name

Returns:

  • (String)


1700
1701
1702
# File 'lib/google/apis/spanner_v1/classes.rb', line 1700

def name
  @name
end

#progressGoogle::Apis::SpannerV1::OperationProgress

Encapsulates progress related information for a Cloud Spanner long running operation. Corresponds to the JSON property progress



1706
1707
1708
# File 'lib/google/apis/spanner_v1/classes.rb', line 1706

def progress
  @progress
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1713
1714
1715
1716
1717
1718
# File 'lib/google/apis/spanner_v1/classes.rb', line 1713

def update!(**args)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @database = args[:database] if args.key?(:database)
  @name = args[:name] if args.key?(:name)
  @progress = args[:progress] if args.key?(:progress)
end