Class: Google::Apis::SpannerV1::CreateInstanceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::CreateInstanceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Metadata type for the operation returned by CreateInstance.
Instance Attribute Summary collapse
-
#cancel_time ⇒ String
The time at which this operation was cancelled.
-
#end_time ⇒ String
The time at which this operation failed or was completed successfully.
-
#expected_fulfillment_period ⇒ String
The expected fulfillment period of this create operation.
-
#instance ⇒ Google::Apis::SpannerV1::Instance
An isolated set of Cloud Spanner resources on which databases can be hosted.
-
#start_time ⇒ String
The time at which the CreateInstance request was received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateInstanceMetadata
constructor
A new instance of CreateInstanceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateInstanceMetadata
Returns a new instance of CreateInstanceMetadata.
1913 1914 1915 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancel_time ⇒ String
The time at which this operation was cancelled. If set, this operation is in
the process of undoing itself (which is guaranteed to succeed) and cannot be
cancelled again.
Corresponds to the JSON property cancelTime
1891 1892 1893 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1891 def cancel_time @cancel_time end |
#end_time ⇒ String
The time at which this operation failed or was completed successfully.
Corresponds to the JSON property endTime
1896 1897 1898 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1896 def end_time @end_time end |
#expected_fulfillment_period ⇒ String
The expected fulfillment period of this create operation.
Corresponds to the JSON property expectedFulfillmentPeriod
1901 1902 1903 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1901 def expected_fulfillment_period @expected_fulfillment_period end |
#instance ⇒ Google::Apis::SpannerV1::Instance
An isolated set of Cloud Spanner resources on which databases can be hosted.
Corresponds to the JSON property instance
1906 1907 1908 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1906 def instance @instance end |
#start_time ⇒ String
The time at which the CreateInstance request was received.
Corresponds to the JSON property startTime
1911 1912 1913 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1911 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1918 1919 1920 1921 1922 1923 1924 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1918 def update!(**args) @cancel_time = args[:cancel_time] if args.key?(:cancel_time) @end_time = args[:end_time] if args.key?(:end_time) @expected_fulfillment_period = args[:expected_fulfillment_period] if args.key?(:expected_fulfillment_period) @instance = args[:instance] if args.key?(:instance) @start_time = args[:start_time] if args.key?(:start_time) end |