Class: Google::Apis::SpannerV1::CreateInstanceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the operation returned by CreateInstance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateInstanceMetadata

Returns a new instance of CreateInstanceMetadata.



1901
1902
1903
# File 'lib/google/apis/spanner_v1/classes.rb', line 1901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancel_timeString

The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again. Corresponds to the JSON property cancelTime

Returns:

  • (String)


1879
1880
1881
# File 'lib/google/apis/spanner_v1/classes.rb', line 1879

def cancel_time
  @cancel_time
end

#end_timeString

The time at which this operation failed or was completed successfully. Corresponds to the JSON property endTime

Returns:

  • (String)


1884
1885
1886
# File 'lib/google/apis/spanner_v1/classes.rb', line 1884

def end_time
  @end_time
end

#expected_fulfillment_periodString

The expected fulfillment period of this create operation. Corresponds to the JSON property expectedFulfillmentPeriod

Returns:

  • (String)


1889
1890
1891
# File 'lib/google/apis/spanner_v1/classes.rb', line 1889

def expected_fulfillment_period
  @expected_fulfillment_period
end

#instanceGoogle::Apis::SpannerV1::Instance

An isolated set of Cloud Spanner resources on which databases can be hosted. Corresponds to the JSON property instance



1894
1895
1896
# File 'lib/google/apis/spanner_v1/classes.rb', line 1894

def instance
  @instance
end

#start_timeString

The time at which the CreateInstance request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


1899
1900
1901
# File 'lib/google/apis/spanner_v1/classes.rb', line 1899

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1906
1907
1908
1909
1910
1911
1912
# File 'lib/google/apis/spanner_v1/classes.rb', line 1906

def update!(**args)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @expected_fulfillment_period = args[:expected_fulfillment_period] if args.key?(:expected_fulfillment_period)
  @instance = args[:instance] if args.key?(:instance)
  @start_time = args[:start_time] if args.key?(:start_time)
end