Class: Google::Apis::SpannerV1::CreateInstancePartitionMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the operation returned by CreateInstancePartition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateInstancePartitionMetadata

Returns a new instance of CreateInstancePartitionMetadata.



1935
1936
1937
# File 'lib/google/apis/spanner_v1/classes.rb', line 1935

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancel_timeString

The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again. Corresponds to the JSON property cancelTime

Returns:

  • (String)


1917
1918
1919
# File 'lib/google/apis/spanner_v1/classes.rb', line 1917

def cancel_time
  @cancel_time
end

#end_timeString

The time at which this operation failed or was completed successfully. Corresponds to the JSON property endTime

Returns:

  • (String)


1922
1923
1924
# File 'lib/google/apis/spanner_v1/classes.rb', line 1922

def end_time
  @end_time
end

#instance_partitionGoogle::Apis::SpannerV1::InstancePartition

An isolated set of Cloud Spanner resources that databases can define placements on. Corresponds to the JSON property instancePartition



1928
1929
1930
# File 'lib/google/apis/spanner_v1/classes.rb', line 1928

def instance_partition
  @instance_partition
end

#start_timeString

The time at which the CreateInstancePartition request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


1933
1934
1935
# File 'lib/google/apis/spanner_v1/classes.rb', line 1933

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1940
1941
1942
1943
1944
1945
# File 'lib/google/apis/spanner_v1/classes.rb', line 1940

def update!(**args)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @instance_partition = args[:instance_partition] if args.key?(:instance_partition)
  @start_time = args[:start_time] if args.key?(:start_time)
end