Class: Google::Apis::SpannerV1::CreateInstancePartitionMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::CreateInstancePartitionMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Metadata type for the operation returned by CreateInstancePartition.
Instance Attribute Summary collapse
-
#cancel_time ⇒ String
The time at which this operation was cancelled.
-
#end_time ⇒ String
The time at which this operation failed or was completed successfully.
-
#instance_partition ⇒ Google::Apis::SpannerV1::InstancePartition
An isolated set of Cloud Spanner resources that databases can define placements on.
-
#start_time ⇒ String
The time at which the CreateInstancePartition request was received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateInstancePartitionMetadata
constructor
A new instance of CreateInstancePartitionMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateInstancePartitionMetadata
Returns a new instance of CreateInstancePartitionMetadata.
1850 1851 1852 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancel_time ⇒ String
The time at which this operation was cancelled. If set, this operation is in
the process of undoing itself (which is guaranteed to succeed) and cannot be
cancelled again.
Corresponds to the JSON property cancelTime
1832 1833 1834 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1832 def cancel_time @cancel_time end |
#end_time ⇒ String
The time at which this operation failed or was completed successfully.
Corresponds to the JSON property endTime
1837 1838 1839 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1837 def end_time @end_time end |
#instance_partition ⇒ Google::Apis::SpannerV1::InstancePartition
An isolated set of Cloud Spanner resources that databases can define
placements on.
Corresponds to the JSON property instancePartition
1843 1844 1845 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1843 def instance_partition @instance_partition end |
#start_time ⇒ String
The time at which the CreateInstancePartition request was received.
Corresponds to the JSON property startTime
1848 1849 1850 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1848 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1855 1856 1857 1858 1859 1860 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 1855 def update!(**args) @cancel_time = args[:cancel_time] if args.key?(:cancel_time) @end_time = args[:end_time] if args.key?(:end_time) @instance_partition = args[:instance_partition] if args.key?(:instance_partition) @start_time = args[:start_time] if args.key?(:start_time) end |