Class: Google::Apis::SpannerV1::CrontabSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

CrontabSpec can be used to specify the version time and frequency at which the backup is created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrontabSpec

Returns a new instance of CrontabSpec.



2064
2065
2066
# File 'lib/google/apis/spanner_v1/classes.rb', line 2064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_windowString

Output only. Scheduled backups contain an externally consistent copy of the database at the version time specified in schedule_spec.cron_spec. However, Spanner might not initiate the creation of the scheduled backups at that version time. Spanner initiates the creation of scheduled backups within the time window bounded by the version_time specified in schedule_spec.cron_spec and version_time + creation_window. Corresponds to the JSON property creationWindow

Returns:

  • (String)


2040
2041
2042
# File 'lib/google/apis/spanner_v1/classes.rb', line 2040

def creation_window
  @creation_window
end

#textString

Required. Textual representation of the crontab. User can customize the backup frequency and the backup version time using the cron expression. The version time must be in UTC timezone. The backup will contain an externally consistent copy of the database at the version time. Full backups must be scheduled a minimum of 12 hours apart and incremental backups must be scheduled a minimum of 4 hours apart. Examples of valid cron specifications: * 0 2/12 * * * : every 12 hours at (2, 14) hours past midnight in UTC. * 0 2,14 * * * : every 12 hours at (2, 14) hours past midnight in UTC. * 0 */4 * * * : (incremental backups only) every 4 hours at (0, 4, 8, 12, 16, 20) hours past midnight in UTC. * 0 2 * * * : once a day at 2 past midnight in UTC. * 0 2 * * 0 : once a week every Sunday at 2 past midnight in UTC. * 0 2 8 * * : once a month on 8th day at 2 past midnight in UTC. Corresponds to the JSON property text

Returns:

  • (String)


2056
2057
2058
# File 'lib/google/apis/spanner_v1/classes.rb', line 2056

def text
  @text
end

#time_zoneString

Output only. The time zone of the times in CrontabSpec.text. Currently, only UTC is supported. Corresponds to the JSON property timeZone

Returns:

  • (String)


2062
2063
2064
# File 'lib/google/apis/spanner_v1/classes.rb', line 2062

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2069
2070
2071
2072
2073
# File 'lib/google/apis/spanner_v1/classes.rb', line 2069

def update!(**args)
  @creation_window = args[:creation_window] if args.key?(:creation_window)
  @text = args[:text] if args.key?(:text)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end