Class: Google::Apis::SpannerV1::CrontabSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

CrontabSpec can be used to specify the version time and frequency at which the backup is created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrontabSpec

Returns a new instance of CrontabSpec.



1972
1973
1974
# File 'lib/google/apis/spanner_v1/classes.rb', line 1972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_windowString

Output only. Scheduled backups contain an externally consistent copy of the database at the version time specified in schedule_spec.cron_spec. However, Spanner might not initiate the creation of the scheduled backups at that version time. Spanner initiates the creation of scheduled backups within the time window bounded by the version_time specified in schedule_spec.cron_spec and version_time + creation_window. Corresponds to the JSON property creationWindow

Returns:

  • (String)


1948
1949
1950
# File 'lib/google/apis/spanner_v1/classes.rb', line 1948

def creation_window
  @creation_window
end

#textString

Required. Textual representation of the crontab. User can customize the backup frequency and the backup version time using the cron expression. The version time must be in UTC timezone. The backup will contain an externally consistent copy of the database at the version time. Full backups must be scheduled a minimum of 12 hours apart and incremental backups must be scheduled a minimum of 4 hours apart. Examples of valid cron specifications: * 0 2/12 * * * : every 12 hours at (2, 14) hours past midnight in UTC. * 0 2,14 * * * : every 12 hours at (2, 14) hours past midnight in UTC. * 0 */4 * * * : (incremental backups only) every 4 hours at (0, 4, 8, 12, 16, 20) hours past midnight in UTC. * 0 2 * * * : once a day at 2 past midnight in UTC. * 0 2 * * 0 : once a week every Sunday at 2 past midnight in UTC. * 0 2 8 * * : once a month on 8th day at 2 past midnight in UTC. Corresponds to the JSON property text

Returns:

  • (String)


1964
1965
1966
# File 'lib/google/apis/spanner_v1/classes.rb', line 1964

def text
  @text
end

#time_zoneString

Output only. The time zone of the times in CrontabSpec.text. Currently, only UTC is supported. Corresponds to the JSON property timeZone

Returns:

  • (String)


1970
1971
1972
# File 'lib/google/apis/spanner_v1/classes.rb', line 1970

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1977
1978
1979
1980
1981
# File 'lib/google/apis/spanner_v1/classes.rb', line 1977

def update!(**args)
  @creation_window = args[:creation_window] if args.key?(:creation_window)
  @text = args[:text] if args.key?(:text)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end