Class: Google::Apis::SpannerV1::DatabaseMoveConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The configuration for each database in the target instance configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseMoveConfig

Returns a new instance of DatabaseMoveConfig.



2319
2320
2321
# File 'lib/google/apis/spanner_v1/classes.rb', line 2319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_idString

Required. The unique identifier of the database resource in the Instance. For example, if the database uri is projects/foo/instances/bar/databases/baz, then the id to supply here is baz. Corresponds to the JSON property databaseId

Returns:

  • (String)


2312
2313
2314
# File 'lib/google/apis/spanner_v1/classes.rb', line 2312

def database_id
  @database_id
end

#encryption_configGoogle::Apis::SpannerV1::InstanceEncryptionConfig

Encryption configuration for a Cloud Spanner database. Corresponds to the JSON property encryptionConfig



2317
2318
2319
# File 'lib/google/apis/spanner_v1/classes.rb', line 2317

def encryption_config
  @encryption_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2324
2325
2326
2327
# File 'lib/google/apis/spanner_v1/classes.rb', line 2324

def update!(**args)
  @database_id = args[:database_id] if args.key?(:database_id)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
end