Class: Google::Apis::SpannerV1::DatabaseMoveConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The configuration for each database in the target instance configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseMoveConfig

Returns a new instance of DatabaseMoveConfig.



2234
2235
2236
# File 'lib/google/apis/spanner_v1/classes.rb', line 2234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_idString

Required. The unique identifier of the database resource in the Instance. For example, if the database uri is projects/foo/instances/bar/databases/baz, then the id to supply here is baz. Corresponds to the JSON property databaseId

Returns:

  • (String)


2227
2228
2229
# File 'lib/google/apis/spanner_v1/classes.rb', line 2227

def database_id
  @database_id
end

#encryption_configGoogle::Apis::SpannerV1::InstanceEncryptionConfig

Encryption configuration for a Cloud Spanner database. Corresponds to the JSON property encryptionConfig



2232
2233
2234
# File 'lib/google/apis/spanner_v1/classes.rb', line 2232

def encryption_config
  @encryption_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2239
2240
2241
2242
# File 'lib/google/apis/spanner_v1/classes.rb', line 2239

def update!(**args)
  @database_id = args[:database_id] if args.key?(:database_id)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
end