Class: Google::Apis::SpannerV1::Delete
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::Delete
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Arguments to delete operations.
Instance Attribute Summary collapse
-
#key_set ⇒ Google::Apis::SpannerV1::KeySet
KeySetdefines a collection of Cloud Spanner keys and/or key ranges. -
#table ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Delete
constructor
A new instance of Delete.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Delete
Returns a new instance of Delete.
2415 2416 2417 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key_set ⇒ Google::Apis::SpannerV1::KeySet
KeySet defines a collection of Cloud Spanner keys and/or key ranges. All the
keys are expected to be in the same table or index. The keys need not be
sorted in any particular way. If the same key is specified multiple times in
the set (for example if two ranges, two keys, or a key and a range overlap),
Cloud Spanner behaves as if the key were only specified once.
Corresponds to the JSON property keySet
2408 2409 2410 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2408 def key_set @key_set end |
#table ⇒ String
Required. The table whose rows will be deleted.
Corresponds to the JSON property table
2413 2414 2415 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2413 def table @table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2420 2421 2422 2423 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2420 def update!(**args) @key_set = args[:key_set] if args.key?(:key_set) @table = args[:table] if args.key?(:table) end |