Class: Google::Apis::SpannerV1::Delete

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Arguments to delete operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Delete

Returns a new instance of Delete.



2408
2409
2410
# File 'lib/google/apis/spanner_v1/classes.rb', line 2408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#key_setGoogle::Apis::SpannerV1::KeySet

KeySet defines a collection of Cloud Spanner keys and/or key ranges. All the keys are expected to be in the same table or index. The keys need not be sorted in any particular way. If the same key is specified multiple times in the set (for example if two ranges, two keys, or a key and a range overlap), Cloud Spanner behaves as if the key were only specified once. Corresponds to the JSON property keySet



2401
2402
2403
# File 'lib/google/apis/spanner_v1/classes.rb', line 2401

def key_set
  @key_set
end

#tableString

Required. The table whose rows will be deleted. Corresponds to the JSON property table

Returns:

  • (String)


2406
2407
2408
# File 'lib/google/apis/spanner_v1/classes.rb', line 2406

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2413
2414
2415
2416
# File 'lib/google/apis/spanner_v1/classes.rb', line 2413

def update!(**args)
  @key_set = args[:key_set] if args.key?(:key_set)
  @table = args[:table] if args.key?(:table)
end