Class: Google::Apis::SpannerV1::Delete

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Arguments to delete operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Delete

Returns a new instance of Delete.



2323
2324
2325
# File 'lib/google/apis/spanner_v1/classes.rb', line 2323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#key_setGoogle::Apis::SpannerV1::KeySet

KeySet defines a collection of Cloud Spanner keys and/or key ranges. All the keys are expected to be in the same table or index. The keys need not be sorted in any particular way. If the same key is specified multiple times in the set (for example if two ranges, two keys, or a key and a range overlap), Cloud Spanner behaves as if the key were only specified once. Corresponds to the JSON property keySet



2316
2317
2318
# File 'lib/google/apis/spanner_v1/classes.rb', line 2316

def key_set
  @key_set
end

#tableString

Required. The table whose rows will be deleted. Corresponds to the JSON property table

Returns:

  • (String)


2321
2322
2323
# File 'lib/google/apis/spanner_v1/classes.rb', line 2321

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2328
2329
2330
2331
# File 'lib/google/apis/spanner_v1/classes.rb', line 2328

def update!(**args)
  @key_set = args[:key_set] if args.key?(:key_set)
  @table = args[:table] if args.key?(:table)
end