Class: Google::Apis::SpannerV1::DerivedMetric
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::DerivedMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A message representing a derived metric.
Instance Attribute Summary collapse
-
#denominator ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#numerator ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DerivedMetric
constructor
A new instance of DerivedMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DerivedMetric
Returns a new instance of DerivedMetric.
2442 2443 2444 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#denominator ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property denominator
2434 2435 2436 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2434 def denominator @denominator end |
#numerator ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property numerator
2440 2441 2442 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2440 def numerator @numerator end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2447 2448 2449 2450 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2447 def update!(**args) @denominator = args[:denominator] if args.key?(:denominator) @numerator = args[:numerator] if args.key?(:numerator) end |