Class: Google::Apis::SpannerV1::DerivedMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A message representing a derived metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DerivedMetric

Returns a new instance of DerivedMetric.



2350
2351
2352
# File 'lib/google/apis/spanner_v1/classes.rb', line 2350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#denominatorGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property denominator



2342
2343
2344
# File 'lib/google/apis/spanner_v1/classes.rb', line 2342

def denominator
  @denominator
end

#numeratorGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property numerator



2348
2349
2350
# File 'lib/google/apis/spanner_v1/classes.rb', line 2348

def numerator
  @numerator
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2355
2356
2357
2358
# File 'lib/google/apis/spanner_v1/classes.rb', line 2355

def update!(**args)
  @denominator = args[:denominator] if args.key?(:denominator)
  @numerator = args[:numerator] if args.key?(:numerator)
end