Class: Google::Apis::SpannerV1::DiagnosticMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A message representing the key visualizer diagnostic messages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiagnosticMessage

Returns a new instance of DiagnosticMessage.



2484
2485
2486
# File 'lib/google/apis/spanner_v1/classes.rb', line 2484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#infoGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property info



2454
2455
2456
# File 'lib/google/apis/spanner_v1/classes.rb', line 2454

def info
  @info
end

#metricGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property metric



2460
2461
2462
# File 'lib/google/apis/spanner_v1/classes.rb', line 2460

def metric
  @metric
end

#metric_specificBoolean Also known as: metric_specific?

Whether this message is specific only for the current metric. By default Diagnostics are shown for all metrics, regardless which metric is the currently selected metric in the UI. However occasionally a metric will generate so many messages that the resulting visual clutter becomes overwhelming. In this case setting this to true, will show the diagnostic messages for that metric only if it is the currently selected metric. Corresponds to the JSON property metricSpecific

Returns:

  • (Boolean)


2470
2471
2472
# File 'lib/google/apis/spanner_v1/classes.rb', line 2470

def metric_specific
  @metric_specific
end

#severityString

The severity of the diagnostic message. Corresponds to the JSON property severity

Returns:

  • (String)


2476
2477
2478
# File 'lib/google/apis/spanner_v1/classes.rb', line 2476

def severity
  @severity
end

#short_messageGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property shortMessage



2482
2483
2484
# File 'lib/google/apis/spanner_v1/classes.rb', line 2482

def short_message
  @short_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2489
2490
2491
2492
2493
2494
2495
# File 'lib/google/apis/spanner_v1/classes.rb', line 2489

def update!(**args)
  @info = args[:info] if args.key?(:info)
  @metric = args[:metric] if args.key?(:metric)
  @metric_specific = args[:metric_specific] if args.key?(:metric_specific)
  @severity = args[:severity] if args.key?(:severity)
  @short_message = args[:short_message] if args.key?(:short_message)
end