Class: Google::Apis::SpannerV1::DiagnosticMessage
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::DiagnosticMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A message representing the key visualizer diagnostic messages.
Instance Attribute Summary collapse
-
#info ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#metric ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#metric_specific ⇒ Boolean
(also: #metric_specific?)
Whether this message is specific only for the current metric.
-
#severity ⇒ String
The severity of the diagnostic message.
-
#short_message ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiagnosticMessage
constructor
A new instance of DiagnosticMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiagnosticMessage
Returns a new instance of DiagnosticMessage.
2399 2400 2401 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#info ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property info
2369 2370 2371 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2369 def info @info end |
#metric ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property metric
2375 2376 2377 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2375 def metric @metric end |
#metric_specific ⇒ Boolean Also known as: metric_specific?
Whether this message is specific only for the current metric. By default
Diagnostics are shown for all metrics, regardless which metric is the
currently selected metric in the UI. However occasionally a metric will
generate so many messages that the resulting visual clutter becomes
overwhelming. In this case setting this to true, will show the diagnostic
messages for that metric only if it is the currently selected metric.
Corresponds to the JSON property metricSpecific
2385 2386 2387 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2385 def metric_specific @metric_specific end |
#severity ⇒ String
The severity of the diagnostic message.
Corresponds to the JSON property severity
2391 2392 2393 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2391 def severity @severity end |
#short_message ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property shortMessage
2397 2398 2399 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2397 def @short_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2404 2405 2406 2407 2408 2409 2410 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2404 def update!(**args) @info = args[:info] if args.key?(:info) @metric = args[:metric] if args.key?(:metric) @metric_specific = args[:metric_specific] if args.key?(:metric_specific) @severity = args[:severity] if args.key?(:severity) @short_message = args[:short_message] if args.key?(:short_message) end |