Class: Google::Apis::SpannerV1::ExecuteBatchDmlRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for ExecuteBatchDml.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecuteBatchDmlRequest

Returns a new instance of ExecuteBatchDmlRequest.



2697
2698
2699
# File 'lib/google/apis/spanner_v1/classes.rb', line 2697

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_statementsBoolean Also known as: last_statements?

Optional. If set to true, this request marks the end of the transaction. After these statements execute, you must commit or abort the transaction. Attempts to execute any other requests against this transaction (including reads and queries) are rejected. Setting this option might cause some error reporting to be deferred until commit time (for example, validation of unique constraints). Given this, successful execution of statements shouldn't be assumed until a subsequent Commit call completes successfully. Corresponds to the JSON property lastStatements

Returns:

  • (Boolean)


2663
2664
2665
# File 'lib/google/apis/spanner_v1/classes.rb', line 2663

def last_statements
  @last_statements
end

#request_optionsGoogle::Apis::SpannerV1::RequestOptions

Common request options for various APIs. Corresponds to the JSON property requestOptions



2669
2670
2671
# File 'lib/google/apis/spanner_v1/classes.rb', line 2669

def request_options
  @request_options
end

#seqnoFixnum

Required. A per-transaction sequence number used to identify this request. This field makes each request idempotent such that if the request is received multiple times, at most one succeeds. The sequence number must be monotonically increasing within the transaction. If a request arrives for the first time with an out-of-order sequence number, the transaction might be aborted. Replays of previously handled requests yield the same response as the first execution. Corresponds to the JSON property seqno

Returns:

  • (Fixnum)


2680
2681
2682
# File 'lib/google/apis/spanner_v1/classes.rb', line 2680

def seqno
  @seqno
end

#statementsArray<Google::Apis::SpannerV1::Statement>

Required. The list of statements to execute in this batch. Statements are executed serially, such that the effects of statement i are visible to statement i+1. Each statement must be a DML statement. Execution stops at the first failed statement; the remaining statements are not executed. Callers must provide at least one statement. Corresponds to the JSON property statements



2689
2690
2691
# File 'lib/google/apis/spanner_v1/classes.rb', line 2689

def statements
  @statements
end

#transactionGoogle::Apis::SpannerV1::TransactionSelector

This message is used to select the transaction in which a Read or ExecuteSql call runs. See TransactionOptions for more information about transactions. Corresponds to the JSON property transaction



2695
2696
2697
# File 'lib/google/apis/spanner_v1/classes.rb', line 2695

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2702
2703
2704
2705
2706
2707
2708
# File 'lib/google/apis/spanner_v1/classes.rb', line 2702

def update!(**args)
  @last_statements = args[:last_statements] if args.key?(:last_statements)
  @request_options = args[:request_options] if args.key?(:request_options)
  @seqno = args[:seqno] if args.key?(:seqno)
  @statements = args[:statements] if args.key?(:statements)
  @transaction = args[:transaction] if args.key?(:transaction)
end