Class: Google::Apis::SpannerV1::ExecuteSqlRequest
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ExecuteSqlRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The request for ExecuteSql and ExecuteStreamingSql.
Instance Attribute Summary collapse
-
#data_boost_enabled ⇒ Boolean
(also: #data_boost_enabled?)
If this is for a partitioned query and this field is set to
true, the request is executed with Spanner Data Boost independent compute resources. -
#directed_read_options ⇒ Google::Apis::SpannerV1::DirectedReadOptions
The
DirectedReadOptionscan be used to indicate which replicas or regions should be used for non-transactional reads or queries. -
#last_statement ⇒ Boolean
(also: #last_statement?)
Optional.
-
#param_types ⇒ Hash<String,Google::Apis::SpannerV1::Type>
It isn't always possible for Cloud Spanner to infer the right SQL type from a JSON value.
-
#params ⇒ Hash<String,Object>
Parameter names and values that bind to placeholders in the SQL string.
-
#partition_token ⇒ String
If present, results are restricted to the specified partition previously created using
PartitionQuery. -
#query_mode ⇒ String
Used to control the amount of debugging information returned in ResultSetStats.
-
#query_options ⇒ Google::Apis::SpannerV1::QueryOptions
Query optimizer configuration.
-
#request_options ⇒ Google::Apis::SpannerV1::RequestOptions
Common request options for various APIs.
-
#resume_token ⇒ String
If this request is resuming a previously interrupted SQL statement execution,
resume_tokenshould be copied from the last PartialResultSet yielded before the interruption. -
#seqno ⇒ Fixnum
A per-transaction sequence number used to identify this request.
-
#sql ⇒ String
Required.
-
#transaction ⇒ Google::Apis::SpannerV1::TransactionSelector
This message is used to select the transaction in which a Read or ExecuteSql call runs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecuteSqlRequest
constructor
A new instance of ExecuteSqlRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecuteSqlRequest
Returns a new instance of ExecuteSqlRequest.
2795 2796 2797 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_boost_enabled ⇒ Boolean Also known as: data_boost_enabled?
If this is for a partitioned query and this field is set to true, the
request is executed with Spanner Data Boost independent compute resources. If
the field is set to true but the request doesn't set partition_token, the
API returns an INVALID_ARGUMENT error.
Corresponds to the JSON property dataBoostEnabled
2692 2693 2694 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2692 def data_boost_enabled @data_boost_enabled end |
#directed_read_options ⇒ Google::Apis::SpannerV1::DirectedReadOptions
The DirectedReadOptions can be used to indicate which replicas or regions
should be used for non-transactional reads or queries. DirectedReadOptions
can only be specified for a read-only transaction, otherwise the API returns
an INVALID_ARGUMENT error.
Corresponds to the JSON property directedReadOptions
2701 2702 2703 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2701 def @directed_read_options end |
#last_statement ⇒ Boolean Also known as: last_statement?
Optional. If set to true, this statement marks the end of the transaction.
After this statement executes, you must commit or abort the transaction.
Attempts to execute any other requests against this transaction (including
reads and queries) are rejected. For DML statements, setting this option might
cause some error reporting to be deferred until commit time (for example,
validation of unique constraints). Given this, successful execution of a DML
statement shouldn't be assumed until a subsequent Commit call completes
successfully.
Corresponds to the JSON property lastStatement
2713 2714 2715 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2713 def last_statement @last_statement end |
#param_types ⇒ Hash<String,Google::Apis::SpannerV1::Type>
It isn't always possible for Cloud Spanner to infer the right SQL type from a
JSON value. For example, values of type BYTES and values of type STRING
both appear in params as JSON strings. In these cases, you can use
param_types to specify the exact SQL type for some or all of the SQL
statement parameters. See the definition of Type for more information about
SQL types.
Corresponds to the JSON property paramTypes
2724 2725 2726 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2724 def param_types @param_types end |
#params ⇒ Hash<String,Object>
Parameter names and values that bind to placeholders in the SQL string. A
parameter placeholder consists of the @ character followed by the parameter
name (for example, @firstName). Parameter names must conform to the naming
requirements of identifiers as specified at https://cloud.google.com/spanner/
docs/lexical#identifiers. Parameters can appear anywhere that a literal value
is expected. The same parameter name can be used more than once, for example:
"WHERE id > @msg_id AND id < @msg_id + 100" It's an error to execute a SQL
statement with unbound parameters.
Corresponds to the JSON property params
2736 2737 2738 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2736 def params @params end |
#partition_token ⇒ String
If present, results are restricted to the specified partition previously
created using PartitionQuery. There must be an exact match for the values of
fields common to this message and the PartitionQueryRequest message used to
create this partition_token.
Corresponds to the JSON property partitionToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
2745 2746 2747 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2745 def partition_token @partition_token end |
#query_mode ⇒ String
Used to control the amount of debugging information returned in ResultSetStats.
If partition_token is set, query_mode can only be set to QueryMode.NORMAL.
Corresponds to the JSON property queryMode
2751 2752 2753 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2751 def query_mode @query_mode end |
#query_options ⇒ Google::Apis::SpannerV1::QueryOptions
Query optimizer configuration.
Corresponds to the JSON property queryOptions
2756 2757 2758 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2756 def @query_options end |
#request_options ⇒ Google::Apis::SpannerV1::RequestOptions
Common request options for various APIs.
Corresponds to the JSON property requestOptions
2761 2762 2763 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2761 def @request_options end |
#resume_token ⇒ String
If this request is resuming a previously interrupted SQL statement execution,
resume_token should be copied from the last PartialResultSet yielded before
the interruption. Doing this enables the new SQL statement execution to resume
where the last one left off. The rest of the request parameters must exactly
match the request that yielded this token.
Corresponds to the JSON property resumeToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
2771 2772 2773 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2771 def resume_token @resume_token end |
#seqno ⇒ Fixnum
A per-transaction sequence number used to identify this request. This field
makes each request idempotent such that if the request is received multiple
times, at most one succeeds. The sequence number must be monotonically
increasing within the transaction. If a request arrives for the first time
with an out-of-order sequence number, the transaction can be aborted. Replays
of previously handled requests yield the same response as the first execution.
Required for DML statements. Ignored for queries.
Corresponds to the JSON property seqno
2782 2783 2784 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2782 def seqno @seqno end |
#sql ⇒ String
Required. The SQL string.
Corresponds to the JSON property sql
2787 2788 2789 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2787 def sql @sql end |
#transaction ⇒ Google::Apis::SpannerV1::TransactionSelector
This message is used to select the transaction in which a Read or ExecuteSql
call runs. See TransactionOptions for more information about transactions.
Corresponds to the JSON property transaction
2793 2794 2795 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2793 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2800 def update!(**args) @data_boost_enabled = args[:data_boost_enabled] if args.key?(:data_boost_enabled) @directed_read_options = args[:directed_read_options] if args.key?(:directed_read_options) @last_statement = args[:last_statement] if args.key?(:last_statement) @param_types = args[:param_types] if args.key?(:param_types) @params = args[:params] if args.key?(:params) @partition_token = args[:partition_token] if args.key?(:partition_token) @query_mode = args[:query_mode] if args.key?(:query_mode) @query_options = args[:query_options] if args.key?(:query_options) @request_options = args[:request_options] if args.key?(:request_options) @resume_token = args[:resume_token] if args.key?(:resume_token) @seqno = args[:seqno] if args.key?(:seqno) @sql = args[:sql] if args.key?(:sql) @transaction = args[:transaction] if args.key?(:transaction) end |