Class: Google::Apis::SpannerV1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Message representing a single field of a struct.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



2975
2976
2977
# File 'lib/google/apis/spanner_v1/classes.rb', line 2975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the field. For reads, this is the column name. For SQL queries, it is the column alias (e.g., "Word" in the query "SELECT 'hello' AS Word"), or the column name (e.g., "ColName" in the query "SELECT ColName FROM Table" ). Some columns might have an empty name (e.g., "SELECT UPPER(ColName)"). Note that a query result can contain multiple fields with the same name. Corresponds to the JSON property name

Returns:

  • (String)


2967
2968
2969
# File 'lib/google/apis/spanner_v1/classes.rb', line 2967

def name
  @name
end

#typeGoogle::Apis::SpannerV1::Type

Type indicates the type of a Cloud Spanner value, as might be stored in a table cell or returned from an SQL query. Corresponds to the JSON property type



2973
2974
2975
# File 'lib/google/apis/spanner_v1/classes.rb', line 2973

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2980
2981
2982
2983
# File 'lib/google/apis/spanner_v1/classes.rb', line 2980

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end