Class: Google::Apis::SpannerV1::FreeInstanceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::FreeInstanceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Free instance specific metadata that is kept even after an instance has been upgraded for tracking purposes.
Instance Attribute Summary collapse
-
#expire_behavior ⇒ String
Specifies the expiration behavior of a free instance.
-
#expire_time ⇒ String
Output only.
-
#upgrade_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FreeInstanceMetadata
constructor
A new instance of FreeInstanceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FreeInstanceMetadata
Returns a new instance of FreeInstanceMetadata.
2927 2928 2929 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_behavior ⇒ String
Specifies the expiration behavior of a free instance. The default of
ExpireBehavior is REMOVE_AFTER_GRACE_PERIOD. This can be modified during or
after creation, and before expiration.
Corresponds to the JSON property expireBehavior
2911 2912 2913 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2911 def expire_behavior @expire_behavior end |
#expire_time ⇒ String
Output only. Timestamp after which the instance will either be upgraded or
scheduled for deletion after a grace period. ExpireBehavior is used to choose
between upgrading or scheduling the free instance for deletion. This timestamp
is set during the creation of a free instance.
Corresponds to the JSON property expireTime
2919 2920 2921 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2919 def expire_time @expire_time end |
#upgrade_time ⇒ String
Output only. If present, the timestamp at which the free instance was upgraded
to a provisioned instance.
Corresponds to the JSON property upgradeTime
2925 2926 2927 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2925 def upgrade_time @upgrade_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2932 2933 2934 2935 2936 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 2932 def update!(**args) @expire_behavior = args[:expire_behavior] if args.key?(:expire_behavior) @expire_time = args[:expire_time] if args.key?(:expire_time) @upgrade_time = args[:upgrade_time] if args.key?(:upgrade_time) end |