Class: Google::Apis::SpannerV1::IndexAdvice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Recommendation to add new indexes to run queries more efficiently.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IndexAdvice

Returns a new instance of IndexAdvice.



3201
3202
3203
# File 'lib/google/apis/spanner_v1/classes.rb', line 3201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ddlArray<String>

Optional. DDL statements to add new indexes that will improve the query. Corresponds to the JSON property ddl

Returns:

  • (Array<String>)


3192
3193
3194
# File 'lib/google/apis/spanner_v1/classes.rb', line 3192

def ddl
  @ddl
end

#improvement_factorFloat

Optional. Estimated latency improvement factor. For example if the query currently takes 500 ms to run and the estimated latency with new indexes is 100 ms this field will be 5. Corresponds to the JSON property improvementFactor

Returns:

  • (Float)


3199
3200
3201
# File 'lib/google/apis/spanner_v1/classes.rb', line 3199

def improvement_factor
  @improvement_factor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3206
3207
3208
3209
# File 'lib/google/apis/spanner_v1/classes.rb', line 3206

def update!(**args)
  @ddl = args[:ddl] if args.key?(:ddl)
  @improvement_factor = args[:improvement_factor] if args.key?(:improvement_factor)
end