Class: Google::Apis::SpannerV1::IndexedHotKey
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::IndexedHotKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A message representing a (sparse) collection of hot keys for specific key buckets.
Instance Attribute Summary collapse
-
#sparse_hot_keys ⇒ Hash<String,Fixnum>
A (sparse) mapping from key bucket index to the index of the specific hot row key for that key bucket.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IndexedHotKey
constructor
A new instance of IndexedHotKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IndexedHotKey
Returns a new instance of IndexedHotKey.
3224 3225 3226 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sparse_hot_keys ⇒ Hash<String,Fixnum>
A (sparse) mapping from key bucket index to the index of the specific hot row
key for that key bucket. The index of the hot row key can be translated to the
actual row key via the ScanData.VisualizationData.indexed_keys repeated field.
Corresponds to the JSON property sparseHotKeys
3222 3223 3224 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3222 def sparse_hot_keys @sparse_hot_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3229 3230 3231 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3229 def update!(**args) @sparse_hot_keys = args[:sparse_hot_keys] if args.key?(:sparse_hot_keys) end |