Class: Google::Apis::SpannerV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

An isolated set of Cloud Spanner resources on which databases can be hosted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



3307
3308
3309
# File 'lib/google/apis/spanner_v1/classes.rb', line 3307

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_configGoogle::Apis::SpannerV1::AutoscalingConfig

Autoscaling configuration for an instance. Corresponds to the JSON property autoscalingConfig



3177
3178
3179
# File 'lib/google/apis/spanner_v1/classes.rb', line 3177

def autoscaling_config
  @autoscaling_config
end

#configString

Required. The name of the instance's configuration. Values are of the form projects//instanceConfigs/. See also InstanceConfig and ListInstanceConfigs. Corresponds to the JSON property config

Returns:

  • (String)


3183
3184
3185
# File 'lib/google/apis/spanner_v1/classes.rb', line 3183

def config
  @config
end

#create_timeString

Output only. The time at which the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3188
3189
3190
# File 'lib/google/apis/spanner_v1/classes.rb', line 3188

def create_time
  @create_time
end

#default_backup_schedule_typeString

Optional. Controls the default backup schedule behavior for new databases within the instance. By default, a backup schedule is created automatically when a new database is created in a new instance. Note that the AUTOMATIC value isn't permitted for free instances, as backups and backup schedules aren' t supported for free instances. In the GetInstance or ListInstances response, if the value of default_backup_schedule_type isn't set, or set to NONE, Spanner doesn't create a default backup schedule for new databases in the instance. Corresponds to the JSON property defaultBackupScheduleType

Returns:

  • (String)


3200
3201
3202
# File 'lib/google/apis/spanner_v1/classes.rb', line 3200

def default_backup_schedule_type
  @default_backup_schedule_type
end

#display_nameString

Required. The descriptive name for this instance as it appears in UIs. Must be unique per project and between 4 and 30 characters in length. Corresponds to the JSON property displayName

Returns:

  • (String)


3206
3207
3208
# File 'lib/google/apis/spanner_v1/classes.rb', line 3206

def display_name
  @display_name
end

#editionString

Optional. The Edition of the current instance. Corresponds to the JSON property edition

Returns:

  • (String)


3211
3212
3213
# File 'lib/google/apis/spanner_v1/classes.rb', line 3211

def edition
  @edition
end

#endpoint_urisArray<String>

Deprecated. This field is not populated. Corresponds to the JSON property endpointUris

Returns:

  • (Array<String>)


3216
3217
3218
# File 'lib/google/apis/spanner_v1/classes.rb', line 3216

def endpoint_uris
  @endpoint_uris
end

#free_instance_metadataGoogle::Apis::SpannerV1::FreeInstanceMetadata

Free instance specific metadata that is kept even after an instance has been upgraded for tracking purposes. Corresponds to the JSON property freeInstanceMetadata



3222
3223
3224
# File 'lib/google/apis/spanner_v1/classes.rb', line 3222

def 
  @free_instance_metadata
end

#instance_typeString

The InstanceType of the current instance. Corresponds to the JSON property instanceType

Returns:

  • (String)


3227
3228
3229
# File 'lib/google/apis/spanner_v1/classes.rb', line 3227

def instance_type
  @instance_type
end

#labelsHash<String,String>

Cloud Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies. Cloud Labels can be used to filter collections of resources. They can be used to control how resource metrics are aggregated. And they can be used as arguments to policy management rules (e.g. route, firewall, load balancing, etc.). * Label keys must be between 1 and 63 characters long and must conform to the following regular expression: a-z0, 62. * Label values must be between 0 and 63 characters long and must conform to the regular expression `[a-z0-9_-]`0,63. * No more than 64 labels can be associated with a given resource. See https://goo.gl/xmQnxf for more information on and examples of labels. If you plan to use labels in your own code, please note that additional characters may be allowed in the future. And so you are advised to use an internal label representation, such as JSON, which doesn't rely upon specific characters being disallowed. For example, representing labels as the string: name + "" + value would prove problematic if we were to allow "" in a future release. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3247
3248
3249
# File 'lib/google/apis/spanner_v1/classes.rb', line 3247

def labels
  @labels
end

#nameString

Required. A unique identifier for the instance, which cannot be changed after the instance is created. Values are of the form projects//instances/a-z*[a-z0- 9]. The final segment of the name must be between 2 and 64 characters in length. Corresponds to the JSON property name

Returns:

  • (String)


3255
3256
3257
# File 'lib/google/apis/spanner_v1/classes.rb', line 3255

def name
  @name
end

#node_countFixnum

The number of nodes allocated to this instance. At most, one of either node_count or processing_units should be present in the message. Users can set the node_count field to specify the target number of nodes allocated to the instance. If autoscaling is enabled, node_count is treated as an OUTPUT_ONLY field and reflects the current number of nodes allocated to the instance. This might be zero in API responses for instances that are not yet in the READY state. If the instance has varying node count across replicas ( achieved by setting asymmetric_autoscaling_options in the autoscaling configuration), the node_count set here is the maximum node count across all replicas. For more information, see Compute capacity, nodes, and processing units. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


3270
3271
3272
# File 'lib/google/apis/spanner_v1/classes.rb', line 3270

def node_count
  @node_count
end

#processing_unitsFixnum

The number of processing units allocated to this instance. At most, one of either processing_units or node_count should be present in the message. Users can set the processing_units field to specify the target number of processing units allocated to the instance. If autoscaling is enabled, processing_units is treated as an OUTPUT_ONLY field and reflects the current number of processing units allocated to the instance. This might be zero in API responses for instances that are not yet in the READY state. If the instance has varying processing units per replica (achieved by setting asymmetric_autoscaling_options in the autoscaling configuration), the processing_units set here is the maximum processing units across all replicas. For more information, see Compute capacity, nodes and processing units. Corresponds to the JSON property processingUnits

Returns:

  • (Fixnum)


3286
3287
3288
# File 'lib/google/apis/spanner_v1/classes.rb', line 3286

def processing_units
  @processing_units
end

#replica_compute_capacityArray<Google::Apis::SpannerV1::ReplicaComputeCapacity>

Output only. Lists the compute capacity per ReplicaSelection. A replica selection identifies a set of replicas with common properties. Replicas identified by a ReplicaSelection are scaled with the same compute capacity. Corresponds to the JSON property replicaComputeCapacity



3293
3294
3295
# File 'lib/google/apis/spanner_v1/classes.rb', line 3293

def replica_compute_capacity
  @replica_compute_capacity
end

#stateString

Output only. The current instance state. For CreateInstance, the state must be either omitted or set to CREATING. For UpdateInstance, the state must be either omitted or set to READY. Corresponds to the JSON property state

Returns:

  • (String)


3300
3301
3302
# File 'lib/google/apis/spanner_v1/classes.rb', line 3300

def state
  @state
end

#update_timeString

Output only. The time at which the instance was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3305
3306
3307
# File 'lib/google/apis/spanner_v1/classes.rb', line 3305

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3312
3313
3314
3315
3316
3317
3318
3319
3320
3321
3322
3323
3324
3325
3326
3327
3328
3329
# File 'lib/google/apis/spanner_v1/classes.rb', line 3312

def update!(**args)
  @autoscaling_config = args[:autoscaling_config] if args.key?(:autoscaling_config)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_backup_schedule_type = args[:default_backup_schedule_type] if args.key?(:default_backup_schedule_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @edition = args[:edition] if args.key?(:edition)
  @endpoint_uris = args[:endpoint_uris] if args.key?(:endpoint_uris)
  @free_instance_metadata = args[:free_instance_metadata] if args.key?(:free_instance_metadata)
  @instance_type = args[:instance_type] if args.key?(:instance_type)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @node_count = args[:node_count] if args.key?(:node_count)
  @processing_units = args[:processing_units] if args.key?(:processing_units)
  @replica_compute_capacity = args[:replica_compute_capacity] if args.key?(:replica_compute_capacity)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end