Class: Google::Apis::SpannerV1::InstanceOperationProgress
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::InstanceOperationProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Encapsulates progress related information for a Cloud Spanner long running instance operations.
Instance Attribute Summary collapse
-
#end_time ⇒ String
If set, the time at which this operation failed or was completed successfully.
-
#progress_percent ⇒ Fixnum
Percent completion of the operation.
-
#start_time ⇒ String
Time the request was received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceOperationProgress
constructor
A new instance of InstanceOperationProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceOperationProgress
Returns a new instance of InstanceOperationProgress.
3531 3532 3533 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
If set, the time at which this operation failed or was completed successfully.
Corresponds to the JSON property endTime
3519 3520 3521 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3519 def end_time @end_time end |
#progress_percent ⇒ Fixnum
Percent completion of the operation. Values are between 0 and 100 inclusive.
Corresponds to the JSON property progressPercent
3524 3525 3526 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3524 def progress_percent @progress_percent end |
#start_time ⇒ String
Time the request was received.
Corresponds to the JSON property startTime
3529 3530 3531 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3529 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3536 3537 3538 3539 3540 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3536 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @progress_percent = args[:progress_percent] if args.key?(:progress_percent) @start_time = args[:start_time] if args.key?(:start_time) end |