Class: Google::Apis::SpannerV1::KeyRangeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A message representing information for a key range (possibly one key).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyRangeInfo

Returns a new instance of KeyRangeInfo.



3904
3905
3906
# File 'lib/google/apis/spanner_v1/classes.rb', line 3904

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_valuesArray<Google::Apis::SpannerV1::ContextValue>

The list of context values for this key range. Corresponds to the JSON property contextValues



3859
3860
3861
# File 'lib/google/apis/spanner_v1/classes.rb', line 3859

def context_values
  @context_values
end

#end_key_indexFixnum

The index of the end key in indexed_keys. Corresponds to the JSON property endKeyIndex

Returns:

  • (Fixnum)


3864
3865
3866
# File 'lib/google/apis/spanner_v1/classes.rb', line 3864

def end_key_index
  @end_key_index
end

#infoGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property info



3870
3871
3872
# File 'lib/google/apis/spanner_v1/classes.rb', line 3870

def info
  @info
end

#keys_countFixnum

The number of keys this range covers. Corresponds to the JSON property keysCount

Returns:

  • (Fixnum)


3875
3876
3877
# File 'lib/google/apis/spanner_v1/classes.rb', line 3875

def keys_count
  @keys_count
end

#metricGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property metric



3881
3882
3883
# File 'lib/google/apis/spanner_v1/classes.rb', line 3881

def metric
  @metric
end

#start_key_indexFixnum

The index of the start key in indexed_keys. Corresponds to the JSON property startKeyIndex

Returns:

  • (Fixnum)


3886
3887
3888
# File 'lib/google/apis/spanner_v1/classes.rb', line 3886

def start_key_index
  @start_key_index
end

#time_offsetString

The time offset. This is the time since the start of the time interval. Corresponds to the JSON property timeOffset

Returns:

  • (String)


3891
3892
3893
# File 'lib/google/apis/spanner_v1/classes.rb', line 3891

def time_offset
  @time_offset
end

#unitGoogle::Apis::SpannerV1::LocalizedString

A message representing a user-facing string whose value may need to be translated before being displayed. Corresponds to the JSON property unit



3897
3898
3899
# File 'lib/google/apis/spanner_v1/classes.rb', line 3897

def unit
  @unit
end

#valueFloat

The value of the metric. Corresponds to the JSON property value

Returns:

  • (Float)


3902
3903
3904
# File 'lib/google/apis/spanner_v1/classes.rb', line 3902

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3909
3910
3911
3912
3913
3914
3915
3916
3917
3918
3919
# File 'lib/google/apis/spanner_v1/classes.rb', line 3909

def update!(**args)
  @context_values = args[:context_values] if args.key?(:context_values)
  @end_key_index = args[:end_key_index] if args.key?(:end_key_index)
  @info = args[:info] if args.key?(:info)
  @keys_count = args[:keys_count] if args.key?(:keys_count)
  @metric = args[:metric] if args.key?(:metric)
  @start_key_index = args[:start_key_index] if args.key?(:start_key_index)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @unit = args[:unit] if args.key?(:unit)
  @value = args[:value] if args.key?(:value)
end