Class: Google::Apis::SpannerV1::KeyRangeInfo
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::KeyRangeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A message representing information for a key range (possibly one key).
Instance Attribute Summary collapse
-
#context_values ⇒ Array<Google::Apis::SpannerV1::ContextValue>
The list of context values for this key range.
-
#end_key_index ⇒ Fixnum
The index of the end key in indexed_keys.
-
#info ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#keys_count ⇒ Fixnum
The number of keys this range covers.
-
#metric ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#start_key_index ⇒ Fixnum
The index of the start key in indexed_keys.
-
#time_offset ⇒ String
The time offset.
-
#unit ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#value ⇒ Float
The value of the metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyRangeInfo
constructor
A new instance of KeyRangeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyRangeInfo
Returns a new instance of KeyRangeInfo.
3819 3820 3821 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_values ⇒ Array<Google::Apis::SpannerV1::ContextValue>
The list of context values for this key range.
Corresponds to the JSON property contextValues
3774 3775 3776 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3774 def context_values @context_values end |
#end_key_index ⇒ Fixnum
The index of the end key in indexed_keys.
Corresponds to the JSON property endKeyIndex
3779 3780 3781 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3779 def end_key_index @end_key_index end |
#info ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property info
3785 3786 3787 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3785 def info @info end |
#keys_count ⇒ Fixnum
The number of keys this range covers.
Corresponds to the JSON property keysCount
3790 3791 3792 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3790 def keys_count @keys_count end |
#metric ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property metric
3796 3797 3798 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3796 def metric @metric end |
#start_key_index ⇒ Fixnum
The index of the start key in indexed_keys.
Corresponds to the JSON property startKeyIndex
3801 3802 3803 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3801 def start_key_index @start_key_index end |
#time_offset ⇒ String
The time offset. This is the time since the start of the time interval.
Corresponds to the JSON property timeOffset
3806 3807 3808 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3806 def time_offset @time_offset end |
#unit ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property unit
3812 3813 3814 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3812 def unit @unit end |
#value ⇒ Float
The value of the metric.
Corresponds to the JSON property value
3817 3818 3819 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3817 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3824 3825 3826 3827 3828 3829 3830 3831 3832 3833 3834 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3824 def update!(**args) @context_values = args[:context_values] if args.key?(:context_values) @end_key_index = args[:end_key_index] if args.key?(:end_key_index) @info = args[:info] if args.key?(:info) @keys_count = args[:keys_count] if args.key?(:keys_count) @metric = args[:metric] if args.key?(:metric) @start_key_index = args[:start_key_index] if args.key?(:start_key_index) @time_offset = args[:time_offset] if args.key?(:time_offset) @unit = args[:unit] if args.key?(:unit) @value = args[:value] if args.key?(:value) end |