Class: Google::Apis::SpannerV1::KeyRangeInfos
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::KeyRangeInfos
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A message representing a list of specific information for multiple key ranges.
Instance Attribute Summary collapse
-
#infos ⇒ Array<Google::Apis::SpannerV1::KeyRangeInfo>
The list individual KeyRangeInfos.
-
#total_size ⇒ Fixnum
The total size of the list of all KeyRangeInfos.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyRangeInfos
constructor
A new instance of KeyRangeInfos.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyRangeInfos
Returns a new instance of KeyRangeInfos.
3945 3946 3947 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3945 def initialize(**args) update!(**args) end |
Instance Attribute Details
#infos ⇒ Array<Google::Apis::SpannerV1::KeyRangeInfo>
The list individual KeyRangeInfos.
Corresponds to the JSON property infos
3936 3937 3938 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3936 def infos @infos end |
#total_size ⇒ Fixnum
The total size of the list of all KeyRangeInfos. This may be larger than the
number of repeated messages above. If that is the case, this number may be
used to determine how many are not being shown.
Corresponds to the JSON property totalSize
3943 3944 3945 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3943 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3950 3951 3952 3953 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 3950 def update!(**args) @infos = args[:infos] if args.key?(:infos) @total_size = args[:total_size] if args.key?(:total_size) end |