Class: Google::Apis::SpannerV1::ListInstancePartitionOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The response for ListInstancePartitionOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancePartitionOperationsResponse

Returns a new instance of ListInstancePartitionOperationsResponse.



4150
4151
4152
# File 'lib/google/apis/spanner_v1/classes.rb', line 4150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

next_page_token can be sent in a subsequent ListInstancePartitionOperations call to fetch more of the matching metadata. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4133
4134
4135
# File 'lib/google/apis/spanner_v1/classes.rb', line 4133

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::SpannerV1::Operation>

The list of matching instance partition long-running operations. Each operation's name will be prefixed by the instance partition's name. The operation's metadata field type metadata.type_url describes the type of the metadata. Corresponds to the JSON property operations



4141
4142
4143
# File 'lib/google/apis/spanner_v1/classes.rb', line 4141

def operations
  @operations
end

#unreachable_instance_partitionsArray<String>

The list of unreachable instance partitions. It includes the names of instance partitions whose operation metadata could not be retrieved within instance_partition_deadline. Corresponds to the JSON property unreachableInstancePartitions

Returns:

  • (Array<String>)


4148
4149
4150
# File 'lib/google/apis/spanner_v1/classes.rb', line 4148

def unreachable_instance_partitions
  @unreachable_instance_partitions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4155
4156
4157
4158
4159
# File 'lib/google/apis/spanner_v1/classes.rb', line 4155

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable_instance_partitions = args[:unreachable_instance_partitions] if args.key?(:unreachable_instance_partitions)
end