Class: Google::Apis::SpannerV1::LocalizedString
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::LocalizedString
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A message representing a user-facing string whose value may need to be translated before being displayed.
Instance Attribute Summary collapse
-
#args ⇒ Hash<String,String>
A map of arguments used when creating the localized message.
-
#message ⇒ String
The canonical English version of this message.
-
#token ⇒ String
The token identifying the message, e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocalizedString
constructor
A new instance of LocalizedString.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocalizedString
Returns a new instance of LocalizedString.
4340 4341 4342 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4340 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Hash<String,String>
A map of arguments used when creating the localized message. Keys represent
parameter names which may be used by the localized version when substituting
dynamic values.
Corresponds to the JSON property args
4325 4326 4327 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4325 def args @args end |
#message ⇒ String
The canonical English version of this message. If no token is provided or the
front-end has no message associated with the token, this text will be
displayed as-is.
Corresponds to the JSON property message
4332 4333 4334 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4332 def @message end |
#token ⇒ String
The token identifying the message, e.g. 'METRIC_READ_CPU'. This should be
unique within the service.
Corresponds to the JSON property token
4338 4339 4340 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4338 def token @token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4345 4346 4347 4348 4349 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4345 def update!(**args) @args = args[:args] if args.key?(:args) @message = args[:message] if args.key?(:message) @token = args[:token] if args.key?(:token) end |