Class: Google::Apis::SpannerV1::Metric
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::Metric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A message representing the actual monitoring data, values for each key bucket over time, of a metric.
Instance Attribute Summary collapse
-
#aggregation ⇒ String
The aggregation function used to aggregate each key bucket Corresponds to the JSON property
aggregation. -
#category ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#derived ⇒ Google::Apis::SpannerV1::DerivedMetric
A message representing a derived metric.
-
#display_label ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#has_nonzero_data ⇒ Boolean
(also: #has_nonzero_data?)
Whether the metric has any non-zero data.
-
#hot_value ⇒ Float
The value that is considered hot for the metric.
-
#indexed_hot_keys ⇒ Hash<String,Google::Apis::SpannerV1::IndexedHotKey>
The (sparse) mapping from time index to an IndexedHotKey message, representing those time intervals for which there are hot keys.
-
#indexed_key_range_infos ⇒ Hash<String,Google::Apis::SpannerV1::IndexedKeyRangeInfos>
The (sparse) mapping from time interval index to an IndexedKeyRangeInfos message, representing those time intervals for which there are informational messages concerning key ranges.
-
#info ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#matrix ⇒ Google::Apis::SpannerV1::MetricMatrix
A message representing a matrix of floats.
-
#unit ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#visible ⇒ Boolean
(also: #visible?)
Whether the metric is visible to the end user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Metric
constructor
A new instance of Metric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Metric
Returns a new instance of Metric.
4521 4522 4523 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4521 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation ⇒ String
The aggregation function used to aggregate each key bucket
Corresponds to the JSON property aggregation
4452 4453 4454 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4452 def aggregation @aggregation end |
#category ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property category
4458 4459 4460 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4458 def category @category end |
#derived ⇒ Google::Apis::SpannerV1::DerivedMetric
A message representing a derived metric.
Corresponds to the JSON property derived
4463 4464 4465 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4463 def derived @derived end |
#display_label ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property displayLabel
4469 4470 4471 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4469 def display_label @display_label end |
#has_nonzero_data ⇒ Boolean Also known as: has_nonzero_data?
Whether the metric has any non-zero data.
Corresponds to the JSON property hasNonzeroData
4474 4475 4476 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4474 def has_nonzero_data @has_nonzero_data end |
#hot_value ⇒ Float
The value that is considered hot for the metric. On a per metric basis hotness
signals high utilization and something that might potentially be a cause for
concern by the end user. hot_value is used to calibrate and scale visual color
scales.
Corresponds to the JSON property hotValue
4483 4484 4485 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4483 def hot_value @hot_value end |
#indexed_hot_keys ⇒ Hash<String,Google::Apis::SpannerV1::IndexedHotKey>
The (sparse) mapping from time index to an IndexedHotKey message, representing
those time intervals for which there are hot keys.
Corresponds to the JSON property indexedHotKeys
4489 4490 4491 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4489 def indexed_hot_keys @indexed_hot_keys end |
#indexed_key_range_infos ⇒ Hash<String,Google::Apis::SpannerV1::IndexedKeyRangeInfos>
The (sparse) mapping from time interval index to an IndexedKeyRangeInfos
message, representing those time intervals for which there are informational
messages concerning key ranges.
Corresponds to the JSON property indexedKeyRangeInfos
4496 4497 4498 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4496 def indexed_key_range_infos @indexed_key_range_infos end |
#info ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property info
4502 4503 4504 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4502 def info @info end |
#matrix ⇒ Google::Apis::SpannerV1::MetricMatrix
A message representing a matrix of floats.
Corresponds to the JSON property matrix
4507 4508 4509 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4507 def matrix @matrix end |
#unit ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property unit
4513 4514 4515 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4513 def unit @unit end |
#visible ⇒ Boolean Also known as: visible?
Whether the metric is visible to the end user.
Corresponds to the JSON property visible
4518 4519 4520 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4518 def visible @visible end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4526 4527 4528 4529 4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4526 def update!(**args) @aggregation = args[:aggregation] if args.key?(:aggregation) @category = args[:category] if args.key?(:category) @derived = args[:derived] if args.key?(:derived) @display_label = args[:display_label] if args.key?(:display_label) @has_nonzero_data = args[:has_nonzero_data] if args.key?(:has_nonzero_data) @hot_value = args[:hot_value] if args.key?(:hot_value) @indexed_hot_keys = args[:indexed_hot_keys] if args.key?(:indexed_hot_keys) @indexed_key_range_infos = args[:indexed_key_range_infos] if args.key?(:indexed_key_range_infos) @info = args[:info] if args.key?(:info) @matrix = args[:matrix] if args.key?(:matrix) @unit = args[:unit] if args.key?(:unit) @visible = args[:visible] if args.key?(:visible) end |