Class: Google::Apis::SpannerV1::Metric
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::Metric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A message representing the actual monitoring data, values for each key bucket over time, of a metric.
Instance Attribute Summary collapse
-
#aggregation ⇒ String
The aggregation function used to aggregate each key bucket Corresponds to the JSON property
aggregation. -
#category ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#derived ⇒ Google::Apis::SpannerV1::DerivedMetric
A message representing a derived metric.
-
#display_label ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#has_nonzero_data ⇒ Boolean
(also: #has_nonzero_data?)
Whether the metric has any non-zero data.
-
#hot_value ⇒ Float
The value that is considered hot for the metric.
-
#indexed_hot_keys ⇒ Hash<String,Google::Apis::SpannerV1::IndexedHotKey>
The (sparse) mapping from time index to an IndexedHotKey message, representing those time intervals for which there are hot keys.
-
#indexed_key_range_infos ⇒ Hash<String,Google::Apis::SpannerV1::IndexedKeyRangeInfos>
The (sparse) mapping from time interval index to an IndexedKeyRangeInfos message, representing those time intervals for which there are informational messages concerning key ranges.
-
#info ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#matrix ⇒ Google::Apis::SpannerV1::MetricMatrix
A message representing a matrix of floats.
-
#unit ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be translated before being displayed.
-
#visible ⇒ Boolean
(also: #visible?)
Whether the metric is visible to the end user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Metric
constructor
A new instance of Metric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Metric
Returns a new instance of Metric.
4429 4430 4431 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation ⇒ String
The aggregation function used to aggregate each key bucket
Corresponds to the JSON property aggregation
4360 4361 4362 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4360 def aggregation @aggregation end |
#category ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property category
4366 4367 4368 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4366 def category @category end |
#derived ⇒ Google::Apis::SpannerV1::DerivedMetric
A message representing a derived metric.
Corresponds to the JSON property derived
4371 4372 4373 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4371 def derived @derived end |
#display_label ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property displayLabel
4377 4378 4379 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4377 def display_label @display_label end |
#has_nonzero_data ⇒ Boolean Also known as: has_nonzero_data?
Whether the metric has any non-zero data.
Corresponds to the JSON property hasNonzeroData
4382 4383 4384 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4382 def has_nonzero_data @has_nonzero_data end |
#hot_value ⇒ Float
The value that is considered hot for the metric. On a per metric basis hotness
signals high utilization and something that might potentially be a cause for
concern by the end user. hot_value is used to calibrate and scale visual color
scales.
Corresponds to the JSON property hotValue
4391 4392 4393 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4391 def hot_value @hot_value end |
#indexed_hot_keys ⇒ Hash<String,Google::Apis::SpannerV1::IndexedHotKey>
The (sparse) mapping from time index to an IndexedHotKey message, representing
those time intervals for which there are hot keys.
Corresponds to the JSON property indexedHotKeys
4397 4398 4399 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4397 def indexed_hot_keys @indexed_hot_keys end |
#indexed_key_range_infos ⇒ Hash<String,Google::Apis::SpannerV1::IndexedKeyRangeInfos>
The (sparse) mapping from time interval index to an IndexedKeyRangeInfos
message, representing those time intervals for which there are informational
messages concerning key ranges.
Corresponds to the JSON property indexedKeyRangeInfos
4404 4405 4406 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4404 def indexed_key_range_infos @indexed_key_range_infos end |
#info ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property info
4410 4411 4412 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4410 def info @info end |
#matrix ⇒ Google::Apis::SpannerV1::MetricMatrix
A message representing a matrix of floats.
Corresponds to the JSON property matrix
4415 4416 4417 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4415 def matrix @matrix end |
#unit ⇒ Google::Apis::SpannerV1::LocalizedString
A message representing a user-facing string whose value may need to be
translated before being displayed.
Corresponds to the JSON property unit
4421 4422 4423 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4421 def unit @unit end |
#visible ⇒ Boolean Also known as: visible?
Whether the metric is visible to the end user.
Corresponds to the JSON property visible
4426 4427 4428 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4426 def visible @visible end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4434 def update!(**args) @aggregation = args[:aggregation] if args.key?(:aggregation) @category = args[:category] if args.key?(:category) @derived = args[:derived] if args.key?(:derived) @display_label = args[:display_label] if args.key?(:display_label) @has_nonzero_data = args[:has_nonzero_data] if args.key?(:has_nonzero_data) @hot_value = args[:hot_value] if args.key?(:hot_value) @indexed_hot_keys = args[:indexed_hot_keys] if args.key?(:indexed_hot_keys) @indexed_key_range_infos = args[:indexed_key_range_infos] if args.key?(:indexed_key_range_infos) @info = args[:info] if args.key?(:info) @matrix = args[:matrix] if args.key?(:matrix) @unit = args[:unit] if args.key?(:unit) @visible = args[:visible] if args.key?(:visible) end |