Class: Google::Apis::SpannerV1::ModValue
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ModValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Returns the value and associated metadata for a particular field of the Mod.
Instance Attribute Summary collapse
-
#column_metadata_index ⇒ Fixnum
Index within the repeated column_metadata field, to obtain the column metadata for the column that was modified.
-
#value ⇒ Object
The value of the column.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ModValue
constructor
A new instance of ModValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ModValue
Returns a new instance of ModValue.
4622 4623 4624 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4622 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_metadata_index ⇒ Fixnum
Index within the repeated column_metadata field, to obtain the column metadata
for the column that was modified.
Corresponds to the JSON property columnMetadataIndex
4615 4616 4617 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4615 def @column_metadata_index end |
#value ⇒ Object
The value of the column.
Corresponds to the JSON property value
4620 4621 4622 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4620 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4627 4628 4629 4630 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4627 def update!(**args) @column_metadata_index = args[:column_metadata_index] if args.key?(:column_metadata_index) @value = args[:value] if args.key?(:value) end |