Class: Google::Apis::SpannerV1::MoveInstanceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for MoveInstance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MoveInstanceRequest

Returns a new instance of MoveInstanceRequest.



4590
4591
4592
# File 'lib/google/apis/spanner_v1/classes.rb', line 4590

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_configString

Required. The target instance configuration where to move the instance. Values are of the form projects//instanceConfigs/. Corresponds to the JSON property targetConfig

Returns:

  • (String)


4582
4583
4584
# File 'lib/google/apis/spanner_v1/classes.rb', line 4582

def target_config
  @target_config
end

#target_database_move_configsArray<Google::Apis::SpannerV1::DatabaseMoveConfig>

Optional. The configuration for each database in the target instance configuration. Corresponds to the JSON property targetDatabaseMoveConfigs



4588
4589
4590
# File 'lib/google/apis/spanner_v1/classes.rb', line 4588

def target_database_move_configs
  @target_database_move_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4595
4596
4597
4598
# File 'lib/google/apis/spanner_v1/classes.rb', line 4595

def update!(**args)
  @target_config = args[:target_config] if args.key?(:target_config)
  @target_database_move_configs = args[:target_database_move_configs] if args.key?(:target_database_move_configs)
end