Class: Google::Apis::SpannerV1::MoveOutEvent
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::MoveOutEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Describes move-out of the key ranges out of the change stream partition identified by partition_token. To maintain processing the changes for a particular key in timestamp order, the query processing the MoveOutEvent in the partition identified by partition_token should inform the queries processing the destination partitions that they can unblock and proceed processing records past the commit_timestamp.
Instance Attribute Summary collapse
-
#destination_partition_token ⇒ String
An unique partition identifier describing the destination change stream partition that will record changes for the key range that is moving out of this partition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MoveOutEvent
constructor
A new instance of MoveOutEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MoveOutEvent
Returns a new instance of MoveOutEvent.
4617 4618 4619 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_partition_token ⇒ String
An unique partition identifier describing the destination change stream
partition that will record changes for the key range that is moving out of
this partition.
Corresponds to the JSON property destinationPartitionToken
4615 4616 4617 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4615 def destination_partition_token @destination_partition_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4622 4623 4624 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4622 def update!(**args) @destination_partition_token = args[:destination_partition_token] if args.key?(:destination_partition_token) end |