Class: Google::Apis::SpannerV1::MultiplexedSessionPrecommitToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiplexedSessionPrecommitToken

Returns a new instance of MultiplexedSessionPrecommitToken.



4739
4740
4741
# File 'lib/google/apis/spanner_v1/classes.rb', line 4739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#precommit_tokenString

Opaque precommit token. Corresponds to the JSON property precommitToken NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4730
4731
4732
# File 'lib/google/apis/spanner_v1/classes.rb', line 4730

def precommit_token
  @precommit_token
end

#seq_numFixnum

An incrementing seq number is generated on every precommit token that is returned. Clients should remember the precommit token with the highest sequence number from the current transaction attempt. Corresponds to the JSON property seqNum

Returns:

  • (Fixnum)


4737
4738
4739
# File 'lib/google/apis/spanner_v1/classes.rb', line 4737

def seq_num
  @seq_num
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4744
4745
4746
4747
# File 'lib/google/apis/spanner_v1/classes.rb', line 4744

def update!(**args)
  @precommit_token = args[:precommit_token] if args.key?(:precommit_token)
  @seq_num = args[:seq_num] if args.key?(:seq_num)
end