Class: Google::Apis::SpannerV1::Mutation
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::Mutation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A modification to one or more Cloud Spanner rows. Mutations can be applied to a Cloud Spanner database by sending them in a Commit call.
Instance Attribute Summary collapse
-
#ack ⇒ Google::Apis::SpannerV1::Ack
Arguments to ack operations.
-
#delete ⇒ Google::Apis::SpannerV1::Delete
Arguments to delete operations.
-
#insert ⇒ Google::Apis::SpannerV1::Write
Arguments to insert, update, insert_or_update, and replace operations.
-
#insert_or_update ⇒ Google::Apis::SpannerV1::Write
Arguments to insert, update, insert_or_update, and replace operations.
-
#replace ⇒ Google::Apis::SpannerV1::Write
Arguments to insert, update, insert_or_update, and replace operations.
-
#send_prop ⇒ Google::Apis::SpannerV1::SendProp
Arguments to send operations.
-
#update ⇒ Google::Apis::SpannerV1::Write
Arguments to insert, update, insert_or_update, and replace operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Mutation
constructor
A new instance of Mutation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Mutation
Returns a new instance of Mutation.
4783 4784 4785 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ack ⇒ Google::Apis::SpannerV1::Ack
Arguments to ack operations.
Corresponds to the JSON property ack
4751 4752 4753 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4751 def ack @ack end |
#delete ⇒ Google::Apis::SpannerV1::Delete
Arguments to delete operations.
Corresponds to the JSON property delete
4756 4757 4758 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4756 def delete @delete end |
#insert ⇒ Google::Apis::SpannerV1::Write
Arguments to insert, update, insert_or_update, and replace operations.
Corresponds to the JSON property insert
4761 4762 4763 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4761 def insert @insert end |
#insert_or_update ⇒ Google::Apis::SpannerV1::Write
Arguments to insert, update, insert_or_update, and replace operations.
Corresponds to the JSON property insertOrUpdate
4766 4767 4768 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4766 def insert_or_update @insert_or_update end |
#replace ⇒ Google::Apis::SpannerV1::Write
Arguments to insert, update, insert_or_update, and replace operations.
Corresponds to the JSON property replace
4771 4772 4773 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4771 def replace @replace end |
#send_prop ⇒ Google::Apis::SpannerV1::SendProp
Arguments to send operations.
Corresponds to the JSON property send
4776 4777 4778 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4776 def send_prop @send_prop end |
#update ⇒ Google::Apis::SpannerV1::Write
Arguments to insert, update, insert_or_update, and replace operations.
Corresponds to the JSON property update
4781 4782 4783 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4781 def update @update end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4788 4789 4790 4791 4792 4793 4794 4795 4796 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 4788 def update!(**args) @ack = args[:ack] if args.key?(:ack) @delete = args[:delete] if args.key?(:delete) @insert = args[:insert] if args.key?(:insert) @insert_or_update = args[:insert_or_update] if args.key?(:insert_or_update) @replace = args[:replace] if args.key?(:replace) @send_prop = args[:send_prop] if args.key?(:send_prop) @update = args[:update] if args.key?(:update) end |