Class: Google::Apis::SpannerV1::Mutation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

A modification to one or more Cloud Spanner rows. Mutations can be applied to a Cloud Spanner database by sending them in a Commit call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Mutation

Returns a new instance of Mutation.



4698
4699
4700
# File 'lib/google/apis/spanner_v1/classes.rb', line 4698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ackGoogle::Apis::SpannerV1::Ack

Arguments to ack operations. Corresponds to the JSON property ack



4666
4667
4668
# File 'lib/google/apis/spanner_v1/classes.rb', line 4666

def ack
  @ack
end

#deleteGoogle::Apis::SpannerV1::Delete

Arguments to delete operations. Corresponds to the JSON property delete



4671
4672
4673
# File 'lib/google/apis/spanner_v1/classes.rb', line 4671

def delete
  @delete
end

#insertGoogle::Apis::SpannerV1::Write

Arguments to insert, update, insert_or_update, and replace operations. Corresponds to the JSON property insert



4676
4677
4678
# File 'lib/google/apis/spanner_v1/classes.rb', line 4676

def insert
  @insert
end

#insert_or_updateGoogle::Apis::SpannerV1::Write

Arguments to insert, update, insert_or_update, and replace operations. Corresponds to the JSON property insertOrUpdate



4681
4682
4683
# File 'lib/google/apis/spanner_v1/classes.rb', line 4681

def insert_or_update
  @insert_or_update
end

#replaceGoogle::Apis::SpannerV1::Write

Arguments to insert, update, insert_or_update, and replace operations. Corresponds to the JSON property replace



4686
4687
4688
# File 'lib/google/apis/spanner_v1/classes.rb', line 4686

def replace
  @replace
end

#send_propGoogle::Apis::SpannerV1::SendProp

Arguments to send operations. Corresponds to the JSON property send



4691
4692
4693
# File 'lib/google/apis/spanner_v1/classes.rb', line 4691

def send_prop
  @send_prop
end

#updateGoogle::Apis::SpannerV1::Write

Arguments to insert, update, insert_or_update, and replace operations. Corresponds to the JSON property update



4696
4697
4698
# File 'lib/google/apis/spanner_v1/classes.rb', line 4696

def update
  @update
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4703
4704
4705
4706
4707
4708
4709
4710
4711
# File 'lib/google/apis/spanner_v1/classes.rb', line 4703

def update!(**args)
  @ack = args[:ack] if args.key?(:ack)
  @delete = args[:delete] if args.key?(:delete)
  @insert = args[:insert] if args.key?(:insert)
  @insert_or_update = args[:insert_or_update] if args.key?(:insert_or_update)
  @replace = args[:replace] if args.key?(:replace)
  @send_prop = args[:send_prop] if args.key?(:send_prop)
  @update = args[:update] if args.key?(:update)
end