Class: Google::Apis::SpannerV1::Partition
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::Partition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Information returned for each partition returned in a PartitionResponse.
Instance Attribute Summary collapse
-
#partition_token ⇒ String
This token can be passed to
Read,StreamingRead,ExecuteSql, orExecuteStreamingSqlrequests to restrict the results to those identified by this partition token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Partition
constructor
A new instance of Partition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Partition
Returns a new instance of Partition.
5059 5060 5061 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partition_token ⇒ String
This token can be passed to Read, StreamingRead, ExecuteSql, or
ExecuteStreamingSql requests to restrict the results to those identified by
this partition token.
Corresponds to the JSON property partitionToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
5057 5058 5059 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5057 def partition_token @partition_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5064 5065 5066 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5064 def update!(**args) @partition_token = args[:partition_token] if args.key?(:partition_token) end |