Class: Google::Apis::SpannerV1::PartitionOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Options for a PartitionQueryRequest and PartitionReadRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartitionOptions

Returns a new instance of PartitionOptions.



5137
5138
5139
# File 'lib/google/apis/spanner_v1/classes.rb', line 5137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_partitionsFixnum

Note: This hint is currently ignored by PartitionQuery and PartitionRead requests. The desired maximum number of partitions to return. For example, this might be set to the number of workers available. The default for this option is currently 10,000. The maximum value is currently 200,000. This is only a hint. The actual number of partitions returned can be smaller or larger than this maximum count request. Corresponds to the JSON property maxPartitions

Returns:

  • (Fixnum)


5127
5128
5129
# File 'lib/google/apis/spanner_v1/classes.rb', line 5127

def max_partitions
  @max_partitions
end

#partition_size_bytesFixnum

Note: This hint is currently ignored by PartitionQuery and PartitionRead requests. The desired data size for each partition generated. The default for this option is currently 1 GiB. This is only a hint. The actual size of each partition can be smaller or larger than this size request. Corresponds to the JSON property partitionSizeBytes

Returns:

  • (Fixnum)


5135
5136
5137
# File 'lib/google/apis/spanner_v1/classes.rb', line 5135

def partition_size_bytes
  @partition_size_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5142
5143
5144
5145
# File 'lib/google/apis/spanner_v1/classes.rb', line 5142

def update!(**args)
  @max_partitions = args[:max_partitions] if args.key?(:max_partitions)
  @partition_size_bytes = args[:partition_size_bytes] if args.key?(:partition_size_bytes)
end