Class: Google::Apis::SpannerV1::PartitionQueryRequest
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::PartitionQueryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The request for PartitionQuery
Instance Attribute Summary collapse
-
#param_types ⇒ Hash<String,Google::Apis::SpannerV1::Type>
Optional.
-
#params ⇒ Hash<String,Object>
Optional.
-
#partition_options ⇒ Google::Apis::SpannerV1::PartitionOptions
Options for a
PartitionQueryRequestandPartitionReadRequest. -
#sql ⇒ String
Required.
-
#transaction ⇒ Google::Apis::SpannerV1::TransactionSelector
This message is used to select the transaction in which a Read or ExecuteSql call runs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartitionQueryRequest
constructor
A new instance of PartitionQueryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartitionQueryRequest
Returns a new instance of PartitionQueryRequest.
5281 5282 5283 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5281 def initialize(**args) update!(**args) end |
Instance Attribute Details
#param_types ⇒ Hash<String,Google::Apis::SpannerV1::Type>
Optional. It isn't always possible for Cloud Spanner to infer the right SQL
type from a JSON value. For example, values of type BYTES and values of type
STRING both appear in params as JSON strings. In these cases, param_types
can be used to specify the exact SQL type for some or all of the SQL query
parameters. See the definition of Type for more information about SQL types.
Corresponds to the JSON property paramTypes
5244 5245 5246 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5244 def param_types @param_types end |
#params ⇒ Hash<String,Object>
Optional. Parameter names and values that bind to placeholders in the SQL
string. A parameter placeholder consists of the @ character followed by the
parameter name (for example, @firstName). Parameter names can contain
letters, numbers, and underscores. Parameters can appear anywhere that a
literal value is expected. The same parameter name can be used more than once,
for example: "WHERE id > @msg_id AND id < @msg_id + 100" It's an error to
execute a SQL statement with unbound parameters.
Corresponds to the JSON property params
5255 5256 5257 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5255 def params @params end |
#partition_options ⇒ Google::Apis::SpannerV1::PartitionOptions
Options for a PartitionQueryRequest and PartitionReadRequest.
Corresponds to the JSON property partitionOptions
5260 5261 5262 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5260 def @partition_options end |
#sql ⇒ String
Required. The query request to generate partitions for. The request fails if
the query isn't root partitionable. For a query to be root partitionable, it
needs to satisfy a few conditions. For example, if the query execution plan
contains a distributed union operator, then it must be the first operator in
the plan. For more information about other conditions, see Read data in
parallel.
The query request must not contain DML commands, such as INSERT, UPDATE,
or DELETE. Use ExecuteStreamingSql with a PartitionedDml transaction for
large, partition-friendly DML operations.
Corresponds to the JSON property sql
5273 5274 5275 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5273 def sql @sql end |
#transaction ⇒ Google::Apis::SpannerV1::TransactionSelector
This message is used to select the transaction in which a Read or ExecuteSql
call runs. See TransactionOptions for more information about transactions.
Corresponds to the JSON property transaction
5279 5280 5281 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5279 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5286 5287 5288 5289 5290 5291 5292 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5286 def update!(**args) @param_types = args[:param_types] if args.key?(:param_types) @params = args[:params] if args.key?(:params) @partition_options = args[:partition_options] if args.key?(:partition_options) @sql = args[:sql] if args.key?(:sql) @transaction = args[:transaction] if args.key?(:transaction) end |