Class: Google::Apis::SpannerV1::PartitionReadRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The request for PartitionRead

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartitionReadRequest

Returns a new instance of PartitionReadRequest.



5251
5252
5253
# File 'lib/google/apis/spanner_v1/classes.rb', line 5251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<String>

The columns of table to be returned for each row matching this request. Corresponds to the JSON property columns

Returns:

  • (Array<String>)


5217
5218
5219
# File 'lib/google/apis/spanner_v1/classes.rb', line 5217

def columns
  @columns
end

#indexString

If non-empty, the name of an index on table. This index is used instead of the table primary key when interpreting key_set and sorting result rows. See key_set for further information. Corresponds to the JSON property index

Returns:

  • (String)


5224
5225
5226
# File 'lib/google/apis/spanner_v1/classes.rb', line 5224

def index
  @index
end

#key_setGoogle::Apis::SpannerV1::KeySet

KeySet defines a collection of Cloud Spanner keys and/or key ranges. All the keys are expected to be in the same table or index. The keys need not be sorted in any particular way. If the same key is specified multiple times in the set (for example if two ranges, two keys, or a key and a range overlap), Cloud Spanner behaves as if the key were only specified once. Corresponds to the JSON property keySet



5233
5234
5235
# File 'lib/google/apis/spanner_v1/classes.rb', line 5233

def key_set
  @key_set
end

#partition_optionsGoogle::Apis::SpannerV1::PartitionOptions

Options for a PartitionQueryRequest and PartitionReadRequest. Corresponds to the JSON property partitionOptions



5238
5239
5240
# File 'lib/google/apis/spanner_v1/classes.rb', line 5238

def partition_options
  @partition_options
end

#tableString

Required. The name of the table in the database to be read. Corresponds to the JSON property table

Returns:

  • (String)


5243
5244
5245
# File 'lib/google/apis/spanner_v1/classes.rb', line 5243

def table
  @table
end

#transactionGoogle::Apis::SpannerV1::TransactionSelector

This message is used to select the transaction in which a Read or ExecuteSql call runs. See TransactionOptions for more information about transactions. Corresponds to the JSON property transaction



5249
5250
5251
# File 'lib/google/apis/spanner_v1/classes.rb', line 5249

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5256
5257
5258
5259
5260
5261
5262
5263
# File 'lib/google/apis/spanner_v1/classes.rb', line 5256

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @index = args[:index] if args.key?(:index)
  @key_set = args[:key_set] if args.key?(:key_set)
  @partition_options = args[:partition_options] if args.key?(:partition_options)
  @table = args[:table] if args.key?(:table)
  @transaction = args[:transaction] if args.key?(:transaction)
end