Class: Google::Apis::SpannerV1::ReadRequest
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ReadRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The request for Read and StreamingRead.
Instance Attribute Summary collapse
-
#columns ⇒ Array<String>
Required.
-
#data_boost_enabled ⇒ Boolean
(also: #data_boost_enabled?)
If this is for a partitioned read and this field is set to
true, the request is executed with Spanner Data Boost independent compute resources. -
#directed_read_options ⇒ Google::Apis::SpannerV1::DirectedReadOptions
The
DirectedReadOptionscan be used to indicate which replicas or regions should be used for non-transactional reads or queries. -
#index ⇒ String
If non-empty, the name of an index on table.
-
#key_set ⇒ Google::Apis::SpannerV1::KeySet
KeySetdefines a collection of Cloud Spanner keys and/or key ranges. -
#limit ⇒ Fixnum
If greater than zero, only the first
limitrows are yielded. -
#lock_hint ⇒ String
Optional.
-
#order_by ⇒ String
Optional.
-
#partition_token ⇒ String
If present, results are restricted to the specified partition previously created using
PartitionRead. -
#request_options ⇒ Google::Apis::SpannerV1::RequestOptions
Common request options for various APIs.
-
#resume_token ⇒ String
If this request is resuming a previously interrupted read,
resume_tokenshould be copied from the last PartialResultSet yielded before the interruption. -
#table ⇒ String
Required.
-
#transaction ⇒ Google::Apis::SpannerV1::TransactionSelector
This message is used to select the transaction in which a Read or ExecuteSql call runs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReadRequest
constructor
A new instance of ReadRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReadRequest
Returns a new instance of ReadRequest.
5969 5970 5971 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5969 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<String>
Required. The columns of table to be returned for each row matching this
request.
Corresponds to the JSON property columns
5876 5877 5878 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5876 def columns @columns end |
#data_boost_enabled ⇒ Boolean Also known as: data_boost_enabled?
If this is for a partitioned read and this field is set to true, the request
is executed with Spanner Data Boost independent compute resources. If the
field is set to true but the request doesn't set partition_token, the API
returns an INVALID_ARGUMENT error.
Corresponds to the JSON property dataBoostEnabled
5884 5885 5886 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5884 def data_boost_enabled @data_boost_enabled end |
#directed_read_options ⇒ Google::Apis::SpannerV1::DirectedReadOptions
The DirectedReadOptions can be used to indicate which replicas or regions
should be used for non-transactional reads or queries. DirectedReadOptions
can only be specified for a read-only transaction, otherwise the API returns
an INVALID_ARGUMENT error.
Corresponds to the JSON property directedReadOptions
5893 5894 5895 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5893 def @directed_read_options end |
#index ⇒ String
If non-empty, the name of an index on table. This index is used instead of the
table primary key when interpreting key_set and sorting result rows. See
key_set for further information.
Corresponds to the JSON property index
5900 5901 5902 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5900 def index @index end |
#key_set ⇒ Google::Apis::SpannerV1::KeySet
KeySet defines a collection of Cloud Spanner keys and/or key ranges. All the
keys are expected to be in the same table or index. The keys need not be
sorted in any particular way. If the same key is specified multiple times in
the set (for example if two ranges, two keys, or a key and a range overlap),
Cloud Spanner behaves as if the key were only specified once.
Corresponds to the JSON property keySet
5909 5910 5911 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5909 def key_set @key_set end |
#limit ⇒ Fixnum
If greater than zero, only the first limit rows are yielded. If limit is
zero, the default is no limit. A limit can't be specified if partition_token
is set.
Corresponds to the JSON property limit
5916 5917 5918 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5916 def limit @limit end |
#lock_hint ⇒ String
Optional. Lock Hint for the request, it can only be used with read-write
transactions.
Corresponds to the JSON property lockHint
5922 5923 5924 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5922 def lock_hint @lock_hint end |
#order_by ⇒ String
Optional. Order for the returned rows. By default, Spanner returns result rows
in primary key order except for PartitionRead requests. For applications that
don't require rows to be returned in primary key (ORDER_BY_PRIMARY_KEY)
order, setting ORDER_BY_NO_ORDER option allows Spanner to optimize row
retrieval, resulting in lower latencies in certain cases (for example, bulk
point lookups).
Corresponds to the JSON property orderBy
5932 5933 5934 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5932 def order_by @order_by end |
#partition_token ⇒ String
If present, results are restricted to the specified partition previously
created using PartitionRead. There must be an exact match for the values of
fields common to this message and the PartitionReadRequest message used to
create this partition_token.
Corresponds to the JSON property partitionToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
5941 5942 5943 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5941 def partition_token @partition_token end |
#request_options ⇒ Google::Apis::SpannerV1::RequestOptions
Common request options for various APIs.
Corresponds to the JSON property requestOptions
5946 5947 5948 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5946 def @request_options end |
#resume_token ⇒ String
If this request is resuming a previously interrupted read, resume_token
should be copied from the last PartialResultSet yielded before the
interruption. Doing this enables the new read to resume where the last read
left off. The rest of the request parameters must exactly match the request
that yielded this token.
Corresponds to the JSON property resumeToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
5956 5957 5958 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5956 def resume_token @resume_token end |
#table ⇒ String
Required. The name of the table in the database to be read.
Corresponds to the JSON property table
5961 5962 5963 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5961 def table @table end |
#transaction ⇒ Google::Apis::SpannerV1::TransactionSelector
This message is used to select the transaction in which a Read or ExecuteSql
call runs. See TransactionOptions for more information about transactions.
Corresponds to the JSON property transaction
5967 5968 5969 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5967 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5974 5975 5976 5977 5978 5979 5980 5981 5982 5983 5984 5985 5986 5987 5988 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5974 def update!(**args) @columns = args[:columns] if args.key?(:columns) @data_boost_enabled = args[:data_boost_enabled] if args.key?(:data_boost_enabled) @directed_read_options = args[:directed_read_options] if args.key?(:directed_read_options) @index = args[:index] if args.key?(:index) @key_set = args[:key_set] if args.key?(:key_set) @limit = args[:limit] if args.key?(:limit) @lock_hint = args[:lock_hint] if args.key?(:lock_hint) @order_by = args[:order_by] if args.key?(:order_by) @partition_token = args[:partition_token] if args.key?(:partition_token) @request_options = args[:request_options] if args.key?(:request_options) @resume_token = args[:resume_token] if args.key?(:resume_token) @table = args[:table] if args.key?(:table) @transaction = args[:transaction] if args.key?(:transaction) end |