Class: Google::Apis::SpannerV1::ReplicaComputeCapacity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

ReplicaComputeCapacity describes the amount of server resources that are allocated to each replica identified by the replica selection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplicaComputeCapacity

Returns a new instance of ReplicaComputeCapacity.



6049
6050
6051
# File 'lib/google/apis/spanner_v1/classes.rb', line 6049

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#node_countFixnum

The number of nodes allocated to each replica. This may be zero in API responses for instances that are not yet in state READY. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


6036
6037
6038
# File 'lib/google/apis/spanner_v1/classes.rb', line 6036

def node_count
  @node_count
end

#processing_unitsFixnum

The number of processing units allocated to each replica. This may be zero in API responses for instances that are not yet in state READY. Corresponds to the JSON property processingUnits

Returns:

  • (Fixnum)


6042
6043
6044
# File 'lib/google/apis/spanner_v1/classes.rb', line 6042

def processing_units
  @processing_units
end

#replica_selectionGoogle::Apis::SpannerV1::InstanceReplicaSelection

ReplicaSelection identifies replicas with common properties. Corresponds to the JSON property replicaSelection



6047
6048
6049
# File 'lib/google/apis/spanner_v1/classes.rb', line 6047

def replica_selection
  @replica_selection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6054
6055
6056
6057
6058
# File 'lib/google/apis/spanner_v1/classes.rb', line 6054

def update!(**args)
  @node_count = args[:node_count] if args.key?(:node_count)
  @processing_units = args[:processing_units] if args.key?(:processing_units)
  @replica_selection = args[:replica_selection] if args.key?(:replica_selection)
end