Class: Google::Apis::SpannerV1::ReplicaInfo
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ReplicaInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Instance Attribute Summary collapse
-
#default_leader_location ⇒ Boolean
(also: #default_leader_location?)
If true, this location is designated as the default leader location where leader replicas are placed.
-
#location ⇒ String
The location of the serving resources, e.g., "us-central1".
-
#type ⇒ String
The type of replica.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplicaInfo
constructor
A new instance of ReplicaInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplicaInfo
Returns a new instance of ReplicaInfo.
6076 6077 6078 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_leader_location ⇒ Boolean Also known as: default_leader_location?
If true, this location is designated as the default leader location where
leader replicas are placed. See the region types documentation for more details.
Corresponds to the JSON property defaultLeaderLocation
6063 6064 6065 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6063 def default_leader_location @default_leader_location end |
#location ⇒ String
The location of the serving resources, e.g., "us-central1".
Corresponds to the JSON property location
6069 6070 6071 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6069 def location @location end |
#type ⇒ String
The type of replica.
Corresponds to the JSON property type
6074 6075 6076 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6074 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6081 6082 6083 6084 6085 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6081 def update!(**args) @default_leader_location = args[:default_leader_location] if args.key?(:default_leader_location) @location = args[:location] if args.key?(:location) @type = args[:type] if args.key?(:type) end |