Class: Google::Apis::SpannerV1::ReplicaInfo
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ReplicaInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Instance Attribute Summary collapse
-
#default_leader_location ⇒ Boolean
(also: #default_leader_location?)
If true, this location is designated as the default leader location where leader replicas are placed.
-
#location ⇒ String
The location of the serving resources, e.g., "us-central1".
-
#type ⇒ String
The type of replica.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplicaInfo
constructor
A new instance of ReplicaInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplicaInfo
Returns a new instance of ReplicaInfo.
5991 5992 5993 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_leader_location ⇒ Boolean Also known as: default_leader_location?
If true, this location is designated as the default leader location where
leader replicas are placed. See the region types documentation for more details.
Corresponds to the JSON property defaultLeaderLocation
5978 5979 5980 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5978 def default_leader_location @default_leader_location end |
#location ⇒ String
The location of the serving resources, e.g., "us-central1".
Corresponds to the JSON property location
5984 5985 5986 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5984 def location @location end |
#type ⇒ String
The type of replica.
Corresponds to the JSON property type
5989 5990 5991 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5989 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5996 5997 5998 5999 6000 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 5996 def update!(**args) @default_leader_location = args[:default_leader_location] if args.key?(:default_leader_location) @location = args[:location] if args.key?(:location) @type = args[:type] if args.key?(:type) end |