Class: Google::Apis::SpannerV1::RestoreDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the long-running operation returned by RestoreDatabase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreDatabaseMetadata

Returns a new instance of RestoreDatabaseMetadata.



6273
6274
6275
# File 'lib/google/apis/spanner_v1/classes.rb', line 6273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_infoGoogle::Apis::SpannerV1::BackupInfo

Information about a backup. Corresponds to the JSON property backupInfo



6230
6231
6232
# File 'lib/google/apis/spanner_v1/classes.rb', line 6230

def backup_info
  @backup_info
end

#cancel_timeString

The time at which cancellation of this operation was received. Operations. CancelOperation starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google. rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property cancelTime

Returns:

  • (String)


6242
6243
6244
# File 'lib/google/apis/spanner_v1/classes.rb', line 6242

def cancel_time
  @cancel_time
end

#nameString

Name of the database being created and restored to. Corresponds to the JSON property name

Returns:

  • (String)


6247
6248
6249
# File 'lib/google/apis/spanner_v1/classes.rb', line 6247

def name
  @name
end

#optimize_database_operation_nameString

If exists, the name of the long-running operation that will be used to track the post-restore optimization process to optimize the performance of the restored database, and remove the dependency on the restore source. The name is of the form projects//instances//databases//operations/ where the is the name of database being created and restored to. The metadata type of the long- running operation is OptimizeRestoredDatabaseMetadata. This long-running operation will be automatically created by the system after the RestoreDatabase long-running operation completes successfully. This operation will not be created if the restore was not successful. Corresponds to the JSON property optimizeDatabaseOperationName

Returns:

  • (String)


6260
6261
6262
# File 'lib/google/apis/spanner_v1/classes.rb', line 6260

def optimize_database_operation_name
  @optimize_database_operation_name
end

#progressGoogle::Apis::SpannerV1::OperationProgress

Encapsulates progress related information for a Cloud Spanner long running operation. Corresponds to the JSON property progress



6266
6267
6268
# File 'lib/google/apis/spanner_v1/classes.rb', line 6266

def progress
  @progress
end

#source_typeString

The type of the restore source. Corresponds to the JSON property sourceType

Returns:

  • (String)


6271
6272
6273
# File 'lib/google/apis/spanner_v1/classes.rb', line 6271

def source_type
  @source_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6278
6279
6280
6281
6282
6283
6284
6285
# File 'lib/google/apis/spanner_v1/classes.rb', line 6278

def update!(**args)
  @backup_info = args[:backup_info] if args.key?(:backup_info)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @name = args[:name] if args.key?(:name)
  @optimize_database_operation_name = args[:optimize_database_operation_name] if args.key?(:optimize_database_operation_name)
  @progress = args[:progress] if args.key?(:progress)
  @source_type = args[:source_type] if args.key?(:source_type)
end