Class: Google::Apis::SpannerV1::ResultSet
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ResultSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Results from Read or ExecuteSql.
Instance Attribute Summary collapse
-
#metadata ⇒ Google::Apis::SpannerV1::ResultSetMetadata
Metadata about a ResultSet or PartialResultSet.
-
#precommit_token ⇒ Google::Apis::SpannerV1::MultiplexedSessionPrecommitToken
When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses.
-
#rows ⇒ Array<Array<Object>>
Each element in
rowsis a row whose format is defined by metadata.row_type. -
#stats ⇒ Google::Apis::SpannerV1::ResultSetStats
Additional statistics about a ResultSet or PartialResultSet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResultSet
constructor
A new instance of ResultSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResultSet
Returns a new instance of ResultSet.
6400 6401 6402 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata ⇒ Google::Apis::SpannerV1::ResultSetMetadata
Metadata about a ResultSet or PartialResultSet.
Corresponds to the JSON property metadata
6378 6379 6380 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6378 def @metadata end |
#precommit_token ⇒ Google::Apis::SpannerV1::MultiplexedSessionPrecommitToken
When a read-write transaction is executed on a multiplexed session, this
precommit token is sent back to the client as a part of the Transaction
message in the BeginTransaction response and also as a part of the ResultSet
and PartialResultSet responses.
Corresponds to the JSON property precommitToken
6386 6387 6388 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6386 def precommit_token @precommit_token end |
#rows ⇒ Array<Array<Object>>
Each element in rows is a row whose format is defined by metadata.row_type.
The ith element in each row matches the ith field in metadata.row_type.
Elements are encoded based on type as described here.
Corresponds to the JSON property rows
6393 6394 6395 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6393 def rows @rows end |
#stats ⇒ Google::Apis::SpannerV1::ResultSetStats
Additional statistics about a ResultSet or PartialResultSet.
Corresponds to the JSON property stats
6398 6399 6400 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6398 def stats @stats end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6405 6406 6407 6408 6409 6410 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6405 def update!(**args) @metadata = args[:metadata] if args.key?(:metadata) @precommit_token = args[:precommit_token] if args.key?(:precommit_token) @rows = args[:rows] if args.key?(:rows) @stats = args[:stats] if args.key?(:stats) end |