Class: Google::Apis::SpannerV1::ResultSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Results from Read or ExecuteSql.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResultSet

Returns a new instance of ResultSet.



6284
6285
6286
# File 'lib/google/apis/spanner_v1/classes.rb', line 6284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadataGoogle::Apis::SpannerV1::ResultSetMetadata

Metadata about a ResultSet or PartialResultSet. Corresponds to the JSON property metadata



6262
6263
6264
# File 'lib/google/apis/spanner_v1/classes.rb', line 6262

def 
  @metadata
end

#precommit_tokenGoogle::Apis::SpannerV1::MultiplexedSessionPrecommitToken

When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses. Corresponds to the JSON property precommitToken



6270
6271
6272
# File 'lib/google/apis/spanner_v1/classes.rb', line 6270

def precommit_token
  @precommit_token
end

#rowsArray<Array<Object>>

Each element in rows is a row whose format is defined by metadata.row_type. The ith element in each row matches the ith field in metadata.row_type. Elements are encoded based on type as described here. Corresponds to the JSON property rows

Returns:

  • (Array<Array<Object>>)


6277
6278
6279
# File 'lib/google/apis/spanner_v1/classes.rb', line 6277

def rows
  @rows
end

#statsGoogle::Apis::SpannerV1::ResultSetStats

Additional statistics about a ResultSet or PartialResultSet. Corresponds to the JSON property stats



6282
6283
6284
# File 'lib/google/apis/spanner_v1/classes.rb', line 6282

def stats
  @stats
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6289
6290
6291
6292
6293
6294
# File 'lib/google/apis/spanner_v1/classes.rb', line 6289

def update!(**args)
  @metadata = args[:metadata] if args.key?(:metadata)
  @precommit_token = args[:precommit_token] if args.key?(:precommit_token)
  @rows = args[:rows] if args.key?(:rows)
  @stats = args[:stats] if args.key?(:stats)
end