Class: Google::Apis::SpannerV1::Scan

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Scan is a structure which describes Cloud Key Visualizer scan information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Scan

Returns a new instance of Scan.



6519
6520
6521
# File 'lib/google/apis/spanner_v1/classes.rb', line 6519

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsHash<String,Object>

Additional information provided by the implementer. Corresponds to the JSON property details

Returns:

  • (Hash<String,Object>)


6494
6495
6496
# File 'lib/google/apis/spanner_v1/classes.rb', line 6494

def details
  @details
end

#end_timeString

The upper bound for when the scan is defined. Corresponds to the JSON property endTime

Returns:

  • (String)


6499
6500
6501
# File 'lib/google/apis/spanner_v1/classes.rb', line 6499

def end_time
  @end_time
end

#nameString

The unique name of the scan, specific to the Database service implementing this interface. Corresponds to the JSON property name

Returns:

  • (String)


6505
6506
6507
# File 'lib/google/apis/spanner_v1/classes.rb', line 6505

def name
  @name
end

#scan_dataGoogle::Apis::SpannerV1::ScanData

ScanData contains Cloud Key Visualizer scan data used by the caller to construct a visualization. Corresponds to the JSON property scanData



6511
6512
6513
# File 'lib/google/apis/spanner_v1/classes.rb', line 6511

def scan_data
  @scan_data
end

#start_timeString

A range of time (inclusive) for when the scan is defined. The lower bound for when the scan is defined. Corresponds to the JSON property startTime

Returns:

  • (String)


6517
6518
6519
# File 'lib/google/apis/spanner_v1/classes.rb', line 6517

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6524
6525
6526
6527
6528
6529
6530
# File 'lib/google/apis/spanner_v1/classes.rb', line 6524

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @scan_data = args[:scan_data] if args.key?(:scan_data)
  @start_time = args[:start_time] if args.key?(:start_time)
end