Class: Google::Apis::SpannerV1::Scan
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::Scan
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Scan is a structure which describes Cloud Key Visualizer scan information.
Instance Attribute Summary collapse
-
#details ⇒ Hash<String,Object>
Additional information provided by the implementer.
-
#end_time ⇒ String
The upper bound for when the scan is defined.
-
#name ⇒ String
The unique name of the scan, specific to the Database service implementing this interface.
-
#scan_data ⇒ Google::Apis::SpannerV1::ScanData
ScanData contains Cloud Key Visualizer scan data used by the caller to construct a visualization.
-
#start_time ⇒ String
A range of time (inclusive) for when the scan is defined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scan
constructor
A new instance of Scan.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Scan
Returns a new instance of Scan.
6512 6513 6514 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ Hash<String,Object>
Additional information provided by the implementer.
Corresponds to the JSON property details
6487 6488 6489 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6487 def details @details end |
#end_time ⇒ String
The upper bound for when the scan is defined.
Corresponds to the JSON property endTime
6492 6493 6494 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6492 def end_time @end_time end |
#name ⇒ String
The unique name of the scan, specific to the Database service implementing
this interface.
Corresponds to the JSON property name
6498 6499 6500 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6498 def name @name end |
#scan_data ⇒ Google::Apis::SpannerV1::ScanData
ScanData contains Cloud Key Visualizer scan data used by the caller to
construct a visualization.
Corresponds to the JSON property scanData
6504 6505 6506 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6504 def scan_data @scan_data end |
#start_time ⇒ String
A range of time (inclusive) for when the scan is defined. The lower bound for
when the scan is defined.
Corresponds to the JSON property startTime
6510 6511 6512 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6510 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6517 6518 6519 6520 6521 6522 6523 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6517 def update!(**args) @details = args[:details] if args.key?(:details) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @scan_data = args[:scan_data] if args.key?(:scan_data) @start_time = args[:start_time] if args.key?(:start_time) end |