Class: Google::Apis::SpannerV1::ScanData
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ScanData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
ScanData contains Cloud Key Visualizer scan data used by the caller to construct a visualization.
Instance Attribute Summary collapse
-
#data ⇒ Google::Apis::SpannerV1::VisualizationData
Cloud Key Visualizer scan data.
-
#end_time ⇒ String
The upper bound for when the contained data is defined.
-
#start_time ⇒ String
A range of time (inclusive) for when the contained data is defined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScanData
constructor
A new instance of ScanData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScanData
Returns a new instance of ScanData.
6556 6557 6558 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6556 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Google::Apis::SpannerV1::VisualizationData
Cloud Key Visualizer scan data. The range of time this information covers is
captured via the above time range fields. Note, this field is not available to
the ListScans method.
Corresponds to the JSON property data
6543 6544 6545 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6543 def data @data end |
#end_time ⇒ String
The upper bound for when the contained data is defined.
Corresponds to the JSON property endTime
6548 6549 6550 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6548 def end_time @end_time end |
#start_time ⇒ String
A range of time (inclusive) for when the contained data is defined. The lower
bound for when the contained data is defined.
Corresponds to the JSON property startTime
6554 6555 6556 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6554 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6561 6562 6563 6564 6565 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6561 def update!(**args) @data = args[:data] if args.key?(:data) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |