Class: Google::Apis::SpannerV1::ScanData
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::ScanData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
ScanData contains Cloud Key Visualizer scan data used by the caller to construct a visualization.
Instance Attribute Summary collapse
-
#data ⇒ Google::Apis::SpannerV1::VisualizationData
Cloud Key Visualizer scan data.
-
#end_time ⇒ String
The upper bound for when the contained data is defined.
-
#start_time ⇒ String
A range of time (inclusive) for when the contained data is defined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScanData
constructor
A new instance of ScanData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScanData
Returns a new instance of ScanData.
6549 6550 6551 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Google::Apis::SpannerV1::VisualizationData
Cloud Key Visualizer scan data. The range of time this information covers is
captured via the above time range fields. Note, this field is not available to
the ListScans method.
Corresponds to the JSON property data
6536 6537 6538 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6536 def data @data end |
#end_time ⇒ String
The upper bound for when the contained data is defined.
Corresponds to the JSON property endTime
6541 6542 6543 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6541 def end_time @end_time end |
#start_time ⇒ String
A range of time (inclusive) for when the contained data is defined. The lower
bound for when the contained data is defined.
Corresponds to the JSON property startTime
6547 6548 6549 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6547 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6554 6555 6556 6557 6558 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6554 def update!(**args) @data = args[:data] if args.key?(:data) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |