Class: Google::Apis::SpannerV1::SendProp
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::SendProp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Arguments to send operations.
Instance Attribute Summary collapse
-
#deliver_time ⇒ String
The time at which Spanner will begin attempting to deliver the message.
-
#key ⇒ Array<Object>
Required.
-
#payload ⇒ Object
The payload of the message.
-
#queue ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SendProp
constructor
A new instance of SendProp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SendProp
Returns a new instance of SendProp.
6588 6589 6590 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6588 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deliver_time ⇒ String
The time at which Spanner will begin attempting to deliver the message. If
deliver_time is not set, Spanner will deliver the message immediately. If
deliver_time is in the past, Spanner will replace it with a value closer to
the current time.
Corresponds to the JSON property deliverTime
6571 6572 6573 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6571 def deliver_time @deliver_time end |
#key ⇒ Array<Object>
Required. The primary key of the message to be sent.
Corresponds to the JSON property key
6576 6577 6578 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6576 def key @key end |
#payload ⇒ Object
The payload of the message.
Corresponds to the JSON property payload
6581 6582 6583 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6581 def payload @payload end |
#queue ⇒ String
Required. The queue to which the message will be sent.
Corresponds to the JSON property queue
6586 6587 6588 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6586 def queue @queue end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6593 6594 6595 6596 6597 6598 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6593 def update!(**args) @deliver_time = args[:deliver_time] if args.key?(:deliver_time) @key = args[:key] if args.key?(:key) @payload = args[:payload] if args.key?(:payload) @queue = args[:queue] if args.key?(:queue) end |