Class: Google::Apis::SpannerV1::SendProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Arguments to send operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SendProp

Returns a new instance of SendProp.



6496
6497
6498
# File 'lib/google/apis/spanner_v1/classes.rb', line 6496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deliver_timeString

The time at which Spanner will begin attempting to deliver the message. If deliver_time is not set, Spanner will deliver the message immediately. If deliver_time is in the past, Spanner will replace it with a value closer to the current time. Corresponds to the JSON property deliverTime

Returns:

  • (String)


6479
6480
6481
# File 'lib/google/apis/spanner_v1/classes.rb', line 6479

def deliver_time
  @deliver_time
end

#keyArray<Object>

Required. The primary key of the message to be sent. Corresponds to the JSON property key

Returns:

  • (Array<Object>)


6484
6485
6486
# File 'lib/google/apis/spanner_v1/classes.rb', line 6484

def key
  @key
end

#payloadObject

The payload of the message. Corresponds to the JSON property payload

Returns:

  • (Object)


6489
6490
6491
# File 'lib/google/apis/spanner_v1/classes.rb', line 6489

def payload
  @payload
end

#queueString

Required. The queue to which the message will be sent. Corresponds to the JSON property queue

Returns:

  • (String)


6494
6495
6496
# File 'lib/google/apis/spanner_v1/classes.rb', line 6494

def queue
  @queue
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6501
6502
6503
6504
6505
6506
# File 'lib/google/apis/spanner_v1/classes.rb', line 6501

def update!(**args)
  @deliver_time = args[:deliver_time] if args.key?(:deliver_time)
  @key = args[:key] if args.key?(:key)
  @payload = args[:payload] if args.key?(:payload)
  @queue = args[:queue] if args.key?(:queue)
end