Class: Google::Apis::SpannerV1::SingleRegionQuorum
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::SingleRegionQuorum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Message type for a single-region quorum.
Instance Attribute Summary collapse
-
#serving_location ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleRegionQuorum
constructor
A new instance of SingleRegionQuorum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleRegionQuorum
Returns a new instance of SingleRegionQuorum.
6656 6657 6658 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#serving_location ⇒ String
Required. The location of the serving region, for example, "us-central1". The
location must be one of the regions within the dual-region instance
configuration of your database. The list of valid locations is available using
the GetInstanceConfig API. This should only be used if you plan to change
quorum to the single-region quorum type.
Corresponds to the JSON property servingLocation
6654 6655 6656 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6654 def serving_location @serving_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6661 6662 6663 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6661 def update!(**args) @serving_location = args[:serving_location] if args.key?(:serving_location) end |