Class: Google::Apis::SpannerV1::SplitPoints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

The split points of a table or an index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SplitPoints

Returns a new instance of SplitPoints.



6785
6786
6787
# File 'lib/google/apis/spanner_v1/classes.rb', line 6785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

Optional. The expiration timestamp of the split points. A timestamp in the past means immediate expiration. The maximum value can be 30 days in the future. Defaults to 10 days in the future if not specified. Corresponds to the JSON property expireTime

Returns:

  • (String)


6767
6768
6769
# File 'lib/google/apis/spanner_v1/classes.rb', line 6767

def expire_time
  @expire_time
end

#indexString

The index to split. If specified, the table field must refer to the index's base table. Corresponds to the JSON property index

Returns:

  • (String)


6773
6774
6775
# File 'lib/google/apis/spanner_v1/classes.rb', line 6773

def index
  @index
end

#keysArray<Google::Apis::SpannerV1::Key>

Required. The list of split keys. In essence, the split boundaries. Corresponds to the JSON property keys

Returns:



6778
6779
6780
# File 'lib/google/apis/spanner_v1/classes.rb', line 6778

def keys
  @keys
end

#tableString

The table to split. Corresponds to the JSON property table

Returns:

  • (String)


6783
6784
6785
# File 'lib/google/apis/spanner_v1/classes.rb', line 6783

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6790
6791
6792
6793
6794
6795
# File 'lib/google/apis/spanner_v1/classes.rb', line 6790

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @index = args[:index] if args.key?(:index)
  @keys = args[:keys] if args.key?(:keys)
  @table = args[:table] if args.key?(:table)
end