Class: Google::Apis::SpannerV1::SplitPoints
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::SplitPoints
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
The split points of a table or an index.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
Optional.
-
#index ⇒ String
The index to split.
-
#keys ⇒ Array<Google::Apis::SpannerV1::Key>
Required.
-
#table ⇒ String
The table to split.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SplitPoints
constructor
A new instance of SplitPoints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SplitPoints
Returns a new instance of SplitPoints.
6693 6694 6695 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
Optional. The expiration timestamp of the split points. A timestamp in the
past means immediate expiration. The maximum value can be 30 days in the
future. Defaults to 10 days in the future if not specified.
Corresponds to the JSON property expireTime
6675 6676 6677 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6675 def expire_time @expire_time end |
#index ⇒ String
The index to split. If specified, the table field must refer to the index's
base table.
Corresponds to the JSON property index
6681 6682 6683 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6681 def index @index end |
#keys ⇒ Array<Google::Apis::SpannerV1::Key>
Required. The list of split keys. In essence, the split boundaries.
Corresponds to the JSON property keys
6686 6687 6688 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6686 def keys @keys end |
#table ⇒ String
The table to split.
Corresponds to the JSON property table
6691 6692 6693 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6691 def table @table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6698 6699 6700 6701 6702 6703 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6698 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) @index = args[:index] if args.key?(:index) @keys = args[:keys] if args.key?(:keys) @table = args[:table] if args.key?(:table) end |