Class: Google::Apis::SpannerV1::Statement
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::Statement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
A single DML statement.
Instance Attribute Summary collapse
-
#param_types ⇒ Hash<String,Google::Apis::SpannerV1::Type>
It isn't always possible for Cloud Spanner to infer the right SQL type from a JSON value.
-
#params ⇒ Hash<String,Object>
Parameter names and values that bind to placeholders in the DML string.
-
#sql ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Statement
constructor
A new instance of Statement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Statement
Returns a new instance of Statement.
6827 6828 6829 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#param_types ⇒ Hash<String,Google::Apis::SpannerV1::Type>
It isn't always possible for Cloud Spanner to infer the right SQL type from a
JSON value. For example, values of type BYTES and values of type STRING
both appear in params as JSON strings. In these cases, param_types can be
used to specify the exact SQL type for some or all of the SQL statement
parameters. See the definition of Type for more information about SQL types.
Corresponds to the JSON property paramTypes
6809 6810 6811 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6809 def param_types @param_types end |
#params ⇒ Hash<String,Object>
Parameter names and values that bind to placeholders in the DML string. A
parameter placeholder consists of the @ character followed by the parameter
name (for example, @firstName). Parameter names can contain letters, numbers,
and underscores. Parameters can appear anywhere that a literal value is
expected. The same parameter name can be used more than once, for example: "
WHERE id > @msg_id AND id < @msg_id + 100" It's an error to execute a SQL
statement with unbound parameters.
Corresponds to the JSON property params
6820 6821 6822 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6820 def params @params end |
#sql ⇒ String
Required. The DML string.
Corresponds to the JSON property sql
6825 6826 6827 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6825 def sql @sql end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6832 6833 6834 6835 6836 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 6832 def update!(**args) @param_types = args[:param_types] if args.key?(:param_types) @params = args[:params] if args.key?(:params) @sql = args[:sql] if args.key?(:sql) end |