Class: Google::Apis::SpannerV1::UpdateDatabaseDdlMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the operation returned by UpdateDatabaseDdl.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateDatabaseDdlMetadata

Returns a new instance of UpdateDatabaseDdlMetadata.



7171
7172
7173
# File 'lib/google/apis/spanner_v1/classes.rb', line 7171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::SpannerV1::DdlStatementActionInfo>

The brief action info for the DDL statements. actions[i] is the brief info for statements[i]. Corresponds to the JSON property actions



7134
7135
7136
# File 'lib/google/apis/spanner_v1/classes.rb', line 7134

def actions
  @actions
end

#commit_timestampsArray<String>

Reports the commit timestamps of all statements that have succeeded so far, where commit_timestamps[i] is the commit timestamp for the statement statements[i]. Corresponds to the JSON property commitTimestamps

Returns:

  • (Array<String>)


7141
7142
7143
# File 'lib/google/apis/spanner_v1/classes.rb', line 7141

def commit_timestamps
  @commit_timestamps
end

#databaseString

The database being modified. Corresponds to the JSON property database

Returns:

  • (String)


7146
7147
7148
# File 'lib/google/apis/spanner_v1/classes.rb', line 7146

def database
  @database
end

#progressArray<Google::Apis::SpannerV1::OperationProgress>

The progress of the UpdateDatabaseDdl operations. All DDL statements will have continuously updating progress, and progress[i] is the operation progress for statements[i]. Also, progress[i] will have start time and end time populated with commit timestamp of operation, as well as a progress of 100% once the operation has completed. Corresponds to the JSON property progress



7155
7156
7157
# File 'lib/google/apis/spanner_v1/classes.rb', line 7155

def progress
  @progress
end

#statementsArray<String>

For an update this list contains all the statements. For an individual statement, this list contains only that statement. Corresponds to the JSON property statements

Returns:

  • (Array<String>)


7161
7162
7163
# File 'lib/google/apis/spanner_v1/classes.rb', line 7161

def statements
  @statements
end

#throttledBoolean Also known as: throttled?

Output only. When true, indicates that the operation is throttled, for example, due to resource constraints. When resources become available the operation will resume and this field will be false again. Corresponds to the JSON property throttled

Returns:

  • (Boolean)


7168
7169
7170
# File 'lib/google/apis/spanner_v1/classes.rb', line 7168

def throttled
  @throttled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7176
7177
7178
7179
7180
7181
7182
7183
# File 'lib/google/apis/spanner_v1/classes.rb', line 7176

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @commit_timestamps = args[:commit_timestamps] if args.key?(:commit_timestamps)
  @database = args[:database] if args.key?(:database)
  @progress = args[:progress] if args.key?(:progress)
  @statements = args[:statements] if args.key?(:statements)
  @throttled = args[:throttled] if args.key?(:throttled)
end