Class: Google::Apis::SpannerV1::UpdateInstanceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::UpdateInstanceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Metadata type for the operation returned by UpdateInstance.
Instance Attribute Summary collapse
-
#cancel_time ⇒ String
The time at which this operation was cancelled.
-
#end_time ⇒ String
The time at which this operation failed or was completed successfully.
-
#expected_fulfillment_period ⇒ String
The expected fulfillment period of this update operation.
-
#instance ⇒ Google::Apis::SpannerV1::Instance
An isolated set of Cloud Spanner resources on which databases can be hosted.
-
#start_time ⇒ String
The time at which UpdateInstance request was received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateInstanceMetadata
constructor
A new instance of UpdateInstanceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateInstanceMetadata
Returns a new instance of UpdateInstanceMetadata.
7399 7400 7401 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancel_time ⇒ String
The time at which this operation was cancelled. If set, this operation is in
the process of undoing itself (which is guaranteed to succeed) and cannot be
cancelled again.
Corresponds to the JSON property cancelTime
7377 7378 7379 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7377 def cancel_time @cancel_time end |
#end_time ⇒ String
The time at which this operation failed or was completed successfully.
Corresponds to the JSON property endTime
7382 7383 7384 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7382 def end_time @end_time end |
#expected_fulfillment_period ⇒ String
The expected fulfillment period of this update operation.
Corresponds to the JSON property expectedFulfillmentPeriod
7387 7388 7389 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7387 def expected_fulfillment_period @expected_fulfillment_period end |
#instance ⇒ Google::Apis::SpannerV1::Instance
An isolated set of Cloud Spanner resources on which databases can be hosted.
Corresponds to the JSON property instance
7392 7393 7394 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7392 def instance @instance end |
#start_time ⇒ String
The time at which UpdateInstance request was received.
Corresponds to the JSON property startTime
7397 7398 7399 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7397 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7404 7405 7406 7407 7408 7409 7410 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7404 def update!(**args) @cancel_time = args[:cancel_time] if args.key?(:cancel_time) @end_time = args[:end_time] if args.key?(:end_time) @expected_fulfillment_period = args[:expected_fulfillment_period] if args.key?(:expected_fulfillment_period) @instance = args[:instance] if args.key?(:instance) @start_time = args[:start_time] if args.key?(:start_time) end |