Class: Google::Apis::SpannerV1::UpdateInstanceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the operation returned by UpdateInstance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateInstanceMetadata

Returns a new instance of UpdateInstanceMetadata.



7307
7308
7309
# File 'lib/google/apis/spanner_v1/classes.rb', line 7307

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancel_timeString

The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again. Corresponds to the JSON property cancelTime

Returns:

  • (String)


7285
7286
7287
# File 'lib/google/apis/spanner_v1/classes.rb', line 7285

def cancel_time
  @cancel_time
end

#end_timeString

The time at which this operation failed or was completed successfully. Corresponds to the JSON property endTime

Returns:

  • (String)


7290
7291
7292
# File 'lib/google/apis/spanner_v1/classes.rb', line 7290

def end_time
  @end_time
end

#expected_fulfillment_periodString

The expected fulfillment period of this update operation. Corresponds to the JSON property expectedFulfillmentPeriod

Returns:

  • (String)


7295
7296
7297
# File 'lib/google/apis/spanner_v1/classes.rb', line 7295

def expected_fulfillment_period
  @expected_fulfillment_period
end

#instanceGoogle::Apis::SpannerV1::Instance

An isolated set of Cloud Spanner resources on which databases can be hosted. Corresponds to the JSON property instance



7300
7301
7302
# File 'lib/google/apis/spanner_v1/classes.rb', line 7300

def instance
  @instance
end

#start_timeString

The time at which UpdateInstance request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


7305
7306
7307
# File 'lib/google/apis/spanner_v1/classes.rb', line 7305

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7312
7313
7314
7315
7316
7317
7318
# File 'lib/google/apis/spanner_v1/classes.rb', line 7312

def update!(**args)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @expected_fulfillment_period = args[:expected_fulfillment_period] if args.key?(:expected_fulfillment_period)
  @instance = args[:instance] if args.key?(:instance)
  @start_time = args[:start_time] if args.key?(:start_time)
end