Class: Google::Apis::SpannerV1::UpdateInstancePartitionMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the operation returned by UpdateInstancePartition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateInstancePartitionMetadata

Returns a new instance of UpdateInstancePartitionMetadata.



7447
7448
7449
# File 'lib/google/apis/spanner_v1/classes.rb', line 7447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancel_timeString

The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again. Corresponds to the JSON property cancelTime

Returns:

  • (String)


7429
7430
7431
# File 'lib/google/apis/spanner_v1/classes.rb', line 7429

def cancel_time
  @cancel_time
end

#end_timeString

The time at which this operation failed or was completed successfully. Corresponds to the JSON property endTime

Returns:

  • (String)


7434
7435
7436
# File 'lib/google/apis/spanner_v1/classes.rb', line 7434

def end_time
  @end_time
end

#instance_partitionGoogle::Apis::SpannerV1::InstancePartition

An isolated set of Cloud Spanner resources that databases can define placements on. Corresponds to the JSON property instancePartition



7440
7441
7442
# File 'lib/google/apis/spanner_v1/classes.rb', line 7440

def instance_partition
  @instance_partition
end

#start_timeString

The time at which UpdateInstancePartition request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


7445
7446
7447
# File 'lib/google/apis/spanner_v1/classes.rb', line 7445

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7452
7453
7454
7455
7456
7457
# File 'lib/google/apis/spanner_v1/classes.rb', line 7452

def update!(**args)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @instance_partition = args[:instance_partition] if args.key?(:instance_partition)
  @start_time = args[:start_time] if args.key?(:start_time)
end