Class: Google::Apis::SpannerV1::UpdateInstancePartitionMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpannerV1::UpdateInstancePartitionMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb
Overview
Metadata type for the operation returned by UpdateInstancePartition.
Instance Attribute Summary collapse
-
#cancel_time ⇒ String
The time at which this operation was cancelled.
-
#end_time ⇒ String
The time at which this operation failed or was completed successfully.
-
#instance_partition ⇒ Google::Apis::SpannerV1::InstancePartition
An isolated set of Cloud Spanner resources that databases can define placements on.
-
#start_time ⇒ String
The time at which UpdateInstancePartition request was received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateInstancePartitionMetadata
constructor
A new instance of UpdateInstancePartitionMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateInstancePartitionMetadata
Returns a new instance of UpdateInstancePartitionMetadata.
7440 7441 7442 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cancel_time ⇒ String
The time at which this operation was cancelled. If set, this operation is in
the process of undoing itself (which is guaranteed to succeed) and cannot be
cancelled again.
Corresponds to the JSON property cancelTime
7422 7423 7424 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7422 def cancel_time @cancel_time end |
#end_time ⇒ String
The time at which this operation failed or was completed successfully.
Corresponds to the JSON property endTime
7427 7428 7429 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7427 def end_time @end_time end |
#instance_partition ⇒ Google::Apis::SpannerV1::InstancePartition
An isolated set of Cloud Spanner resources that databases can define
placements on.
Corresponds to the JSON property instancePartition
7433 7434 7435 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7433 def instance_partition @instance_partition end |
#start_time ⇒ String
The time at which UpdateInstancePartition request was received.
Corresponds to the JSON property startTime
7438 7439 7440 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7438 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7445 7446 7447 7448 7449 7450 |
# File 'lib/google/apis/spanner_v1/classes.rb', line 7445 def update!(**args) @cancel_time = args[:cancel_time] if args.key?(:cancel_time) @end_time = args[:end_time] if args.key?(:end_time) @instance_partition = args[:instance_partition] if args.key?(:instance_partition) @start_time = args[:start_time] if args.key?(:start_time) end |