Class: Google::Apis::SpannerV1::UpdateInstancePartitionMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/spanner_v1/classes.rb,
lib/google/apis/spanner_v1/representations.rb,
lib/google/apis/spanner_v1/representations.rb

Overview

Metadata type for the operation returned by UpdateInstancePartition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateInstancePartitionMetadata

Returns a new instance of UpdateInstancePartitionMetadata.



7348
7349
7350
# File 'lib/google/apis/spanner_v1/classes.rb', line 7348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancel_timeString

The time at which this operation was cancelled. If set, this operation is in the process of undoing itself (which is guaranteed to succeed) and cannot be cancelled again. Corresponds to the JSON property cancelTime

Returns:

  • (String)


7330
7331
7332
# File 'lib/google/apis/spanner_v1/classes.rb', line 7330

def cancel_time
  @cancel_time
end

#end_timeString

The time at which this operation failed or was completed successfully. Corresponds to the JSON property endTime

Returns:

  • (String)


7335
7336
7337
# File 'lib/google/apis/spanner_v1/classes.rb', line 7335

def end_time
  @end_time
end

#instance_partitionGoogle::Apis::SpannerV1::InstancePartition

An isolated set of Cloud Spanner resources that databases can define placements on. Corresponds to the JSON property instancePartition



7341
7342
7343
# File 'lib/google/apis/spanner_v1/classes.rb', line 7341

def instance_partition
  @instance_partition
end

#start_timeString

The time at which UpdateInstancePartition request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


7346
7347
7348
# File 'lib/google/apis/spanner_v1/classes.rb', line 7346

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7353
7354
7355
7356
7357
7358
# File 'lib/google/apis/spanner_v1/classes.rb', line 7353

def update!(**args)
  @cancel_time = args[:cancel_time] if args.key?(:cancel_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @instance_partition = args[:instance_partition] if args.key?(:instance_partition)
  @start_time = args[:start_time] if args.key?(:start_time)
end